//-----------------------------------------------------
// version: "1.6"
// name: "Advanced Crossfeed"
// author: "Radoslaw Szkodzinski"
//
// Code generated with Faust 0.9.58 (http://faust.grame.fr)
//-----------------------------------------------------
/* link with  */
#include <math.h>
#include <cmath>
template <int N> inline float faustpower(float x) 		{ return powf(x,N); } 
template <int N> inline double faustpower(double x) 	{ return pow(x,N); }
template <int N> inline int faustpower(int x) 			{ return faustpower<N/2>(x) * faustpower<N-N/2>(x); } 
template <> 	 inline int faustpower<0>(int x) 		{ return 1; }
template <> 	 inline int faustpower<1>(int x) 		{ return x; }
/************************************************************************

	IMPORTANT NOTE : this file contains two clearly delimited sections : 
	the ARCHITECTURE section (in two parts) and the USER section. Each section 
	is governed by its own copyright and license. Please check individually 
	each section for license and copyright information.
*************************************************************************/

/*******************BEGIN ARCHITECTURE SECTION (part 1/2)****************/

/************************************************************************
 ************************************************************************
    FAUST Architecture File
	Copyright (C) 2007-2011 Remy Muller & Julius Smith
	All rights reserved.
    ----------------------------BSD License------------------------------
	Redistribution and use in source and binary forms, with or without 
	modification, are permitted provided that the following conditions 
	are met:

    	* Redistributions of source code must retain the above copyright 
		  notice, this list of conditions and the following disclaimer.
    	* Redistributions in binary form must reproduce the above 
		  copyright notice, this list of conditions and the following 
		  disclaimer in the documentation and/or other materials provided 
		  with the distribution.
    	* Neither the name of Remy Muller or Julius Smith or of its 
		  contributors may be used to endorse or promote products derived 
		  from this software without specific prior written permission.

	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
	"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
	LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
	FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
	COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
	BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
	LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
	CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
	STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
	ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
	OF THE POSSIBILITY OF SUCH DAMAGE.

    ----------------------------VST SDK----------------------------------
	In order to compile a VST (TM) plugin with this architecture file 
	you will need the proprietary VST SDK from Steinberg. Please check 
	the corresponding license.

 ************************************************************************
 ************************************************************************/



/********************************************************************
 * VST-2.4 wrapper for the FAUST language. 
 *
 * Usage: faust -a vst2p4.cpp myfaustprog.dsp
 *
 * By Julius Smith (http://ccrma.stanford.edu/~jos/), based on 
 * vst.cpp by remy muller remy.muller@ircam.fr 
 * http://www.smartelectronix.com/~mdsp/.
 * Essentially, vst.cpp was edited to look more like the "again" 
 * programming sample that comes with the VST-2.4 SDK from Steinberg.
 *
 * NOTES:
 *  Relies on automatically generated slider GUI for VST plugins.
 *   - Horizontal and vertical sliders mapped to "vstSlider"
 *   - Numeric Entries similarly converted to "vstSlider"
 *   - No support for bar graphs or additional numeric and text displays
 *   - Tested on the Muse Receptor Pro 1.0, System Version 1.6.20070717,
 *     using Visual C++ 2008 Express Edition 
 *     (part of the Microsoft Visual Studio 2008, Beta 2)
 *   - Reference: 
 * http://ccrma.stanford.edu/realsimple/faust/Generating_VST_Plugin_Faust.html
 *
 * FAUST 
 * Copyright (C) 2003-2007 GRAME, Centre National de Creation Musicale
 * http://www.grame.fr/			     
 *
 ********************************************************************/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <limits.h>
#include <math.h>
#include <errno.h>
#include <time.h>
//#include <unistd.h>
#include <fcntl.h>
#include <assert.h>
#include <string>
#include <vector>
#include <map>
#include <cstring>
#include <cmath>
#include <cstdio>

using namespace std ;

// There is a bug with powf() when cross compiling with mingw
// the following macro avoid the problem
#ifdef WIN32
#define powf(x,y) pow(x,y)
#define expf(x) exp(x)
#endif

// On Intel set FZ (Flush to Zero) and DAZ (Denormals Are Zero)
// flags to avoid costly denormals
#ifdef __SSE__
    #include <xmmintrin.h>
    #ifdef __SSE2__
        #define AVOIDDENORMALS _mm_setcsr(_mm_getcsr() | 0x8040)
    #else
        #define AVOIDDENORMALS _mm_setcsr(_mm_getcsr() | 0x8000)
    #endif
#else
    #define AVOIDDENORMALS 
#endif

struct Meta : std::map<std::string, std::string>
{
    void declare(const char* key, const char* value)
    {
        (*this)[key] = value;
    }
};
		
// abs is now predefined
//template<typename T> T abs (T a) { return (a<T(0)) ? -a : a; }

inline int lsr (int x, int n) { return int(((unsigned int)x) >> n); }

inline int int2pow2 (int x) { int r=0; while ((1<<r)<x) r++; return r; }

/******************************************************************************
*******************************************************************************
*
*							       VECTOR INTRINSICS
*
*******************************************************************************
*******************************************************************************/

//inline void *aligned_calloc(size_t nmemb, size_t size) { return (void*)((unsigned)(calloc((nmemb*size)+15,sizeof(char)))+15 & 0xfffffff0); }
//inline void *aligned_calloc(size_t nmemb, size_t size) { return (void*)((size_t)(calloc((nmemb*size)+15,sizeof(char)))+15 & ~15); }


/******************************************************************************
*******************************************************************************
*
*								USER INTERFACE
*
*******************************************************************************
*******************************************************************************/

class UI
{
  bool	fStopped;
		
public:
			
  UI() : fStopped(false) {}
  virtual ~UI() {}
		
  virtual void addButton(const char* label, float* zone) = 0;
  virtual void addToggleButton(const char* label, float* zone) = 0;
  virtual void addCheckButton(const char* label, float* zone) = 0;
  virtual void addVerticalSlider(const char* label, float* zone, float init, float min, float max, float step) = 0;
  virtual void addHorizontalSlider(const char* label, float* zone, float init, float min, float max, float step) = 0;
  virtual void addNumEntry(const char* label, float* zone, float init, float min, float max, float step) = 0;
	
  virtual void addNumDisplay(const char* label, float* zone, int precision) = 0;
  virtual void addTextDisplay(const char* label, float* zone, char* names[], float min, float max) = 0;
  virtual void addHorizontalBargraph(const char* label, float* zone, float min, float max) = 0;
  virtual void addVerticalBargraph(const char* label, float* zone, float min, float max) = 0;
		
  virtual void openFrameBox(const char* label) = 0;
  virtual void openTabBox(const char* label) = 0;
  virtual void openHorizontalBox(const char* label) = 0;
  virtual void openVerticalBox(const char* label) = 0;
  virtual void closeBox() = 0;
		
  virtual void run() {};
		
  void stop()		{ fStopped = true; }
  bool stopped()	{ return fStopped; }

  virtual void declare(float* zone, const char* key, const char* value) {}
};


/******************************************************************************
*******************************************************************************
*
*								FAUST DSP
*
*******************************************************************************
*******************************************************************************/



//----------------------------------------------------------------
//  Base dsp class for this architecture
//----------------------------------------------------------------
			
class dsp {

protected:
	 
  int fSamplingFreq;
		
public:
	 
  dsp() {}
  virtual ~dsp() {}
  virtual int getNumInputs() = 0;
  virtual int getNumOutputs() = 0;
  virtual void buildUserInterface(UI* interface) = 0;
  virtual void init(int samplingRate) = 0;
  virtual void compute(int len, float** inputs, float** outputs) = 0;
};
		
/********************END ARCHITECTURE SECTION (part 1/2)****************/

/**************************BEGIN USER SECTION **************************/
		
#ifndef FAUSTFLOAT
#define FAUSTFLOAT float
#endif  

typedef long double quad;

#ifndef FAUSTCLASS 
#define FAUSTCLASS mydsp
#endif

class mydsp : public dsp {
  private:
	float 	fYec0[256];
	int 	fYec0_idx;
	int 	fYec0_idx_save;
	FAUSTFLOAT 	fentry0;
	int 	iConst0;
	float 	fConst1;
	float 	fConst2;
	FAUSTFLOAT 	fentry1;
	float 	fConst3;
	float 	fConst4;
	float 	fConst5;
	float 	fConst6;
	float 	fConst7;
	float 	fConst8;
	float 	fConst9;
	float 	fConst10;
	float 	fConst11;
	float 	fConst12;
	float 	fConst13;
	float 	fConst14;
	float 	fConst15;
	float 	fConst16;
	float 	fConst17;
	float 	fConst18;
	float 	fConst19;
	float 	fConst20;
	float 	fConst21;
	float 	fConst22;
	float 	fConst23;
	float 	fConst24;
	float 	fConst25;
	float 	fConst26;
	float 	fConst27;
	float 	fConst28;
	float 	fConst29;
	float 	fConst30;
	float 	fConst31;
	float 	fConst32;
	float 	fConst33;
	float 	fConst34;
	float 	fConst35;
	float 	fConst36;
	float 	fConst37;
	float 	fConst38;
	float 	fConst39;
	float 	fConst40;
	float 	fConst41;
	float 	fConst42;
	float 	fConst43;
	float 	fConst44;
	float 	fConst45;
	float 	fConst46;
	float 	fConst47;
	float 	fConst48;
	float 	fConst49;
	float 	fConst50;
	float 	fConst51;
	float 	fConst52;
	float 	fConst53;
	float 	fConst54;
	float 	fConst55;
	float 	fConst56;
	float 	fConst57;
	float 	fConst58;
	float 	fConst59;
	float 	fConst60;
	float 	fConst61;
	float 	fConst62;
	float 	fConst63;
	float 	fConst64;
	float 	fConst65;
	float 	fConst66;
	float 	fConst67;
	float 	fConst68;
	float 	fConst69;
	float 	fConst70;
	float 	fConst71;
	float 	fConst72;
	float 	fConst73;
	float 	fConst74;
	float 	fConst75;
	float 	fConst76;
	float 	fConst77;
	float 	fConst78;
	float 	fConst79;
	float 	fConst80;
	float 	fConst81;
	float 	fConst82;
	float 	fConst83;
	float 	fConst84;
	float 	fConst85;
	float 	fConst86;
	float 	fConst87;
	float 	fConst88;
	float 	fConst89;
	float 	fConst90;
	float 	fConst91;
	FAUSTFLOAT 	fentry2;
	FAUSTFLOAT 	fentry3;
	float 	fYec1[1024];
	int 	fYec1_idx;
	int 	fYec1_idx_save;
	FAUSTFLOAT 	fentry4;
	float 	fConst92;
	FAUSTFLOAT 	fentry5;
	float 	fYec2[128];
	int 	fYec2_idx;
	int 	fYec2_idx_save;
	FAUSTFLOAT 	fentry6;
	float 	fYec3[256];
	int 	fYec3_idx;
	int 	fYec3_idx_save;
	float 	fYec4[1024];
	int 	fYec4_idx;
	int 	fYec4_idx_save;
	float 	fYec5[128];
	int 	fYec5_idx;
	int 	fYec5_idx_save;
  public:
	static void metadata(Meta* m) 	{ 
		m->declare("version", "1.6");
		m->declare("filter.lib/copyright", "Julius O. Smith III");
		m->declare("filter.lib/version", "1.29");
		m->declare("filter.lib/license", "STK-4.3");
		m->declare("filter.lib/reference", "https://ccrma.stanford.edu/~jos/filters/");
		m->declare("filter.lib/name", "Faust Filter Library");
		m->declare("filter.lib/author", "Julius O. Smith (jos at ccrma.stanford.edu)");
		m->declare("music.lib/name", "Music Library");
		m->declare("music.lib/author", "GRAME");
		m->declare("music.lib/copyright", "GRAME");
		m->declare("music.lib/version", "1.0");
		m->declare("music.lib/license", "LGPL with exception");
		m->declare("name", "Advanced Crossfeed");
		m->declare("id", "adv_xfeed");
		m->declare("author", "Radoslaw Szkodzinski");
		m->declare("email", "astralstorm@gmail.com");
		m->declare("math.lib/name", "Math Library");
		m->declare("math.lib/author", "GRAME");
		m->declare("math.lib/copyright", "GRAME");
		m->declare("math.lib/version", "1.0");
		m->declare("math.lib/license", "LGPL with exception");
	}

	virtual int getNumInputs() 	{ return 2; }
	virtual int getNumOutputs() 	{ return 2; }
	static void classInit(int samplingFreq) {
	}
	virtual void instanceInit(int samplingFreq) {
		fSamplingFreq = samplingFreq;
		for (int i=0; i<256; i++) fYec0[i]=0;
		fYec0_idx = 0;
		fYec0_idx_save = 0;
		fentry0 = 1.5e+003f;
		iConst0 = min(192000, max(1, fSamplingFreq));
		fConst1 = (2.0f / float(iConst0));
		fConst2 = (565.4866776461628f / float(iConst0));
		fentry1 = 0.75f;
		fConst3 = (6.283185307179586f / float(iConst0));
		fConst4 = (12.566370614359172f / float(iConst0));
		fConst5 = (18.84955592153876f / float(iConst0));
		fConst6 = (25.132741228718345f / float(iConst0));
		fConst7 = (31.41592653589793f / float(iConst0));
		fConst8 = (37.69911184307752f / float(iConst0));
		fConst9 = (43.982297150257104f / float(iConst0));
		fConst10 = (50.26548245743669f / float(iConst0));
		fConst11 = (56.548667764616276f / float(iConst0));
		fConst12 = (62.83185307179586f / float(iConst0));
		fConst13 = (69.11503837897544f / float(iConst0));
		fConst14 = (75.39822368615504f / float(iConst0));
		fConst15 = (81.68140899333463f / float(iConst0));
		fConst16 = (87.96459430051421f / float(iConst0));
		fConst17 = (94.24777960769379f / float(iConst0));
		fConst18 = (100.53096491487338f / float(iConst0));
		fConst19 = (106.81415022205297f / float(iConst0));
		fConst20 = (113.09733552923255f / float(iConst0));
		fConst21 = (119.38052083641213f / float(iConst0));
		fConst22 = (125.66370614359172f / float(iConst0));
		fConst23 = (131.94689145077132f / float(iConst0));
		fConst24 = (138.23007675795088f / float(iConst0));
		fConst25 = (144.51326206513048f / float(iConst0));
		fConst26 = (150.79644737231007f / float(iConst0));
		fConst27 = (157.07963267948966f / float(iConst0));
		fConst28 = (163.36281798666926f / float(iConst0));
		fConst29 = (169.64600329384882f / float(iConst0));
		fConst30 = (175.92918860102841f / float(iConst0));
		fConst31 = (182.212373908208f / float(iConst0));
		fConst32 = (188.49555921538757f / float(iConst0));
		fConst33 = (194.77874452256717f / float(iConst0));
		fConst34 = (201.06192982974676f / float(iConst0));
		fConst35 = (207.34511513692635f / float(iConst0));
		fConst36 = (213.62830044410595f / float(iConst0));
		fConst37 = (219.9114857512855f / float(iConst0));
		fConst38 = (226.1946710584651f / float(iConst0));
		fConst39 = (232.4778563656447f / float(iConst0));
		fConst40 = (238.76104167282426f / float(iConst0));
		fConst41 = (245.04422698000386f / float(iConst0));
		fConst42 = (251.32741228718345f / float(iConst0));
		fConst43 = (257.610597594363f / float(iConst0));
		fConst44 = (263.89378290154264f / float(iConst0));
		fConst45 = (270.1769682087222f / float(iConst0));
		fConst46 = (276.46015351590177f / float(iConst0));
		fConst47 = (282.7433388230814f / float(iConst0));
		fConst48 = (289.02652413026095f / float(iConst0));
		fConst49 = (295.3097094374406f / float(iConst0));
		fConst50 = (301.59289474462014f / float(iConst0));
		fConst51 = (307.8760800517997f / float(iConst0));
		fConst52 = (314.1592653589793f / float(iConst0));
		fConst53 = (320.4424506661589f / float(iConst0));
		fConst54 = (326.7256359733385f / float(iConst0));
		fConst55 = (333.0088212805181f / float(iConst0));
		fConst56 = (339.29200658769764f / float(iConst0));
		fConst57 = (345.57519189487726f / float(iConst0));
		fConst58 = (351.85837720205683f / float(iConst0));
		fConst59 = (358.1415625092364f / float(iConst0));
		fConst60 = (364.424747816416f / float(iConst0));
		fConst61 = (370.7079331235956f / float(iConst0));
		fConst62 = (376.99111843077515f / float(iConst0));
		fConst63 = (383.27430373795477f / float(iConst0));
		fConst64 = (389.55748904513433f / float(iConst0));
		fConst65 = (395.84067435231395f / float(iConst0));
		fConst66 = (402.1238596594935f / float(iConst0));
		fConst67 = (408.4070449666731f / float(iConst0));
		fConst68 = (414.6902302738527f / float(iConst0));
		fConst69 = (420.97341558103227f / float(iConst0));
		fConst70 = (427.2566008882119f / float(iConst0));
		fConst71 = (433.53978619539146f / float(iConst0));
		fConst72 = (439.822971502571f / float(iConst0));
		fConst73 = (446.10615680975064f / float(iConst0));
		fConst74 = (452.3893421169302f / float(iConst0));
		fConst75 = (458.6725274241098f / float(iConst0));
		fConst76 = (464.9557127312894f / float(iConst0));
		fConst77 = (471.23889803846896f / float(iConst0));
		fConst78 = (477.5220833456485f / float(iConst0));
		fConst79 = (483.80526865282815f / float(iConst0));
		fConst80 = (490.0884539600077f / float(iConst0));
		fConst81 = (496.37163926718733f / float(iConst0));
		fConst82 = (502.6548245743669f / float(iConst0));
		fConst83 = (508.93800988154646f / float(iConst0));
		fConst84 = (515.221195188726f / float(iConst0));
		fConst85 = (521.5043804959057f / float(iConst0));
		fConst86 = (527.7875658030853f / float(iConst0));
		fConst87 = (534.0707511102648f / float(iConst0));
		fConst88 = (540.3539364174444f / float(iConst0));
		fConst89 = (546.637121724624f / float(iConst0));
		fConst90 = (552.9203070318035f / float(iConst0));
		fConst91 = (559.2034923389832f / float(iConst0));
		fentry2 = -3.0f;
		fentry3 = -9.0f;
		for (int i=0; i<1024; i++) fYec1[i]=0;
		fYec1_idx = 0;
		fYec1_idx_save = 0;
		fentry4 = 37.0f;
		fConst92 = (1e-006f * iConst0);
		fentry5 = 5e+001f;
		for (int i=0; i<128; i++) fYec2[i]=0;
		fYec2_idx = 0;
		fYec2_idx_save = 0;
		fentry6 = -3.0f;
		for (int i=0; i<256; i++) fYec3[i]=0;
		fYec3_idx = 0;
		fYec3_idx_save = 0;
		for (int i=0; i<1024; i++) fYec4[i]=0;
		fYec4_idx = 0;
		fYec4_idx_save = 0;
		for (int i=0; i<128; i++) fYec5[i]=0;
		fYec5_idx = 0;
		fYec5_idx_save = 0;
	}
	virtual void init(int samplingFreq) {
		classInit(samplingFreq);
		instanceInit(samplingFreq);
	}
	virtual void buildUserInterface(UI* interface) {
		interface->openVerticalBox("adv_xfeed_v3");
		interface->declare(&fentry5, "unit", "%%");
		interface->addNumEntry("Center control (percent)", &fentry5, 5e+001f, 0.0f, 1e+002f, 0.1f);
		interface->declare(&fentry0, "unit", "Hz");
		interface->addNumEntry("Corner frequency (Hz)", &fentry0, 1.5e+003f, 1.5e+002f, 6e+003f, 1e+001f);
		interface->addNumEntry("Filter steepness", &fentry1, 0.75f, 0.01f, 6.0f, 0.01f);
		interface->declare(&fentry6, "unit", "dB");
		interface->addNumEntry("Gain (dB)", &fentry6, -3.0f, -24.0f, 0.0f, 0.1f);
		interface->declare(&fentry3, "unit", "dB");
		interface->addNumEntry("HF feed level (dB)", &fentry3, -9.0f, -48.0f, 0.0f, 0.1f);
		interface->declare(&fentry4, "unit", "us");
		interface->addNumEntry("Inter-aural time delay (us)", &fentry4, 37.0f, 0.0f, 7.5e+002f, 1.0f);
		interface->declare(&fentry2, "unit", "dB");
		interface->addNumEntry("LF feed level (dB)", &fentry2, -3.0f, -48.0f, 0.0f, 0.1f);
		interface->closeBox();
	}
	virtual void compute (int fullcount, FAUSTFLOAT** input, FAUSTFLOAT** output) {
		float 	fZec0[32];
		float 	fZec1[32];
		float 	fZec2[32];
		float 	fZec3[32];
		float 	fSlow0 = fentry0;
		float 	fSlow1 = (fConst1 * fSlow0);
		float 	fSlow2 = (0.0035367765131532297f * sinf((0 - (fConst2 * fSlow0))));
		float 	fSlow3 = fentry1;
		float 	fSlow4 = (3.141592653589793f * fSlow3);
		float 	fSlow5 = faustpower<2>(fSlow4);
		float 	fSlow6 = (1 + (fSlow5 * ((((((((((((((0.25f + (0.0625f * fSlow5)) + (0.006944444444444444f * faustpower<4>(fSlow4))) + (0.00043402777777777775f * faustpower<6>(fSlow4))) + (1.736111111111111e-005f * faustpower<8>(fSlow4))) + (4.822530864197531e-007f * faustpower<10>(fSlow4))) + (9.841899722852104e-009f * faustpower<12>(fSlow4))) + (1.5377968316956413e-010f * faustpower<14>(fSlow4))) + (1.898514607031656e-012f * faustpower<16>(fSlow4))) + (1.898514607031656e-014f * faustpower<18>(fSlow4))) + (1.5690203363897983e-016f * faustpower<20>(fSlow4))) + (1.0895974558262487e-018f * faustpower<22>(fSlow4))) + (6.697330183385451e-020f * faustpower<24>(fSlow4))) + (1.5283966662112614e-019f * faustpower<26>(fSlow4))) + (6.223149226587858e-020f * faustpower<28>(fSlow4)))));
		float 	fSlow7 = min(1.0f, (1.0f / fSlow6));
		float 	fSlow8 = (fSlow7 * min(fSlow1, (0 - fSlow2)));
		float 	fSlow9 = min(fSlow1, fSlow1);
		float 	fSlow10 = (fConst3 * fSlow0);
		float 	fSlow11 = (0.3183098861837907f * sinf((0 - fSlow10)));
		float 	fSlow12 = min(fSlow1, (0 - fSlow11));
		float 	fSlow13 = (0.3183098861837907f * sinf(fSlow10));
		float 	fSlow14 = min(fSlow1, fSlow13);
		float 	fSlow15 = (3.1413987221316257f * fSlow3);
		float 	fSlow16 = faustpower<2>(fSlow15);
		float 	fSlow17 = min(1.0f, ((1 + (fSlow16 * ((((((((((((((0.25f + (0.0625f * fSlow16)) + (0.006944444444444444f * faustpower<4>(fSlow15))) + (0.00043402777777777775f * faustpower<6>(fSlow15))) + (1.736111111111111e-005f * faustpower<8>(fSlow15))) + (4.822530864197531e-007f * faustpower<10>(fSlow15))) + (9.841899722852104e-009f * faustpower<12>(fSlow15))) + (1.5377968316956413e-010f * faustpower<14>(fSlow15))) + (1.898514607031656e-012f * faustpower<16>(fSlow15))) + (1.898514607031656e-014f * faustpower<18>(fSlow15))) + (1.5690203363897983e-016f * faustpower<20>(fSlow15))) + (1.0895974558262487e-018f * faustpower<22>(fSlow15))) + (6.697330183385451e-020f * faustpower<24>(fSlow15))) + (1.5283966662112614e-019f * faustpower<26>(fSlow15))) + (6.223149226587858e-020f * faustpower<28>(fSlow15))))) / fSlow6));
		float 	fSlow18 = (fConst4 * fSlow0);
		float 	fSlow19 = (0.15915494309189535f * sinf((0 - fSlow18)));
		float 	fSlow20 = min(fSlow1, (0 - fSlow19));
		float 	fSlow21 = (0.15915494309189535f * sinf(fSlow18));
		float 	fSlow22 = min(fSlow1, fSlow21);
		float 	fSlow23 = (3.1408168559106993f * fSlow3);
		float 	fSlow24 = faustpower<2>(fSlow23);
		float 	fSlow25 = min(1.0f, ((1 + (fSlow24 * ((((((((((((((0.25f + (0.0625f * fSlow24)) + (0.006944444444444444f * faustpower<4>(fSlow23))) + (0.00043402777777777775f * faustpower<6>(fSlow23))) + (1.736111111111111e-005f * faustpower<8>(fSlow23))) + (4.822530864197531e-007f * faustpower<10>(fSlow23))) + (9.841899722852104e-009f * faustpower<12>(fSlow23))) + (1.5377968316956413e-010f * faustpower<14>(fSlow23))) + (1.898514607031656e-012f * faustpower<16>(fSlow23))) + (1.898514607031656e-014f * faustpower<18>(fSlow23))) + (1.5690203363897983e-016f * faustpower<20>(fSlow23))) + (1.0895974558262487e-018f * faustpower<22>(fSlow23))) + (6.697330183385451e-020f * faustpower<24>(fSlow23))) + (1.5283966662112614e-019f * faustpower<26>(fSlow23))) + (6.223149226587858e-020f * faustpower<28>(fSlow23))))) / fSlow6));
		float 	fSlow26 = (fConst5 * fSlow0);
		float 	fSlow27 = (0.1061032953945969f * sinf((0 - fSlow26)));
		float 	fSlow28 = min(fSlow1, (0 - fSlow27));
		float 	fSlow29 = (0.1061032953945969f * sinf(fSlow26));
		float 	fSlow30 = min(fSlow1, fSlow29);
		float 	fSlow31 = (3.1398468392545897f * fSlow3);
		float 	fSlow32 = faustpower<2>(fSlow31);
		float 	fSlow33 = min(1.0f, ((1 + (fSlow32 * ((((((((((((((0.25f + (0.0625f * fSlow32)) + (0.006944444444444444f * faustpower<4>(fSlow31))) + (0.00043402777777777775f * faustpower<6>(fSlow31))) + (1.736111111111111e-005f * faustpower<8>(fSlow31))) + (4.822530864197531e-007f * faustpower<10>(fSlow31))) + (9.841899722852104e-009f * faustpower<12>(fSlow31))) + (1.5377968316956413e-010f * faustpower<14>(fSlow31))) + (1.898514607031656e-012f * faustpower<16>(fSlow31))) + (1.898514607031656e-014f * faustpower<18>(fSlow31))) + (1.5690203363897983e-016f * faustpower<20>(fSlow31))) + (1.0895974558262487e-018f * faustpower<22>(fSlow31))) + (6.697330183385451e-020f * faustpower<24>(fSlow31))) + (1.5283966662112614e-019f * faustpower<26>(fSlow31))) + (6.223149226587858e-020f * faustpower<28>(fSlow31))))) / fSlow6));
		float 	fSlow34 = (fConst6 * fSlow0);
		float 	fSlow35 = (0.07957747154594767f * sinf((0 - fSlow34)));
		float 	fSlow36 = min(fSlow1, (0 - fSlow35));
		float 	fSlow37 = (0.07957747154594767f * sinf(fSlow34));
		float 	fSlow38 = min(fSlow1, fSlow37);
		float 	fSlow39 = (3.138488312264841f * fSlow3);
		float 	fSlow40 = faustpower<2>(fSlow39);
		float 	fSlow41 = min(1.0f, ((1 + (fSlow40 * ((((((((((((((0.25f + (0.0625f * fSlow40)) + (0.006944444444444444f * faustpower<4>(fSlow39))) + (0.00043402777777777775f * faustpower<6>(fSlow39))) + (1.736111111111111e-005f * faustpower<8>(fSlow39))) + (4.822530864197531e-007f * faustpower<10>(fSlow39))) + (9.841899722852104e-009f * faustpower<12>(fSlow39))) + (1.5377968316956413e-010f * faustpower<14>(fSlow39))) + (1.898514607031656e-012f * faustpower<16>(fSlow39))) + (1.898514607031656e-014f * faustpower<18>(fSlow39))) + (1.5690203363897983e-016f * faustpower<20>(fSlow39))) + (1.0895974558262487e-018f * faustpower<22>(fSlow39))) + (6.697330183385451e-020f * faustpower<24>(fSlow39))) + (1.5283966662112614e-019f * faustpower<26>(fSlow39))) + (6.223149226587858e-020f * faustpower<28>(fSlow39))))) / fSlow6));
		float 	fSlow42 = (fConst7 * fSlow0);
		float 	fSlow43 = (0.06366197723675814f * sinf((0 - fSlow42)));
		float 	fSlow44 = min(fSlow1, (0 - fSlow43));
		float 	fSlow45 = (0.06366197723675814f * sinf(fSlow42));
		float 	fSlow46 = min(fSlow1, fSlow45);
		float 	fSlow47 = (3.136740770148322f * fSlow3);
		float 	fSlow48 = faustpower<2>(fSlow47);
		float 	fSlow49 = min(1.0f, ((1 + (fSlow48 * ((((((((((((((0.25f + (0.0625f * fSlow48)) + (0.006944444444444444f * faustpower<4>(fSlow47))) + (0.00043402777777777775f * faustpower<6>(fSlow47))) + (1.736111111111111e-005f * faustpower<8>(fSlow47))) + (4.822530864197531e-007f * faustpower<10>(fSlow47))) + (9.841899722852104e-009f * faustpower<12>(fSlow47))) + (1.5377968316956413e-010f * faustpower<14>(fSlow47))) + (1.898514607031656e-012f * faustpower<16>(fSlow47))) + (1.898514607031656e-014f * faustpower<18>(fSlow47))) + (1.5690203363897983e-016f * faustpower<20>(fSlow47))) + (1.0895974558262487e-018f * faustpower<22>(fSlow47))) + (6.697330183385451e-020f * faustpower<24>(fSlow47))) + (1.5283966662112614e-019f * faustpower<26>(fSlow47))) + (6.223149226587858e-020f * faustpower<28>(fSlow47))))) / fSlow6));
		float 	fSlow50 = (fConst8 * fSlow0);
		float 	fSlow51 = (0.05305164769729845f * sinf((0 - fSlow50)));
		float 	fSlow52 = min(fSlow1, (0 - fSlow51));
		float 	fSlow53 = (0.05305164769729845f * sinf(fSlow50));
		float 	fSlow54 = min(fSlow1, fSlow53);
		float 	fSlow55 = (3.134603562277066f * fSlow3);
		float 	fSlow56 = faustpower<2>(fSlow55);
		float 	fSlow57 = min(1.0f, ((1 + (fSlow56 * ((((((((((((((0.25f + (0.0625f * fSlow56)) + (0.006944444444444444f * faustpower<4>(fSlow55))) + (0.00043402777777777775f * faustpower<6>(fSlow55))) + (1.736111111111111e-005f * faustpower<8>(fSlow55))) + (4.822530864197531e-007f * faustpower<10>(fSlow55))) + (9.841899722852104e-009f * faustpower<12>(fSlow55))) + (1.5377968316956413e-010f * faustpower<14>(fSlow55))) + (1.898514607031656e-012f * faustpower<16>(fSlow55))) + (1.898514607031656e-014f * faustpower<18>(fSlow55))) + (1.5690203363897983e-016f * faustpower<20>(fSlow55))) + (1.0895974558262487e-018f * faustpower<22>(fSlow55))) + (6.697330183385451e-020f * faustpower<24>(fSlow55))) + (1.5283966662112614e-019f * faustpower<26>(fSlow55))) + (6.223149226587858e-020f * faustpower<28>(fSlow55))))) / fSlow6));
		float 	fSlow58 = (fConst9 * fSlow0);
		float 	fSlow59 = (0.04547284088339867f * sinf((0 - fSlow58)));
		float 	fSlow60 = min(fSlow1, (0 - fSlow59));
		float 	fSlow61 = (0.04547284088339867f * sinf(fSlow58));
		float 	fSlow62 = min(fSlow1, fSlow61);
		float 	fSlow63 = (3.1320758909724975f * fSlow3);
		float 	fSlow64 = faustpower<2>(fSlow63);
		float 	fSlow65 = min(1.0f, ((1 + (fSlow64 * ((((((((((((((0.25f + (0.0625f * fSlow64)) + (0.006944444444444444f * faustpower<4>(fSlow63))) + (0.00043402777777777775f * faustpower<6>(fSlow63))) + (1.736111111111111e-005f * faustpower<8>(fSlow63))) + (4.822530864197531e-007f * faustpower<10>(fSlow63))) + (9.841899722852104e-009f * faustpower<12>(fSlow63))) + (1.5377968316956413e-010f * faustpower<14>(fSlow63))) + (1.898514607031656e-012f * faustpower<16>(fSlow63))) + (1.898514607031656e-014f * faustpower<18>(fSlow63))) + (1.5690203363897983e-016f * faustpower<20>(fSlow63))) + (1.0895974558262487e-018f * faustpower<22>(fSlow63))) + (6.697330183385451e-020f * faustpower<24>(fSlow63))) + (1.5283966662112614e-019f * faustpower<26>(fSlow63))) + (6.223149226587858e-020f * faustpower<28>(fSlow63))))) / fSlow6));
		float 	fSlow66 = (fConst10 * fSlow0);
		float 	fSlow67 = (0.039788735772973836f * sinf((0 - fSlow66)));
		float 	fSlow68 = min(fSlow1, (0 - fSlow67));
		float 	fSlow69 = (0.039788735772973836f * sinf(fSlow66));
		float 	fSlow70 = min(fSlow1, fSlow69);
		float 	fSlow71 = (3.129156810008722f * fSlow3);
		float 	fSlow72 = faustpower<2>(fSlow71);
		float 	fSlow73 = min(1.0f, ((1 + (fSlow72 * ((((((((((((((0.25f + (0.0625f * fSlow72)) + (0.006944444444444444f * faustpower<4>(fSlow71))) + (0.00043402777777777775f * faustpower<6>(fSlow71))) + (1.736111111111111e-005f * faustpower<8>(fSlow71))) + (4.822530864197531e-007f * faustpower<10>(fSlow71))) + (9.841899722852104e-009f * faustpower<12>(fSlow71))) + (1.5377968316956413e-010f * faustpower<14>(fSlow71))) + (1.898514607031656e-012f * faustpower<16>(fSlow71))) + (1.898514607031656e-014f * faustpower<18>(fSlow71))) + (1.5690203363897983e-016f * faustpower<20>(fSlow71))) + (1.0895974558262487e-018f * faustpower<22>(fSlow71))) + (6.697330183385451e-020f * faustpower<24>(fSlow71))) + (1.5283966662112614e-019f * faustpower<26>(fSlow71))) + (6.223149226587858e-020f * faustpower<28>(fSlow71))))) / fSlow6));
		float 	fSlow74 = (fConst11 * fSlow0);
		float 	fSlow75 = (0.0353677651315323f * sinf((0 - fSlow74)));
		float 	fSlow76 = min(fSlow1, (0 - fSlow75));
		float 	fSlow77 = (0.0353677651315323f * sinf(fSlow74));
		float 	fSlow78 = min(fSlow1, fSlow77);
		float 	fSlow79 = (3.1258452228282936f * fSlow3);
		float 	fSlow80 = faustpower<2>(fSlow79);
		float 	fSlow81 = min(1.0f, ((1 + (fSlow80 * ((((((((((((((0.25f + (0.0625f * fSlow80)) + (0.006944444444444444f * faustpower<4>(fSlow79))) + (0.00043402777777777775f * faustpower<6>(fSlow79))) + (1.736111111111111e-005f * faustpower<8>(fSlow79))) + (4.822530864197531e-007f * faustpower<10>(fSlow79))) + (9.841899722852104e-009f * faustpower<12>(fSlow79))) + (1.5377968316956413e-010f * faustpower<14>(fSlow79))) + (1.898514607031656e-012f * faustpower<16>(fSlow79))) + (1.898514607031656e-014f * faustpower<18>(fSlow79))) + (1.5690203363897983e-016f * faustpower<20>(fSlow79))) + (1.0895974558262487e-018f * faustpower<22>(fSlow79))) + (6.697330183385451e-020f * faustpower<24>(fSlow79))) + (1.5283966662112614e-019f * faustpower<26>(fSlow79))) + (6.223149226587858e-020f * faustpower<28>(fSlow79))))) / fSlow6));
		float 	fSlow82 = (fConst12 * fSlow0);
		float 	fSlow83 = (0.03183098861837907f * sinf((0 - fSlow82)));
		float 	fSlow84 = min(fSlow1, (0 - fSlow83));
		float 	fSlow85 = (0.03183098861837907f * sinf(fSlow82));
		float 	fSlow86 = min(fSlow1, fSlow85);
		float 	fSlow87 = (3.122139880462545f * fSlow3);
		float 	fSlow88 = faustpower<2>(fSlow87);
		float 	fSlow89 = min(1.0f, ((1 + (fSlow88 * ((((((((((((((0.25f + (0.0625f * fSlow88)) + (0.006944444444444444f * faustpower<4>(fSlow87))) + (0.00043402777777777775f * faustpower<6>(fSlow87))) + (1.736111111111111e-005f * faustpower<8>(fSlow87))) + (4.822530864197531e-007f * faustpower<10>(fSlow87))) + (9.841899722852104e-009f * faustpower<12>(fSlow87))) + (1.5377968316956413e-010f * faustpower<14>(fSlow87))) + (1.898514607031656e-012f * faustpower<16>(fSlow87))) + (1.898514607031656e-014f * faustpower<18>(fSlow87))) + (1.5690203363897983e-016f * faustpower<20>(fSlow87))) + (1.0895974558262487e-018f * faustpower<22>(fSlow87))) + (6.697330183385451e-020f * faustpower<24>(fSlow87))) + (1.5283966662112614e-019f * faustpower<26>(fSlow87))) + (6.223149226587858e-020f * faustpower<28>(fSlow87))))) / fSlow6));
		float 	fSlow90 = (fConst13 * fSlow0);
		float 	fSlow91 = (0.028937262380344612f * sinf((0 - fSlow90)));
		float 	fSlow92 = min(fSlow1, (0 - fSlow91));
		float 	fSlow93 = (0.028937262380344612f * sinf(fSlow90));
		float 	fSlow94 = min(fSlow1, fSlow93);
		float 	fSlow95 = (3.1180393791471896f * fSlow3);
		float 	fSlow96 = faustpower<2>(fSlow95);
		float 	fSlow97 = min(1.0f, ((1 + (fSlow96 * ((((((((((((((0.25f + (0.0625f * fSlow96)) + (0.006944444444444444f * faustpower<4>(fSlow95))) + (0.00043402777777777775f * faustpower<6>(fSlow95))) + (1.736111111111111e-005f * faustpower<8>(fSlow95))) + (4.822530864197531e-007f * faustpower<10>(fSlow95))) + (9.841899722852104e-009f * faustpower<12>(fSlow95))) + (1.5377968316956413e-010f * faustpower<14>(fSlow95))) + (1.898514607031656e-012f * faustpower<16>(fSlow95))) + (1.898514607031656e-014f * faustpower<18>(fSlow95))) + (1.5690203363897983e-016f * faustpower<20>(fSlow95))) + (1.0895974558262487e-018f * faustpower<22>(fSlow95))) + (6.697330183385451e-020f * faustpower<24>(fSlow95))) + (1.5283966662112614e-019f * faustpower<26>(fSlow95))) + (6.223149226587858e-020f * faustpower<28>(fSlow95))))) / fSlow6));
		float 	fSlow98 = (fConst14 * fSlow0);
		float 	fSlow99 = (0.026525823848649224f * sinf((0 - fSlow98)));
		float 	fSlow100 = min(fSlow1, (0 - fSlow99));
		float 	fSlow101 = (0.026525823848649224f * sinf(fSlow98));
		float 	fSlow102 = min(fSlow1, fSlow101);
		float 	fSlow103 = (3.1135421576224425f * fSlow3);
		float 	fSlow104 = faustpower<2>(fSlow103);
		float 	fSlow105 = min(1.0f, ((1 + (fSlow104 * ((((((((((((((0.25f + (0.0625f * fSlow104)) + (0.006944444444444444f * faustpower<4>(fSlow103))) + (0.00043402777777777775f * faustpower<6>(fSlow103))) + (1.736111111111111e-005f * faustpower<8>(fSlow103))) + (4.822530864197531e-007f * faustpower<10>(fSlow103))) + (9.841899722852104e-009f * faustpower<12>(fSlow103))) + (1.5377968316956413e-010f * faustpower<14>(fSlow103))) + (1.898514607031656e-012f * faustpower<16>(fSlow103))) + (1.898514607031656e-014f * faustpower<18>(fSlow103))) + (1.5690203363897983e-016f * faustpower<20>(fSlow103))) + (1.0895974558262487e-018f * faustpower<22>(fSlow103))) + (6.697330183385451e-020f * faustpower<24>(fSlow103))) + (1.5283966662112614e-019f * faustpower<26>(fSlow103))) + (6.223149226587858e-020f * faustpower<28>(fSlow103))))) / fSlow6));
		float 	fSlow106 = (fConst15 * fSlow0);
		float 	fSlow107 = (0.024485375860291588f * sinf((0 - fSlow106)));
		float 	fSlow108 = min(fSlow1, (0 - fSlow107));
		float 	fSlow109 = (0.024485375860291588f * sinf(fSlow106));
		float 	fSlow110 = min(fSlow1, fSlow109);
		float 	fSlow111 = (3.1086464941053595f * fSlow3);
		float 	fSlow112 = faustpower<2>(fSlow111);
		float 	fSlow113 = min(1.0f, ((1 + (fSlow112 * ((((((((((((((0.25f + (0.0625f * fSlow112)) + (0.006944444444444444f * faustpower<4>(fSlow111))) + (0.00043402777777777775f * faustpower<6>(fSlow111))) + (1.736111111111111e-005f * faustpower<8>(fSlow111))) + (4.822530864197531e-007f * faustpower<10>(fSlow111))) + (9.841899722852104e-009f * faustpower<12>(fSlow111))) + (1.5377968316956413e-010f * faustpower<14>(fSlow111))) + (1.898514607031656e-012f * faustpower<16>(fSlow111))) + (1.898514607031656e-014f * faustpower<18>(fSlow111))) + (1.5690203363897983e-016f * faustpower<20>(fSlow111))) + (1.0895974558262487e-018f * faustpower<22>(fSlow111))) + (6.697330183385451e-020f * faustpower<24>(fSlow111))) + (1.5283966662112614e-019f * faustpower<26>(fSlow111))) + (6.223149226587858e-020f * faustpower<28>(fSlow111))))) / fSlow6));
		float 	fSlow114 = (fConst16 * fSlow0);
		float 	fSlow115 = (0.022736420441699334f * sinf((0 - fSlow114)));
		float 	fSlow116 = min(fSlow1, (0 - fSlow115));
		float 	fSlow117 = (0.022736420441699334f * sinf(fSlow114));
		float 	fSlow118 = min(fSlow1, fSlow117);
		float 	fSlow119 = (3.103350502920445f * fSlow3);
		float 	fSlow120 = faustpower<2>(fSlow119);
		float 	fSlow121 = min(1.0f, ((1 + (fSlow120 * ((((((((((((((0.25f + (0.0625f * fSlow120)) + (0.006944444444444444f * faustpower<4>(fSlow119))) + (0.00043402777777777775f * faustpower<6>(fSlow119))) + (1.736111111111111e-005f * faustpower<8>(fSlow119))) + (4.822530864197531e-007f * faustpower<10>(fSlow119))) + (9.841899722852104e-009f * faustpower<12>(fSlow119))) + (1.5377968316956413e-010f * faustpower<14>(fSlow119))) + (1.898514607031656e-012f * faustpower<16>(fSlow119))) + (1.898514607031656e-014f * faustpower<18>(fSlow119))) + (1.5690203363897983e-016f * faustpower<20>(fSlow119))) + (1.0895974558262487e-018f * faustpower<22>(fSlow119))) + (6.697330183385451e-020f * faustpower<24>(fSlow119))) + (1.5283966662112614e-019f * faustpower<26>(fSlow119))) + (6.223149226587858e-020f * faustpower<28>(fSlow119))))) / fSlow6));
		float 	fSlow122 = (fConst17 * fSlow0);
		float 	fSlow123 = (0.02122065907891938f * sinf((0 - fSlow122)));
		float 	fSlow124 = min(fSlow1, (0 - fSlow123));
		float 	fSlow125 = (0.02122065907891938f * sinf(fSlow122));
		float 	fSlow126 = min(fSlow1, fSlow125);
		float 	fSlow127 = (3.0976521307728087f * fSlow3);
		float 	fSlow128 = faustpower<2>(fSlow127);
		float 	fSlow129 = min(1.0f, ((1 + (fSlow128 * ((((((((((((((0.25f + (0.0625f * fSlow128)) + (0.006944444444444444f * faustpower<4>(fSlow127))) + (0.00043402777777777775f * faustpower<6>(fSlow127))) + (1.736111111111111e-005f * faustpower<8>(fSlow127))) + (4.822530864197531e-007f * faustpower<10>(fSlow127))) + (9.841899722852104e-009f * faustpower<12>(fSlow127))) + (1.5377968316956413e-010f * faustpower<14>(fSlow127))) + (1.898514607031656e-012f * faustpower<16>(fSlow127))) + (1.898514607031656e-014f * faustpower<18>(fSlow127))) + (1.5690203363897983e-016f * faustpower<20>(fSlow127))) + (1.0895974558262487e-018f * faustpower<22>(fSlow127))) + (6.697330183385451e-020f * faustpower<24>(fSlow127))) + (1.5283966662112614e-019f * faustpower<26>(fSlow127))) + (6.223149226587858e-020f * faustpower<28>(fSlow127))))) / fSlow6));
		float 	fSlow130 = (fConst18 * fSlow0);
		float 	fSlow131 = (0.019894367886486918f * sinf((0 - fSlow130)));
		float 	fSlow132 = min(fSlow1, (0 - fSlow131));
		float 	fSlow133 = (0.019894367886486918f * sinf(fSlow130));
		float 	fSlow134 = min(fSlow1, fSlow133);
		float 	fSlow135 = (3.0915491526462535f * fSlow3);
		float 	fSlow136 = faustpower<2>(fSlow135);
		float 	fSlow137 = min(1.0f, ((1 + (fSlow136 * ((((((((((((((0.25f + (0.0625f * fSlow136)) + (0.006944444444444444f * faustpower<4>(fSlow135))) + (0.00043402777777777775f * faustpower<6>(fSlow135))) + (1.736111111111111e-005f * faustpower<8>(fSlow135))) + (4.822530864197531e-007f * faustpower<10>(fSlow135))) + (9.841899722852104e-009f * faustpower<12>(fSlow135))) + (1.5377968316956413e-010f * faustpower<14>(fSlow135))) + (1.898514607031656e-012f * faustpower<16>(fSlow135))) + (1.898514607031656e-014f * faustpower<18>(fSlow135))) + (1.5690203363897983e-016f * faustpower<20>(fSlow135))) + (1.0895974558262487e-018f * faustpower<22>(fSlow135))) + (6.697330183385451e-020f * faustpower<24>(fSlow135))) + (1.5283966662112614e-019f * faustpower<26>(fSlow135))) + (6.223149226587858e-020f * faustpower<28>(fSlow135))))) / fSlow6));
		float 	fSlow138 = (fConst19 * fSlow0);
		float 	fSlow139 = (0.018724110951987685f * sinf((0 - fSlow138)));
		float 	fSlow140 = min(fSlow1, (0 - fSlow139));
		float 	fSlow141 = (0.018724110951987685f * sinf(fSlow138));
		float 	fSlow142 = min(fSlow1, fSlow141);
		float 	fSlow143 = (3.0850391673066198f * fSlow3);
		float 	fSlow144 = faustpower<2>(fSlow143);
		float 	fSlow145 = min(1.0f, ((1 + (fSlow144 * ((((((((((((((0.25f + (0.0625f * fSlow144)) + (0.006944444444444444f * faustpower<4>(fSlow143))) + (0.00043402777777777775f * faustpower<6>(fSlow143))) + (1.736111111111111e-005f * faustpower<8>(fSlow143))) + (4.822530864197531e-007f * faustpower<10>(fSlow143))) + (9.841899722852104e-009f * faustpower<12>(fSlow143))) + (1.5377968316956413e-010f * faustpower<14>(fSlow143))) + (1.898514607031656e-012f * faustpower<16>(fSlow143))) + (1.898514607031656e-014f * faustpower<18>(fSlow143))) + (1.5690203363897983e-016f * faustpower<20>(fSlow143))) + (1.0895974558262487e-018f * faustpower<22>(fSlow143))) + (6.697330183385451e-020f * faustpower<24>(fSlow143))) + (1.5283966662112614e-019f * faustpower<26>(fSlow143))) + (6.223149226587858e-020f * faustpower<28>(fSlow143))))) / fSlow6));
		float 	fSlow146 = (fConst20 * fSlow0);
		float 	fSlow147 = (0.01768388256576615f * sinf((0 - fSlow146)));
		float 	fSlow148 = min(fSlow1, (0 - fSlow147));
		float 	fSlow149 = (0.01768388256576615f * sinf(fSlow146));
		float 	fSlow150 = min(fSlow1, fSlow149);
		float 	fSlow151 = (3.0781195923884734f * fSlow3);
		float 	fSlow152 = faustpower<2>(fSlow151);
		float 	fSlow153 = min(1.0f, ((1 + (fSlow152 * ((((((((((((((0.25f + (0.0625f * fSlow152)) + (0.006944444444444444f * faustpower<4>(fSlow151))) + (0.00043402777777777775f * faustpower<6>(fSlow151))) + (1.736111111111111e-005f * faustpower<8>(fSlow151))) + (4.822530864197531e-007f * faustpower<10>(fSlow151))) + (9.841899722852104e-009f * faustpower<12>(fSlow151))) + (1.5377968316956413e-010f * faustpower<14>(fSlow151))) + (1.898514607031656e-012f * faustpower<16>(fSlow151))) + (1.898514607031656e-014f * faustpower<18>(fSlow151))) + (1.5690203363897983e-016f * faustpower<20>(fSlow151))) + (1.0895974558262487e-018f * faustpower<22>(fSlow151))) + (6.697330183385451e-020f * faustpower<24>(fSlow151))) + (1.5283966662112614e-019f * faustpower<26>(fSlow151))) + (6.223149226587858e-020f * faustpower<28>(fSlow151))))) / fSlow6));
		float 	fSlow154 = (fConst21 * fSlow0);
		float 	fSlow155 = (0.016753151904410037f * sinf((0 - fSlow154)));
		float 	fSlow156 = min(fSlow1, (0 - fSlow155));
		float 	fSlow157 = (0.016753151904410037f * sinf(fSlow154));
		float 	fSlow158 = min(fSlow1, fSlow157);
		float 	fSlow159 = (3.070787659040812f * fSlow3);
		float 	fSlow160 = faustpower<2>(fSlow159);
		float 	fSlow161 = min(1.0f, ((1 + (fSlow160 * ((((((((((((((0.25f + (0.0625f * fSlow160)) + (0.006944444444444444f * faustpower<4>(fSlow159))) + (0.00043402777777777775f * faustpower<6>(fSlow159))) + (1.736111111111111e-005f * faustpower<8>(fSlow159))) + (4.822530864197531e-007f * faustpower<10>(fSlow159))) + (9.841899722852104e-009f * faustpower<12>(fSlow159))) + (1.5377968316956413e-010f * faustpower<14>(fSlow159))) + (1.898514607031656e-012f * faustpower<16>(fSlow159))) + (1.898514607031656e-014f * faustpower<18>(fSlow159))) + (1.5690203363897983e-016f * faustpower<20>(fSlow159))) + (1.0895974558262487e-018f * faustpower<22>(fSlow159))) + (6.697330183385451e-020f * faustpower<24>(fSlow159))) + (1.5283966662112614e-019f * faustpower<26>(fSlow159))) + (6.223149226587858e-020f * faustpower<28>(fSlow159))))) / fSlow6));
		float 	fSlow162 = (fConst22 * fSlow0);
		float 	fSlow163 = (0.015915494309189534f * sinf((0 - fSlow162)));
		float 	fSlow164 = min(fSlow1, (0 - fSlow163));
		float 	fSlow165 = (0.015915494309189534f * sinf(fSlow162));
		float 	fSlow166 = min(fSlow1, fSlow165);
		float 	fSlow167 = (3.0630404061047947f * fSlow3);
		float 	fSlow168 = faustpower<2>(fSlow167);
		float 	fSlow169 = min(1.0f, ((1 + (fSlow168 * ((((((((((((((0.25f + (0.0625f * fSlow168)) + (0.006944444444444444f * faustpower<4>(fSlow167))) + (0.00043402777777777775f * faustpower<6>(fSlow167))) + (1.736111111111111e-005f * faustpower<8>(fSlow167))) + (4.822530864197531e-007f * faustpower<10>(fSlow167))) + (9.841899722852104e-009f * faustpower<12>(fSlow167))) + (1.5377968316956413e-010f * faustpower<14>(fSlow167))) + (1.898514607031656e-012f * faustpower<16>(fSlow167))) + (1.898514607031656e-014f * faustpower<18>(fSlow167))) + (1.5690203363897983e-016f * faustpower<20>(fSlow167))) + (1.0895974558262487e-018f * faustpower<22>(fSlow167))) + (6.697330183385451e-020f * faustpower<24>(fSlow167))) + (1.5283966662112614e-019f * faustpower<26>(fSlow167))) + (6.223149226587858e-020f * faustpower<28>(fSlow167))))) / fSlow6));
		float 	fSlow170 = (fConst23 * fSlow0);
		float 	fSlow171 = (0.015157613627799556f * sinf((0 - fSlow170)));
		float 	fSlow172 = min(fSlow1, (0 - fSlow171));
		float 	fSlow173 = (0.015157613627799556f * sinf(fSlow170));
		float 	fSlow174 = min(fSlow1, fSlow173);
		float 	fSlow175 = (3.054874673793608f * fSlow3);
		float 	fSlow176 = faustpower<2>(fSlow175);
		float 	fSlow177 = min(1.0f, ((1 + (fSlow176 * ((((((((((((((0.25f + (0.0625f * fSlow176)) + (0.006944444444444444f * faustpower<4>(fSlow175))) + (0.00043402777777777775f * faustpower<6>(fSlow175))) + (1.736111111111111e-005f * faustpower<8>(fSlow175))) + (4.822530864197531e-007f * faustpower<10>(fSlow175))) + (9.841899722852104e-009f * faustpower<12>(fSlow175))) + (1.5377968316956413e-010f * faustpower<14>(fSlow175))) + (1.898514607031656e-012f * faustpower<16>(fSlow175))) + (1.898514607031656e-014f * faustpower<18>(fSlow175))) + (1.5690203363897983e-016f * faustpower<20>(fSlow175))) + (1.0895974558262487e-018f * faustpower<22>(fSlow175))) + (6.697330183385451e-020f * faustpower<24>(fSlow175))) + (1.5283966662112614e-019f * faustpower<26>(fSlow175))) + (6.223149226587858e-020f * faustpower<28>(fSlow175))))) / fSlow6));
		float 	fSlow178 = (fConst24 * fSlow0);
		float 	fSlow179 = (0.014468631190172306f * sinf((0 - fSlow178)));
		float 	fSlow180 = min(fSlow1, (0 - fSlow179));
		float 	fSlow181 = (0.014468631190172306f * sinf(fSlow178));
		float 	fSlow182 = min(fSlow1, fSlow181);
		float 	fSlow183 = (3.046287096841381f * fSlow3);
		float 	fSlow184 = faustpower<2>(fSlow183);
		float 	fSlow185 = min(1.0f, ((1 + (fSlow184 * ((((((((((((((0.25f + (0.0625f * fSlow184)) + (0.006944444444444444f * faustpower<4>(fSlow183))) + (0.00043402777777777775f * faustpower<6>(fSlow183))) + (1.736111111111111e-005f * faustpower<8>(fSlow183))) + (4.822530864197531e-007f * faustpower<10>(fSlow183))) + (9.841899722852104e-009f * faustpower<12>(fSlow183))) + (1.5377968316956413e-010f * faustpower<14>(fSlow183))) + (1.898514607031656e-012f * faustpower<16>(fSlow183))) + (1.898514607031656e-014f * faustpower<18>(fSlow183))) + (1.5690203363897983e-016f * faustpower<20>(fSlow183))) + (1.0895974558262487e-018f * faustpower<22>(fSlow183))) + (6.697330183385451e-020f * faustpower<24>(fSlow183))) + (1.5283966662112614e-019f * faustpower<26>(fSlow183))) + (6.223149226587858e-020f * faustpower<28>(fSlow183))))) / fSlow6));
		float 	fSlow186 = (fConst25 * fSlow0);
		float 	fSlow187 = (0.013839560268860466f * sinf((0 - fSlow186)));
		float 	fSlow188 = min(fSlow1, (0 - fSlow187));
		float 	fSlow189 = (0.013839560268860466f * sinf(fSlow186));
		float 	fSlow190 = min(fSlow1, fSlow189);
		float 	fSlow191 = (3.0372740970845356f * fSlow3);
		float 	fSlow192 = faustpower<2>(fSlow191);
		float 	fSlow193 = min(1.0f, ((1 + (fSlow192 * ((((((((((((((0.25f + (0.0625f * fSlow192)) + (0.006944444444444444f * faustpower<4>(fSlow191))) + (0.00043402777777777775f * faustpower<6>(fSlow191))) + (1.736111111111111e-005f * faustpower<8>(fSlow191))) + (4.822530864197531e-007f * faustpower<10>(fSlow191))) + (9.841899722852104e-009f * faustpower<12>(fSlow191))) + (1.5377968316956413e-010f * faustpower<14>(fSlow191))) + (1.898514607031656e-012f * faustpower<16>(fSlow191))) + (1.898514607031656e-014f * faustpower<18>(fSlow191))) + (1.5690203363897983e-016f * faustpower<20>(fSlow191))) + (1.0895974558262487e-018f * faustpower<22>(fSlow191))) + (6.697330183385451e-020f * faustpower<24>(fSlow191))) + (1.5283966662112614e-019f * faustpower<26>(fSlow191))) + (6.223149226587858e-020f * faustpower<28>(fSlow191))))) / fSlow6));
		float 	fSlow194 = (fConst26 * fSlow0);
		float 	fSlow195 = (0.013262911924324612f * sinf((0 - fSlow194)));
		float 	fSlow196 = min(fSlow1, (0 - fSlow195));
		float 	fSlow197 = (0.013262911924324612f * sinf(fSlow194));
		float 	fSlow198 = min(fSlow1, fSlow197);
		float 	fSlow199 = (3.027831875435091f * fSlow3);
		float 	fSlow200 = faustpower<2>(fSlow199);
		float 	fSlow201 = min(1.0f, ((1 + (fSlow200 * ((((((((((((((0.25f + (0.0625f * fSlow200)) + (0.006944444444444444f * faustpower<4>(fSlow199))) + (0.00043402777777777775f * faustpower<6>(fSlow199))) + (1.736111111111111e-005f * faustpower<8>(fSlow199))) + (4.822530864197531e-007f * faustpower<10>(fSlow199))) + (9.841899722852104e-009f * faustpower<12>(fSlow199))) + (1.5377968316956413e-010f * faustpower<14>(fSlow199))) + (1.898514607031656e-012f * faustpower<16>(fSlow199))) + (1.898514607031656e-014f * faustpower<18>(fSlow199))) + (1.5690203363897983e-016f * faustpower<20>(fSlow199))) + (1.0895974558262487e-018f * faustpower<22>(fSlow199))) + (6.697330183385451e-020f * faustpower<24>(fSlow199))) + (1.5283966662112614e-019f * faustpower<26>(fSlow199))) + (6.223149226587858e-020f * faustpower<28>(fSlow199))))) / fSlow6));
		float 	fSlow202 = (fConst27 * fSlow0);
		float 	fSlow203 = (0.012732395447351627f * sinf((0 - fSlow202)));
		float 	fSlow204 = min(fSlow1, (0 - fSlow203));
		float 	fSlow205 = (0.012732395447351627f * sinf(fSlow202));
		float 	fSlow206 = min(fSlow1, fSlow205);
		float 	fSlow207 = (3.017956403201111f * fSlow3);
		float 	fSlow208 = faustpower<2>(fSlow207);
		float 	fSlow209 = min(1.0f, ((1 + (fSlow208 * ((((((((((((((0.25f + (0.0625f * fSlow208)) + (0.006944444444444444f * faustpower<4>(fSlow207))) + (0.00043402777777777775f * faustpower<6>(fSlow207))) + (1.736111111111111e-005f * faustpower<8>(fSlow207))) + (4.822530864197531e-007f * faustpower<10>(fSlow207))) + (9.841899722852104e-009f * faustpower<12>(fSlow207))) + (1.5377968316956413e-010f * faustpower<14>(fSlow207))) + (1.898514607031656e-012f * faustpower<16>(fSlow207))) + (1.898514607031656e-014f * faustpower<18>(fSlow207))) + (1.5690203363897983e-016f * faustpower<20>(fSlow207))) + (1.0895974558262487e-018f * faustpower<22>(fSlow207))) + (6.697330183385451e-020f * faustpower<24>(fSlow207))) + (1.5283966662112614e-019f * faustpower<26>(fSlow207))) + (6.223149226587858e-020f * faustpower<28>(fSlow207))))) / fSlow6));
		float 	fSlow210 = (fConst28 * fSlow0);
		float 	fSlow211 = (0.012242687930145794f * sinf((0 - fSlow210)));
		float 	fSlow212 = min(fSlow1, (0 - fSlow211));
		float 	fSlow213 = (0.012242687930145794f * sinf(fSlow210));
		float 	fSlow214 = min(fSlow1, fSlow213);
		float 	fSlow215 = (3.0076434127047205f * fSlow3);
		float 	fSlow216 = faustpower<2>(fSlow215);
		float 	fSlow217 = min(1.0f, ((1 + (fSlow216 * ((((((((((((((0.25f + (0.0625f * fSlow216)) + (0.006944444444444444f * faustpower<4>(fSlow215))) + (0.00043402777777777775f * faustpower<6>(fSlow215))) + (1.736111111111111e-005f * faustpower<8>(fSlow215))) + (4.822530864197531e-007f * faustpower<10>(fSlow215))) + (9.841899722852104e-009f * faustpower<12>(fSlow215))) + (1.5377968316956413e-010f * faustpower<14>(fSlow215))) + (1.898514607031656e-012f * faustpower<16>(fSlow215))) + (1.898514607031656e-014f * faustpower<18>(fSlow215))) + (1.5690203363897983e-016f * faustpower<20>(fSlow215))) + (1.0895974558262487e-018f * faustpower<22>(fSlow215))) + (6.697330183385451e-020f * faustpower<24>(fSlow215))) + (1.5283966662112614e-019f * faustpower<26>(fSlow215))) + (6.223149226587858e-020f * faustpower<28>(fSlow215))))) / fSlow6));
		float 	fSlow218 = (fConst29 * fSlow0);
		float 	fSlow219 = (0.0117892550438441f * sinf((0 - fSlow218)));
		float 	fSlow220 = min(fSlow1, (0 - fSlow219));
		float 	fSlow221 = (0.0117892550438441f * sinf(fSlow218));
		float 	fSlow222 = min(fSlow1, fSlow221);
		float 	fSlow223 = (2.9968883871427905f * fSlow3);
		float 	fSlow224 = faustpower<2>(fSlow223);
		float 	fSlow225 = min(1.0f, ((1 + (fSlow224 * ((((((((((((((0.25f + (0.0625f * fSlow224)) + (0.006944444444444444f * faustpower<4>(fSlow223))) + (0.00043402777777777775f * faustpower<6>(fSlow223))) + (1.736111111111111e-005f * faustpower<8>(fSlow223))) + (4.822530864197531e-007f * faustpower<10>(fSlow223))) + (9.841899722852104e-009f * faustpower<12>(fSlow223))) + (1.5377968316956413e-010f * faustpower<14>(fSlow223))) + (1.898514607031656e-012f * faustpower<16>(fSlow223))) + (1.898514607031656e-014f * faustpower<18>(fSlow223))) + (1.5690203363897983e-016f * faustpower<20>(fSlow223))) + (1.0895974558262487e-018f * faustpower<22>(fSlow223))) + (6.697330183385451e-020f * faustpower<24>(fSlow223))) + (1.5283966662112614e-019f * faustpower<26>(fSlow223))) + (6.223149226587858e-020f * faustpower<28>(fSlow223))))) / fSlow6));
		float 	fSlow226 = (fConst30 * fSlow0);
		float 	fSlow227 = (0.011368210220849667f * sinf((0 - fSlow226)));
		float 	fSlow228 = min(fSlow1, (0 - fSlow227));
		float 	fSlow229 = (0.011368210220849667f * sinf(fSlow226));
		float 	fSlow230 = min(fSlow1, fSlow229);
		float 	fSlow231 = (2.9856865496294547f * fSlow3);
		float 	fSlow232 = faustpower<2>(fSlow231);
		float 	fSlow233 = min(1.0f, ((1 + (fSlow232 * ((((((((((((((0.25f + (0.0625f * fSlow232)) + (0.006944444444444444f * faustpower<4>(fSlow231))) + (0.00043402777777777775f * faustpower<6>(fSlow231))) + (1.736111111111111e-005f * faustpower<8>(fSlow231))) + (4.822530864197531e-007f * faustpower<10>(fSlow231))) + (9.841899722852104e-009f * faustpower<12>(fSlow231))) + (1.5377968316956413e-010f * faustpower<14>(fSlow231))) + (1.898514607031656e-012f * faustpower<16>(fSlow231))) + (1.898514607031656e-014f * faustpower<18>(fSlow231))) + (1.5690203363897983e-016f * faustpower<20>(fSlow231))) + (1.0895974558262487e-018f * faustpower<22>(fSlow231))) + (6.697330183385451e-020f * faustpower<24>(fSlow231))) + (1.5283966662112614e-019f * faustpower<26>(fSlow231))) + (6.223149226587858e-020f * faustpower<28>(fSlow231))))) / fSlow6));
		float 	fSlow234 = (fConst31 * fSlow0);
		float 	fSlow235 = (0.010976202971854851f * sinf((0 - fSlow234)));
		float 	fSlow236 = min(fSlow1, (0 - fSlow235));
		float 	fSlow237 = (0.010976202971854851f * sinf(fSlow234));
		float 	fSlow238 = min(fSlow1, fSlow237);
		float 	fSlow239 = (2.974032851353002f * fSlow3);
		float 	fSlow240 = faustpower<2>(fSlow239);
		float 	fSlow241 = min(1.0f, ((1 + (fSlow240 * ((((((((((((((0.25f + (0.0625f * fSlow240)) + (0.006944444444444444f * faustpower<4>(fSlow239))) + (0.00043402777777777775f * faustpower<6>(fSlow239))) + (1.736111111111111e-005f * faustpower<8>(fSlow239))) + (4.822530864197531e-007f * faustpower<10>(fSlow239))) + (9.841899722852104e-009f * faustpower<12>(fSlow239))) + (1.5377968316956413e-010f * faustpower<14>(fSlow239))) + (1.898514607031656e-012f * faustpower<16>(fSlow239))) + (1.898514607031656e-014f * faustpower<18>(fSlow239))) + (1.5690203363897983e-016f * faustpower<20>(fSlow239))) + (1.0895974558262487e-018f * faustpower<22>(fSlow239))) + (6.697330183385451e-020f * faustpower<24>(fSlow239))) + (1.5283966662112614e-019f * faustpower<26>(fSlow239))) + (6.223149226587858e-020f * faustpower<28>(fSlow239))))) / fSlow6));
		float 	fSlow242 = (fConst32 * fSlow0);
		float 	fSlow243 = (0.01061032953945969f * sinf((0 - fSlow242)));
		float 	fSlow244 = min(fSlow1, (0 - fSlow243));
		float 	fSlow245 = (0.01061032953945969f * sinf(fSlow242));
		float 	fSlow246 = min(fSlow1, fSlow245);
		float 	fSlow247 = (2.961921958772244f * fSlow3);
		float 	fSlow248 = faustpower<2>(fSlow247);
		float 	fSlow249 = min(1.0f, ((1 + (fSlow248 * ((((((((((((((0.25f + (0.0625f * fSlow248)) + (0.006944444444444444f * faustpower<4>(fSlow247))) + (0.00043402777777777775f * faustpower<6>(fSlow247))) + (1.736111111111111e-005f * faustpower<8>(fSlow247))) + (4.822530864197531e-007f * faustpower<10>(fSlow247))) + (9.841899722852104e-009f * faustpower<12>(fSlow247))) + (1.5377968316956413e-010f * faustpower<14>(fSlow247))) + (1.898514607031656e-012f * faustpower<16>(fSlow247))) + (1.898514607031656e-014f * faustpower<18>(fSlow247))) + (1.5690203363897983e-016f * faustpower<20>(fSlow247))) + (1.0895974558262487e-018f * faustpower<22>(fSlow247))) + (6.697330183385451e-020f * faustpower<24>(fSlow247))) + (1.5283966662112614e-019f * faustpower<26>(fSlow247))) + (6.223149226587858e-020f * faustpower<28>(fSlow247))))) / fSlow6));
		float 	fSlow250 = (fConst33 * fSlow0);
		float 	fSlow251 = (0.01026806084463841f * sinf((0 - fSlow250)));
		float 	fSlow252 = min(fSlow1, (0 - fSlow251));
		float 	fSlow253 = (0.01026806084463841f * sinf(fSlow250));
		float 	fSlow254 = min(fSlow1, fSlow253);
		float 	fSlow255 = (2.9493482397691277f * fSlow3);
		float 	fSlow256 = faustpower<2>(fSlow255);
		float 	fSlow257 = min(1.0f, ((1 + (fSlow256 * ((((((((((((((0.25f + (0.0625f * fSlow256)) + (0.006944444444444444f * faustpower<4>(fSlow255))) + (0.00043402777777777775f * faustpower<6>(fSlow255))) + (1.736111111111111e-005f * faustpower<8>(fSlow255))) + (4.822530864197531e-007f * faustpower<10>(fSlow255))) + (9.841899722852104e-009f * faustpower<12>(fSlow255))) + (1.5377968316956413e-010f * faustpower<14>(fSlow255))) + (1.898514607031656e-012f * faustpower<16>(fSlow255))) + (1.898514607031656e-014f * faustpower<18>(fSlow255))) + (1.5690203363897983e-016f * faustpower<20>(fSlow255))) + (1.0895974558262487e-018f * faustpower<22>(fSlow255))) + (6.697330183385451e-020f * faustpower<24>(fSlow255))) + (1.5283966662112614e-019f * faustpower<26>(fSlow255))) + (6.223149226587858e-020f * faustpower<28>(fSlow255))))) / fSlow6));
		float 	fSlow258 = (fConst34 * fSlow0);
		float 	fSlow259 = (0.009947183943243459f * sinf((0 - fSlow258)));
		float 	fSlow260 = min(fSlow1, (0 - fSlow259));
		float 	fSlow261 = (0.009947183943243459f * sinf(fSlow258));
		float 	fSlow262 = min(fSlow1, fSlow261);
		float 	fSlow263 = (2.9363057486649784f * fSlow3);
		float 	fSlow264 = faustpower<2>(fSlow263);
		float 	fSlow265 = min(1.0f, ((1 + (fSlow264 * ((((((((((((((0.25f + (0.0625f * fSlow264)) + (0.006944444444444444f * faustpower<4>(fSlow263))) + (0.00043402777777777775f * faustpower<6>(fSlow263))) + (1.736111111111111e-005f * faustpower<8>(fSlow263))) + (4.822530864197531e-007f * faustpower<10>(fSlow263))) + (9.841899722852104e-009f * faustpower<12>(fSlow263))) + (1.5377968316956413e-010f * faustpower<14>(fSlow263))) + (1.898514607031656e-012f * faustpower<16>(fSlow263))) + (1.898514607031656e-014f * faustpower<18>(fSlow263))) + (1.5690203363897983e-016f * faustpower<20>(fSlow263))) + (1.0895974558262487e-018f * faustpower<22>(fSlow263))) + (6.697330183385451e-020f * faustpower<24>(fSlow263))) + (1.5283966662112614e-019f * faustpower<26>(fSlow263))) + (6.223149226587858e-020f * faustpower<28>(fSlow263))))) / fSlow6));
		float 	fSlow266 = (fConst35 * fSlow0);
		float 	fSlow267 = (0.009645754126781536f * sinf((0 - fSlow266)));
		float 	fSlow268 = min(fSlow1, (0 - fSlow267));
		float 	fSlow269 = (0.009645754126781536f * sinf(fSlow266));
		float 	fSlow270 = min(fSlow1, fSlow269);
		float 	fSlow271 = (2.922788209997169f * fSlow3);
		float 	fSlow272 = faustpower<2>(fSlow271);
		float 	fSlow273 = min(1.0f, ((1 + (fSlow272 * ((((((((((((((0.25f + (0.0625f * fSlow272)) + (0.006944444444444444f * faustpower<4>(fSlow271))) + (0.00043402777777777775f * faustpower<6>(fSlow271))) + (1.736111111111111e-005f * faustpower<8>(fSlow271))) + (4.822530864197531e-007f * faustpower<10>(fSlow271))) + (9.841899722852104e-009f * faustpower<12>(fSlow271))) + (1.5377968316956413e-010f * faustpower<14>(fSlow271))) + (1.898514607031656e-012f * faustpower<16>(fSlow271))) + (1.898514607031656e-014f * faustpower<18>(fSlow271))) + (1.5690203363897983e-016f * faustpower<20>(fSlow271))) + (1.0895974558262487e-018f * faustpower<22>(fSlow271))) + (6.697330183385451e-020f * faustpower<24>(fSlow271))) + (1.5283966662112614e-019f * faustpower<26>(fSlow271))) + (6.223149226587858e-020f * faustpower<28>(fSlow271))))) / fSlow6));
		float 	fSlow274 = (fConst36 * fSlow0);
		float 	fSlow275 = (0.009362055475993843f * sinf((0 - fSlow274)));
		float 	fSlow276 = min(fSlow1, (0 - fSlow275));
		float 	fSlow277 = (0.009362055475993843f * sinf(fSlow274));
		float 	fSlow278 = min(fSlow1, fSlow277);
		float 	fSlow279 = (2.9087890009410478f * fSlow3);
		float 	fSlow280 = faustpower<2>(fSlow279);
		float 	fSlow281 = min(1.0f, ((1 + (fSlow280 * ((((((((((((((0.25f + (0.0625f * fSlow280)) + (0.006944444444444444f * faustpower<4>(fSlow279))) + (0.00043402777777777775f * faustpower<6>(fSlow279))) + (1.736111111111111e-005f * faustpower<8>(fSlow279))) + (4.822530864197531e-007f * faustpower<10>(fSlow279))) + (9.841899722852104e-009f * faustpower<12>(fSlow279))) + (1.5377968316956413e-010f * faustpower<14>(fSlow279))) + (1.898514607031656e-012f * faustpower<16>(fSlow279))) + (1.898514607031656e-014f * faustpower<18>(fSlow279))) + (1.5690203363897983e-016f * faustpower<20>(fSlow279))) + (1.0895974558262487e-018f * faustpower<22>(fSlow279))) + (6.697330183385451e-020f * faustpower<24>(fSlow279))) + (1.5283966662112614e-019f * faustpower<26>(fSlow279))) + (6.223149226587858e-020f * faustpower<28>(fSlow279))))) / fSlow6));
		float 	fSlow282 = (fConst37 * fSlow0);
		float 	fSlow283 = (0.009094568176679734f * sinf((0 - fSlow282)));
		float 	fSlow284 = min(fSlow1, (0 - fSlow283));
		float 	fSlow285 = (0.009094568176679734f * sinf(fSlow282));
		float 	fSlow286 = min(fSlow1, fSlow285);
		float 	fSlow287 = (2.8943011322484202f * fSlow3);
		float 	fSlow288 = faustpower<2>(fSlow287);
		float 	fSlow289 = min(1.0f, ((1 + (fSlow288 * ((((((((((((((0.25f + (0.0625f * fSlow288)) + (0.006944444444444444f * faustpower<4>(fSlow287))) + (0.00043402777777777775f * faustpower<6>(fSlow287))) + (1.736111111111111e-005f * faustpower<8>(fSlow287))) + (4.822530864197531e-007f * faustpower<10>(fSlow287))) + (9.841899722852104e-009f * faustpower<12>(fSlow287))) + (1.5377968316956413e-010f * faustpower<14>(fSlow287))) + (1.898514607031656e-012f * faustpower<16>(fSlow287))) + (1.898514607031656e-014f * faustpower<18>(fSlow287))) + (1.5690203363897983e-016f * faustpower<20>(fSlow287))) + (1.0895974558262487e-018f * faustpower<22>(fSlow287))) + (6.697330183385451e-020f * faustpower<24>(fSlow287))) + (1.5283966662112614e-019f * faustpower<26>(fSlow287))) + (6.223149226587858e-020f * faustpower<28>(fSlow287))))) / fSlow6));
		float 	fSlow290 = (fConst38 * fSlow0);
		float 	fSlow291 = (0.008841941282883075f * sinf((0 - fSlow290)));
		float 	fSlow292 = min(fSlow1, (0 - fSlow291));
		float 	fSlow293 = (0.008841941282883075f * sinf(fSlow290));
		float 	fSlow294 = min(fSlow1, fSlow293);
		float 	fSlow295 = (2.8793172275584813f * fSlow3);
		float 	fSlow296 = faustpower<2>(fSlow295);
		float 	fSlow297 = min(1.0f, ((1 + (fSlow296 * ((((((((((((((0.25f + (0.0625f * fSlow296)) + (0.006944444444444444f * faustpower<4>(fSlow295))) + (0.00043402777777777775f * faustpower<6>(fSlow295))) + (1.736111111111111e-005f * faustpower<8>(fSlow295))) + (4.822530864197531e-007f * faustpower<10>(fSlow295))) + (9.841899722852104e-009f * faustpower<12>(fSlow295))) + (1.5377968316956413e-010f * faustpower<14>(fSlow295))) + (1.898514607031656e-012f * faustpower<16>(fSlow295))) + (1.898514607031656e-014f * faustpower<18>(fSlow295))) + (1.5690203363897983e-016f * faustpower<20>(fSlow295))) + (1.0895974558262487e-018f * faustpower<22>(fSlow295))) + (6.697330183385451e-020f * faustpower<24>(fSlow295))) + (1.5283966662112614e-019f * faustpower<26>(fSlow295))) + (6.223149226587858e-020f * faustpower<28>(fSlow295))))) / fSlow6));
		float 	fSlow298 = (fConst39 * fSlow0);
		float 	fSlow299 = (0.008602969896859207f * sinf((0 - fSlow298)));
		float 	fSlow300 = min(fSlow1, (0 - fSlow299));
		float 	fSlow301 = (0.008602969896859207f * sinf(fSlow298));
		float 	fSlow302 = min(fSlow1, fSlow301);
		float 	fSlow303 = (2.863829500919589f * fSlow3);
		float 	fSlow304 = faustpower<2>(fSlow303);
		float 	fSlow305 = min(1.0f, ((1 + (fSlow304 * ((((((((((((((0.25f + (0.0625f * fSlow304)) + (0.006944444444444444f * faustpower<4>(fSlow303))) + (0.00043402777777777775f * faustpower<6>(fSlow303))) + (1.736111111111111e-005f * faustpower<8>(fSlow303))) + (4.822530864197531e-007f * faustpower<10>(fSlow303))) + (9.841899722852104e-009f * faustpower<12>(fSlow303))) + (1.5377968316956413e-010f * faustpower<14>(fSlow303))) + (1.898514607031656e-012f * faustpower<16>(fSlow303))) + (1.898514607031656e-014f * faustpower<18>(fSlow303))) + (1.5690203363897983e-016f * faustpower<20>(fSlow303))) + (1.0895974558262487e-018f * faustpower<22>(fSlow303))) + (6.697330183385451e-020f * faustpower<24>(fSlow303))) + (1.5283966662112614e-019f * faustpower<26>(fSlow303))) + (6.223149226587858e-020f * faustpower<28>(fSlow303))))) / fSlow6));
		float 	fSlow306 = (fConst40 * fSlow0);
		float 	fSlow307 = (0.008376575952205019f * sinf((0 - fSlow306)));
		float 	fSlow308 = min(fSlow1, (0 - fSlow307));
		float 	fSlow309 = (0.008376575952205019f * sinf(fSlow306));
		float 	fSlow310 = min(fSlow1, fSlow309);
		float 	fSlow311 = (2.847829732340283f * fSlow3);
		float 	fSlow312 = faustpower<2>(fSlow311);
		float 	fSlow313 = min(1.0f, ((1 + (fSlow312 * ((((((((((((((0.25f + (0.0625f * fSlow312)) + (0.006944444444444444f * faustpower<4>(fSlow311))) + (0.00043402777777777775f * faustpower<6>(fSlow311))) + (1.736111111111111e-005f * faustpower<8>(fSlow311))) + (4.822530864197531e-007f * faustpower<10>(fSlow311))) + (9.841899722852104e-009f * faustpower<12>(fSlow311))) + (1.5377968316956413e-010f * faustpower<14>(fSlow311))) + (1.898514607031656e-012f * faustpower<16>(fSlow311))) + (1.898514607031656e-014f * faustpower<18>(fSlow311))) + (1.5690203363897983e-016f * faustpower<20>(fSlow311))) + (1.0895974558262487e-018f * faustpower<22>(fSlow311))) + (6.697330183385451e-020f * faustpower<24>(fSlow311))) + (1.5283966662112614e-019f * faustpower<26>(fSlow311))) + (6.223149226587858e-020f * faustpower<28>(fSlow311))))) / fSlow6));
		float 	fSlow314 = (fConst41 * fSlow0);
		float 	fSlow315 = (0.00816179195343053f * sinf((0 - fSlow314)));
		float 	fSlow316 = min(fSlow1, (0 - fSlow315));
		float 	fSlow317 = (0.00816179195343053f * sinf(fSlow314));
		float 	fSlow318 = min(fSlow1, fSlow317);
		float 	fSlow319 = (2.8313092411651226f * fSlow3);
		float 	fSlow320 = faustpower<2>(fSlow319);
		float 	fSlow321 = min(1.0f, ((1 + (fSlow320 * ((((((((((((((0.25f + (0.0625f * fSlow320)) + (0.006944444444444444f * faustpower<4>(fSlow319))) + (0.00043402777777777775f * faustpower<6>(fSlow319))) + (1.736111111111111e-005f * faustpower<8>(fSlow319))) + (4.822530864197531e-007f * faustpower<10>(fSlow319))) + (9.841899722852104e-009f * faustpower<12>(fSlow319))) + (1.5377968316956413e-010f * faustpower<14>(fSlow319))) + (1.898514607031656e-012f * faustpower<16>(fSlow319))) + (1.898514607031656e-014f * faustpower<18>(fSlow319))) + (1.5690203363897983e-016f * faustpower<20>(fSlow319))) + (1.0895974558262487e-018f * faustpower<22>(fSlow319))) + (6.697330183385451e-020f * faustpower<24>(fSlow319))) + (1.5283966662112614e-019f * faustpower<26>(fSlow319))) + (6.223149226587858e-020f * faustpower<28>(fSlow319))))) / fSlow6));
		float 	fSlow322 = (fConst42 * fSlow0);
		float 	fSlow323 = (0.007957747154594767f * sinf((0 - fSlow322)));
		float 	fSlow324 = min(fSlow1, (0 - fSlow323));
		float 	fSlow325 = (0.007957747154594767f * sinf(fSlow322));
		float 	fSlow326 = min(fSlow1, fSlow325);
		float 	fSlow327 = (2.814258857044679f * fSlow3);
		float 	fSlow328 = faustpower<2>(fSlow327);
		float 	fSlow329 = min(1.0f, ((1 + (fSlow328 * ((((((((((((((0.25f + (0.0625f * fSlow328)) + (0.006944444444444444f * faustpower<4>(fSlow327))) + (0.00043402777777777775f * faustpower<6>(fSlow327))) + (1.736111111111111e-005f * faustpower<8>(fSlow327))) + (4.822530864197531e-007f * faustpower<10>(fSlow327))) + (9.841899722852104e-009f * faustpower<12>(fSlow327))) + (1.5377968316956413e-010f * faustpower<14>(fSlow327))) + (1.898514607031656e-012f * faustpower<16>(fSlow327))) + (1.898514607031656e-014f * faustpower<18>(fSlow327))) + (1.5690203363897983e-016f * faustpower<20>(fSlow327))) + (1.0895974558262487e-018f * faustpower<22>(fSlow327))) + (6.697330183385451e-020f * faustpower<24>(fSlow327))) + (1.5283966662112614e-019f * faustpower<26>(fSlow327))) + (6.223149226587858e-020f * faustpower<28>(fSlow327))))) / fSlow6));
		float 	fSlow330 = (fConst43 * fSlow0);
		float 	fSlow331 = (0.0077636557605802615f * sinf((0 - fSlow330)));
		float 	fSlow332 = min(fSlow1, (0 - fSlow331));
		float 	fSlow333 = (0.0077636557605802615f * sinf(fSlow330));
		float 	fSlow334 = min(fSlow1, fSlow333);
		float 	fSlow335 = (2.7966688882389223f * fSlow3);
		float 	fSlow336 = faustpower<2>(fSlow335);
		float 	fSlow337 = min(1.0f, ((1 + (fSlow336 * ((((((((((((((0.25f + (0.0625f * fSlow336)) + (0.006944444444444444f * faustpower<4>(fSlow335))) + (0.00043402777777777775f * faustpower<6>(fSlow335))) + (1.736111111111111e-005f * faustpower<8>(fSlow335))) + (4.822530864197531e-007f * faustpower<10>(fSlow335))) + (9.841899722852104e-009f * faustpower<12>(fSlow335))) + (1.5377968316956413e-010f * faustpower<14>(fSlow335))) + (1.898514607031656e-012f * faustpower<16>(fSlow335))) + (1.898514607031656e-014f * faustpower<18>(fSlow335))) + (1.5690203363897983e-016f * faustpower<20>(fSlow335))) + (1.0895974558262487e-018f * faustpower<22>(fSlow335))) + (6.697330183385451e-020f * faustpower<24>(fSlow335))) + (1.5283966662112614e-019f * faustpower<26>(fSlow335))) + (6.223149226587858e-020f * faustpower<28>(fSlow335))))) / fSlow6));
		float 	fSlow338 = (fConst44 * fSlow0);
		float 	fSlow339 = (0.007578806813899778f * sinf((0 - fSlow338)));
		float 	fSlow340 = min(fSlow1, (0 - fSlow339));
		float 	fSlow341 = (0.007578806813899778f * sinf(fSlow338));
		float 	fSlow342 = min(fSlow1, fSlow341);
		float 	fSlow343 = (2.7785290869584833f * fSlow3);
		float 	fSlow344 = faustpower<2>(fSlow343);
		float 	fSlow345 = min(1.0f, ((1 + (fSlow344 * ((((((((((((((0.25f + (0.0625f * fSlow344)) + (0.006944444444444444f * faustpower<4>(fSlow343))) + (0.00043402777777777775f * faustpower<6>(fSlow343))) + (1.736111111111111e-005f * faustpower<8>(fSlow343))) + (4.822530864197531e-007f * faustpower<10>(fSlow343))) + (9.841899722852104e-009f * faustpower<12>(fSlow343))) + (1.5377968316956413e-010f * faustpower<14>(fSlow343))) + (1.898514607031656e-012f * faustpower<16>(fSlow343))) + (1.898514607031656e-014f * faustpower<18>(fSlow343))) + (1.5690203363897983e-016f * faustpower<20>(fSlow343))) + (1.0895974558262487e-018f * faustpower<22>(fSlow343))) + (6.697330183385451e-020f * faustpower<24>(fSlow343))) + (1.5283966662112614e-019f * faustpower<26>(fSlow343))) + (6.223149226587858e-020f * faustpower<28>(fSlow343))))) / fSlow6));
		float 	fSlow346 = (fConst45 * fSlow0);
		float 	fSlow347 = (0.007402555492646295f * sinf((0 - fSlow346)));
		float 	fSlow348 = min(fSlow1, (0 - fSlow347));
		float 	fSlow349 = (0.007402555492646295f * sinf(fSlow346));
		float 	fSlow350 = min(fSlow1, fSlow349);
		float 	fSlow351 = (2.759828611408118f * fSlow3);
		float 	fSlow352 = faustpower<2>(fSlow351);
		float 	fSlow353 = min(1.0f, ((1 + (fSlow352 * ((((((((((((((0.25f + (0.0625f * fSlow352)) + (0.006944444444444444f * faustpower<4>(fSlow351))) + (0.00043402777777777775f * faustpower<6>(fSlow351))) + (1.736111111111111e-005f * faustpower<8>(fSlow351))) + (4.822530864197531e-007f * faustpower<10>(fSlow351))) + (9.841899722852104e-009f * faustpower<12>(fSlow351))) + (1.5377968316956413e-010f * faustpower<14>(fSlow351))) + (1.898514607031656e-012f * faustpower<16>(fSlow351))) + (1.898514607031656e-014f * faustpower<18>(fSlow351))) + (1.5690203363897983e-016f * faustpower<20>(fSlow351))) + (1.0895974558262487e-018f * faustpower<22>(fSlow351))) + (6.697330183385451e-020f * faustpower<24>(fSlow351))) + (1.5283966662112614e-019f * faustpower<26>(fSlow351))) + (6.223149226587858e-020f * faustpower<28>(fSlow351))))) / fSlow6));
		float 	fSlow354 = (fConst46 * fSlow0);
		float 	fSlow355 = (0.007234315595086153f * sinf((0 - fSlow354)));
		float 	fSlow356 = min(fSlow1, (0 - fSlow355));
		float 	fSlow357 = (0.007234315595086153f * sinf(fSlow354));
		float 	fSlow358 = min(fSlow1, fSlow357);
		float 	fSlow359 = (2.74055598415013f * fSlow3);
		float 	fSlow360 = faustpower<2>(fSlow359);
		float 	fSlow361 = min(1.0f, ((1 + (fSlow360 * ((((((((((((((0.25f + (0.0625f * fSlow360)) + (0.006944444444444444f * faustpower<4>(fSlow359))) + (0.00043402777777777775f * faustpower<6>(fSlow359))) + (1.736111111111111e-005f * faustpower<8>(fSlow359))) + (4.822530864197531e-007f * faustpower<10>(fSlow359))) + (9.841899722852104e-009f * faustpower<12>(fSlow359))) + (1.5377968316956413e-010f * faustpower<14>(fSlow359))) + (1.898514607031656e-012f * faustpower<16>(fSlow359))) + (1.898514607031656e-014f * faustpower<18>(fSlow359))) + (1.5690203363897983e-016f * faustpower<20>(fSlow359))) + (1.0895974558262487e-018f * faustpower<22>(fSlow359))) + (6.697330183385451e-020f * faustpower<24>(fSlow359))) + (1.5283966662112614e-019f * faustpower<26>(fSlow359))) + (6.223149226587858e-020f * faustpower<28>(fSlow359))))) / fSlow6));
		float 	fSlow362 = (fConst47 * fSlow0);
		float 	fSlow363 = (0.007073553026306459f * sinf((0 - fSlow362)));
		float 	fSlow364 = min(fSlow1, (0 - fSlow363));
		float 	fSlow365 = (0.007073553026306459f * sinf(fSlow362));
		float 	fSlow366 = min(fSlow1, fSlow365);
		float 	fSlow367 = (2.7206990463513265f * fSlow3);
		float 	fSlow368 = faustpower<2>(fSlow367);
		float 	fSlow369 = min(1.0f, ((1 + (fSlow368 * ((((((((((((((0.25f + (0.0625f * fSlow368)) + (0.006944444444444444f * faustpower<4>(fSlow367))) + (0.00043402777777777775f * faustpower<6>(fSlow367))) + (1.736111111111111e-005f * faustpower<8>(fSlow367))) + (4.822530864197531e-007f * faustpower<10>(fSlow367))) + (9.841899722852104e-009f * faustpower<12>(fSlow367))) + (1.5377968316956413e-010f * faustpower<14>(fSlow367))) + (1.898514607031656e-012f * faustpower<16>(fSlow367))) + (1.898514607031656e-014f * faustpower<18>(fSlow367))) + (1.5690203363897983e-016f * faustpower<20>(fSlow367))) + (1.0895974558262487e-018f * faustpower<22>(fSlow367))) + (6.697330183385451e-020f * faustpower<24>(fSlow367))) + (1.5283966662112614e-019f * faustpower<26>(fSlow367))) + (6.223149226587858e-020f * faustpower<28>(fSlow367))))) / fSlow6));
		float 	fSlow370 = (fConst48 * fSlow0);
		float 	fSlow371 = (0.006919780134430233f * sinf((0 - fSlow370)));
		float 	fSlow372 = min(fSlow1, (0 - fSlow371));
		float 	fSlow373 = (0.006919780134430233f * sinf(fSlow370));
		float 	fSlow374 = min(fSlow1, fSlow373);
		float 	fSlow375 = (2.700244907413892f * fSlow3);
		float 	fSlow376 = faustpower<2>(fSlow375);
		float 	fSlow377 = min(1.0f, ((1 + (fSlow376 * ((((((((((((((0.25f + (0.0625f * fSlow376)) + (0.006944444444444444f * faustpower<4>(fSlow375))) + (0.00043402777777777775f * faustpower<6>(fSlow375))) + (1.736111111111111e-005f * faustpower<8>(fSlow375))) + (4.822530864197531e-007f * faustpower<10>(fSlow375))) + (9.841899722852104e-009f * faustpower<12>(fSlow375))) + (1.5377968316956413e-010f * faustpower<14>(fSlow375))) + (1.898514607031656e-012f * faustpower<16>(fSlow375))) + (1.898514607031656e-014f * faustpower<18>(fSlow375))) + (1.5690203363897983e-016f * faustpower<20>(fSlow375))) + (1.0895974558262487e-018f * faustpower<22>(fSlow375))) + (6.697330183385451e-020f * faustpower<24>(fSlow375))) + (1.5283966662112614e-019f * faustpower<26>(fSlow375))) + (6.223149226587858e-020f * faustpower<28>(fSlow375))))) / fSlow6));
		float 	fSlow378 = (fConst49 * fSlow0);
		float 	fSlow379 = (0.006772550769867886f * sinf((0 - fSlow378)));
		float 	fSlow380 = min(fSlow1, (0 - fSlow379));
		float 	fSlow381 = (0.006772550769867886f * sinf(fSlow378));
		float 	fSlow382 = min(fSlow1, fSlow381);
		float 	fSlow383 = (2.679179889416536f * fSlow3);
		float 	fSlow384 = faustpower<2>(fSlow383);
		float 	fSlow385 = min(1.0f, ((1 + (fSlow384 * ((((((((((((((0.25f + (0.0625f * fSlow384)) + (0.006944444444444444f * faustpower<4>(fSlow383))) + (0.00043402777777777775f * faustpower<6>(fSlow383))) + (1.736111111111111e-005f * faustpower<8>(fSlow383))) + (4.822530864197531e-007f * faustpower<10>(fSlow383))) + (9.841899722852104e-009f * faustpower<12>(fSlow383))) + (1.5377968316956413e-010f * faustpower<14>(fSlow383))) + (1.898514607031656e-012f * faustpower<16>(fSlow383))) + (1.898514607031656e-014f * faustpower<18>(fSlow383))) + (1.5690203363897983e-016f * faustpower<20>(fSlow383))) + (1.0895974558262487e-018f * faustpower<22>(fSlow383))) + (6.697330183385451e-020f * faustpower<24>(fSlow383))) + (1.5283966662112614e-019f * faustpower<26>(fSlow383))) + (6.223149226587858e-020f * faustpower<28>(fSlow383))))) / fSlow6));
		float 	fSlow386 = (fConst50 * fSlow0);
		float 	fSlow387 = (0.006631455962162306f * sinf((0 - fSlow386)));
		float 	fSlow388 = min(fSlow1, (0 - fSlow387));
		float 	fSlow389 = (0.006631455962162306f * sinf(fSlow386));
		float 	fSlow390 = min(fSlow1, fSlow389);
		float 	fSlow391 = (2.657489465705377f * fSlow3);
		float 	fSlow392 = faustpower<2>(fSlow391);
		float 	fSlow393 = min(1.0f, ((1 + (fSlow392 * ((((((((((((((0.25f + (0.0625f * fSlow392)) + (0.006944444444444444f * faustpower<4>(fSlow391))) + (0.00043402777777777775f * faustpower<6>(fSlow391))) + (1.736111111111111e-005f * faustpower<8>(fSlow391))) + (4.822530864197531e-007f * faustpower<10>(fSlow391))) + (9.841899722852104e-009f * faustpower<12>(fSlow391))) + (1.5377968316956413e-010f * faustpower<14>(fSlow391))) + (1.898514607031656e-012f * faustpower<16>(fSlow391))) + (1.898514607031656e-014f * faustpower<18>(fSlow391))) + (1.5690203363897983e-016f * faustpower<20>(fSlow391))) + (1.0895974558262487e-018f * faustpower<22>(fSlow391))) + (6.697330183385451e-020f * faustpower<24>(fSlow391))) + (1.5283966662112614e-019f * faustpower<26>(fSlow391))) + (6.223149226587858e-020f * faustpower<28>(fSlow391))))) / fSlow6));
		float 	fSlow394 = (fConst51 * fSlow0);
		float 	fSlow395 = (0.00649612012619981f * sinf((0 - fSlow394)));
		float 	fSlow396 = min(fSlow1, (0 - fSlow395));
		float 	fSlow397 = (0.00649612012619981f * sinf(fSlow394));
		float 	fSlow398 = min(fSlow1, fSlow397);
		float 	fSlow399 = (2.6351581928715038f * fSlow3);
		float 	fSlow400 = faustpower<2>(fSlow399);
		float 	fSlow401 = min(1.0f, ((1 + (fSlow400 * ((((((((((((((0.25f + (0.0625f * fSlow400)) + (0.006944444444444444f * faustpower<4>(fSlow399))) + (0.00043402777777777775f * faustpower<6>(fSlow399))) + (1.736111111111111e-005f * faustpower<8>(fSlow399))) + (4.822530864197531e-007f * faustpower<10>(fSlow399))) + (9.841899722852104e-009f * faustpower<12>(fSlow399))) + (1.5377968316956413e-010f * faustpower<14>(fSlow399))) + (1.898514607031656e-012f * faustpower<16>(fSlow399))) + (1.898514607031656e-014f * faustpower<18>(fSlow399))) + (1.5690203363897983e-016f * faustpower<20>(fSlow399))) + (1.0895974558262487e-018f * faustpower<22>(fSlow399))) + (6.697330183385451e-020f * faustpower<24>(fSlow399))) + (1.5283966662112614e-019f * faustpower<26>(fSlow399))) + (6.223149226587858e-020f * faustpower<28>(fSlow399))))) / fSlow6));
		float 	fSlow402 = (fConst52 * fSlow0);
		float 	fSlow403 = (0.006366197723675813f * sinf((0 - fSlow402)));
		float 	fSlow404 = min(fSlow1, (0 - fSlow403));
		float 	fSlow405 = (0.006366197723675813f * sinf(fSlow402));
		float 	fSlow406 = min(fSlow1, fSlow405);
		float 	fSlow407 = (2.6121696352308885f * fSlow3);
		float 	fSlow408 = faustpower<2>(fSlow407);
		float 	fSlow409 = min(1.0f, ((1 + (fSlow408 * ((((((((((((((0.25f + (0.0625f * fSlow408)) + (0.006944444444444444f * faustpower<4>(fSlow407))) + (0.00043402777777777775f * faustpower<6>(fSlow407))) + (1.736111111111111e-005f * faustpower<8>(fSlow407))) + (4.822530864197531e-007f * faustpower<10>(fSlow407))) + (9.841899722852104e-009f * faustpower<12>(fSlow407))) + (1.5377968316956413e-010f * faustpower<14>(fSlow407))) + (1.898514607031656e-012f * faustpower<16>(fSlow407))) + (1.898514607031656e-014f * faustpower<18>(fSlow407))) + (1.5690203363897983e-016f * faustpower<20>(fSlow407))) + (1.0895974558262487e-018f * faustpower<22>(fSlow407))) + (6.697330183385451e-020f * faustpower<24>(fSlow407))) + (1.5283966662112614e-019f * faustpower<26>(fSlow407))) + (6.223149226587858e-020f * faustpower<28>(fSlow407))))) / fSlow6));
		float 	fSlow410 = (fConst53 * fSlow0);
		float 	fSlow411 = (0.006241370317329229f * sinf((0 - fSlow410)));
		float 	fSlow412 = min(fSlow1, (0 - fSlow411));
		float 	fSlow413 = (0.006241370317329229f * sinf(fSlow410));
		float 	fSlow414 = min(fSlow1, fSlow413);
		float 	fSlow415 = (2.588506280778249f * fSlow3);
		float 	fSlow416 = faustpower<2>(fSlow415);
		float 	fSlow417 = min(1.0f, ((1 + (fSlow416 * ((((((((((((((0.25f + (0.0625f * fSlow416)) + (0.006944444444444444f * faustpower<4>(fSlow415))) + (0.00043402777777777775f * faustpower<6>(fSlow415))) + (1.736111111111111e-005f * faustpower<8>(fSlow415))) + (4.822530864197531e-007f * faustpower<10>(fSlow415))) + (9.841899722852104e-009f * faustpower<12>(fSlow415))) + (1.5377968316956413e-010f * faustpower<14>(fSlow415))) + (1.898514607031656e-012f * faustpower<16>(fSlow415))) + (1.898514607031656e-014f * faustpower<18>(fSlow415))) + (1.5690203363897983e-016f * faustpower<20>(fSlow415))) + (1.0895974558262487e-018f * faustpower<22>(fSlow415))) + (6.697330183385451e-020f * faustpower<24>(fSlow415))) + (1.5283966662112614e-019f * faustpower<26>(fSlow415))) + (6.223149226587858e-020f * faustpower<28>(fSlow415))))) / fSlow6));
		float 	fSlow418 = (fConst54 * fSlow0);
		float 	fSlow419 = (0.006121343965072897f * sinf((0 - fSlow418)));
		float 	fSlow420 = min(fSlow1, (0 - fSlow419));
		float 	fSlow421 = (0.006121343965072897f * sinf(fSlow418));
		float 	fSlow422 = min(fSlow1, fSlow421);
		float 	fSlow423 = (2.5641494474145454f * fSlow3);
		float 	fSlow424 = faustpower<2>(fSlow423);
		float 	fSlow425 = min(1.0f, ((1 + (fSlow424 * ((((((((((((((0.25f + (0.0625f * fSlow424)) + (0.006944444444444444f * faustpower<4>(fSlow423))) + (0.00043402777777777775f * faustpower<6>(fSlow423))) + (1.736111111111111e-005f * faustpower<8>(fSlow423))) + (4.822530864197531e-007f * faustpower<10>(fSlow423))) + (9.841899722852104e-009f * faustpower<12>(fSlow423))) + (1.5377968316956413e-010f * faustpower<14>(fSlow423))) + (1.898514607031656e-012f * faustpower<16>(fSlow423))) + (1.898514607031656e-014f * faustpower<18>(fSlow423))) + (1.5690203363897983e-016f * faustpower<20>(fSlow423))) + (1.0895974558262487e-018f * faustpower<22>(fSlow423))) + (6.697330183385451e-020f * faustpower<24>(fSlow423))) + (1.5283966662112614e-019f * faustpower<26>(fSlow423))) + (6.223149226587858e-020f * faustpower<28>(fSlow423))))) / fSlow6));
		float 	fSlow426 = (fConst55 * fSlow0);
		float 	fSlow427 = (0.006005846909128126f * sinf((0 - fSlow426)));
		float 	fSlow428 = min(fSlow1, (0 - fSlow427));
		float 	fSlow429 = (0.006005846909128126f * sinf(fSlow426));
		float 	fSlow430 = min(fSlow1, fSlow429);
		float 	fSlow431 = (2.5390791780418938f * fSlow3);
		float 	fSlow432 = faustpower<2>(fSlow431);
		float 	fSlow433 = min(1.0f, ((1 + (fSlow432 * ((((((((((((((0.25f + (0.0625f * fSlow432)) + (0.006944444444444444f * faustpower<4>(fSlow431))) + (0.00043402777777777775f * faustpower<6>(fSlow431))) + (1.736111111111111e-005f * faustpower<8>(fSlow431))) + (4.822530864197531e-007f * faustpower<10>(fSlow431))) + (9.841899722852104e-009f * faustpower<12>(fSlow431))) + (1.5377968316956413e-010f * faustpower<14>(fSlow431))) + (1.898514607031656e-012f * faustpower<16>(fSlow431))) + (1.898514607031656e-014f * faustpower<18>(fSlow431))) + (1.5690203363897983e-016f * faustpower<20>(fSlow431))) + (1.0895974558262487e-018f * faustpower<22>(fSlow431))) + (6.697330183385451e-020f * faustpower<24>(fSlow431))) + (1.5283966662112614e-019f * faustpower<26>(fSlow431))) + (6.223149226587858e-020f * faustpower<28>(fSlow431))))) / fSlow6));
		float 	fSlow434 = (fConst56 * fSlow0);
		float 	fSlow435 = (0.00589462752192205f * sinf((0 - fSlow434)));
		float 	fSlow436 = min(fSlow1, (0 - fSlow435));
		float 	fSlow437 = (0.00589462752192205f * sinf(fSlow434));
		float 	fSlow438 = min(fSlow1, fSlow437);
		float 	fSlow439 = (2.5132741228718345f * fSlow3);
		float 	fSlow440 = faustpower<2>(fSlow439);
		float 	fSlow441 = min(1.0f, ((1 + (fSlow440 * ((((((((((((((0.25f + (0.0625f * fSlow440)) + (0.006944444444444444f * faustpower<4>(fSlow439))) + (0.00043402777777777775f * faustpower<6>(fSlow439))) + (1.736111111111111e-005f * faustpower<8>(fSlow439))) + (4.822530864197531e-007f * faustpower<10>(fSlow439))) + (9.841899722852104e-009f * faustpower<12>(fSlow439))) + (1.5377968316956413e-010f * faustpower<14>(fSlow439))) + (1.898514607031656e-012f * faustpower<16>(fSlow439))) + (1.898514607031656e-014f * faustpower<18>(fSlow439))) + (1.5690203363897983e-016f * faustpower<20>(fSlow439))) + (1.0895974558262487e-018f * faustpower<22>(fSlow439))) + (6.697330183385451e-020f * faustpower<24>(fSlow439))) + (1.5283966662112614e-019f * faustpower<26>(fSlow439))) + (6.223149226587858e-020f * faustpower<28>(fSlow439))))) / fSlow6));
		float 	fSlow442 = (fConst57 * fSlow0);
		float 	fSlow443 = (0.0057874524760689215f * sinf((0 - fSlow442)));
		float 	fSlow444 = min(fSlow1, (0 - fSlow443));
		float 	fSlow445 = (0.0057874524760689215f * sinf(fSlow442));
		float 	fSlow446 = min(fSlow1, fSlow445);
		float 	fSlow447 = (2.4867114069932166f * fSlow3);
		float 	fSlow448 = faustpower<2>(fSlow447);
		float 	fSlow449 = min(1.0f, ((1 + (fSlow448 * ((((((((((((((0.25f + (0.0625f * fSlow448)) + (0.006944444444444444f * faustpower<4>(fSlow447))) + (0.00043402777777777775f * faustpower<6>(fSlow447))) + (1.736111111111111e-005f * faustpower<8>(fSlow447))) + (4.822530864197531e-007f * faustpower<10>(fSlow447))) + (9.841899722852104e-009f * faustpower<12>(fSlow447))) + (1.5377968316956413e-010f * faustpower<14>(fSlow447))) + (1.898514607031656e-012f * faustpower<16>(fSlow447))) + (1.898514607031656e-014f * faustpower<18>(fSlow447))) + (1.5690203363897983e-016f * faustpower<20>(fSlow447))) + (1.0895974558262487e-018f * faustpower<22>(fSlow447))) + (6.697330183385451e-020f * faustpower<24>(fSlow447))) + (1.5283966662112614e-019f * faustpower<26>(fSlow447))) + (6.223149226587858e-020f * faustpower<28>(fSlow447))))) / fSlow6));
		float 	fSlow450 = (fConst58 * fSlow0);
		float 	fSlow451 = (0.005684105110424833f * sinf((0 - fSlow450)));
		float 	fSlow452 = min(fSlow1, (0 - fSlow451));
		float 	fSlow453 = (0.005684105110424833f * sinf(fSlow450));
		float 	fSlow454 = min(fSlow1, fSlow453);
		float 	fSlow455 = (2.4593664808817914f * fSlow3);
		float 	fSlow456 = faustpower<2>(fSlow455);
		float 	fSlow457 = min(1.0f, ((1 + (fSlow456 * ((((((((((((((0.25f + (0.0625f * fSlow456)) + (0.006944444444444444f * faustpower<4>(fSlow455))) + (0.00043402777777777775f * faustpower<6>(fSlow455))) + (1.736111111111111e-005f * faustpower<8>(fSlow455))) + (4.822530864197531e-007f * faustpower<10>(fSlow455))) + (9.841899722852104e-009f * faustpower<12>(fSlow455))) + (1.5377968316956413e-010f * faustpower<14>(fSlow455))) + (1.898514607031656e-012f * faustpower<16>(fSlow455))) + (1.898514607031656e-014f * faustpower<18>(fSlow455))) + (1.5690203363897983e-016f * faustpower<20>(fSlow455))) + (1.0895974558262487e-018f * faustpower<22>(fSlow455))) + (6.697330183385451e-020f * faustpower<24>(fSlow455))) + (1.5283966662112614e-019f * faustpower<26>(fSlow455))) + (6.223149226587858e-020f * faustpower<28>(fSlow455))))) / fSlow6));
		float 	fSlow458 = (fConst59 * fSlow0);
		float 	fSlow459 = (0.005584383968136679f * sinf((0 - fSlow458)));
		float 	fSlow460 = min(fSlow1, (0 - fSlow459));
		float 	fSlow461 = (0.005584383968136679f * sinf(fSlow458));
		float 	fSlow462 = min(fSlow1, fSlow461);
		float 	fSlow463 = (2.4312129510886726f * fSlow3);
		float 	fSlow464 = faustpower<2>(fSlow463);
		float 	fSlow465 = min(1.0f, ((1 + (fSlow464 * ((((((((((((((0.25f + (0.0625f * fSlow464)) + (0.006944444444444444f * faustpower<4>(fSlow463))) + (0.00043402777777777775f * faustpower<6>(fSlow463))) + (1.736111111111111e-005f * faustpower<8>(fSlow463))) + (4.822530864197531e-007f * faustpower<10>(fSlow463))) + (9.841899722852104e-009f * faustpower<12>(fSlow463))) + (1.5377968316956413e-010f * faustpower<14>(fSlow463))) + (1.898514607031656e-012f * faustpower<16>(fSlow463))) + (1.898514607031656e-014f * faustpower<18>(fSlow463))) + (1.5690203363897983e-016f * faustpower<20>(fSlow463))) + (1.0895974558262487e-018f * faustpower<22>(fSlow463))) + (6.697330183385451e-020f * faustpower<24>(fSlow463))) + (1.5283966662112614e-019f * faustpower<26>(fSlow463))) + (6.223149226587858e-020f * faustpower<28>(fSlow463))))) / fSlow6));
		float 	fSlow466 = (fConst60 * fSlow0);
		float 	fSlow467 = (0.0054881014859274255f * sinf((0 - fSlow466)));
		float 	fSlow468 = min(fSlow1, (0 - fSlow467));
		float 	fSlow469 = (0.0054881014859274255f * sinf(fSlow466));
		float 	fSlow470 = min(fSlow1, fSlow469);
		float 	fSlow471 = (2.402222387798308f * fSlow3);
		float 	fSlow472 = faustpower<2>(fSlow471);
		float 	fSlow473 = min(1.0f, ((1 + (fSlow472 * ((((((((((((((0.25f + (0.0625f * fSlow472)) + (0.006944444444444444f * faustpower<4>(fSlow471))) + (0.00043402777777777775f * faustpower<6>(fSlow471))) + (1.736111111111111e-005f * faustpower<8>(fSlow471))) + (4.822530864197531e-007f * faustpower<10>(fSlow471))) + (9.841899722852104e-009f * faustpower<12>(fSlow471))) + (1.5377968316956413e-010f * faustpower<14>(fSlow471))) + (1.898514607031656e-012f * faustpower<16>(fSlow471))) + (1.898514607031656e-014f * faustpower<18>(fSlow471))) + (1.5690203363897983e-016f * faustpower<20>(fSlow471))) + (1.0895974558262487e-018f * faustpower<22>(fSlow471))) + (6.697330183385451e-020f * faustpower<24>(fSlow471))) + (1.5283966662112614e-019f * faustpower<26>(fSlow471))) + (6.223149226587858e-020f * faustpower<28>(fSlow471))))) / fSlow6));
		float 	fSlow474 = (fConst61 * fSlow0);
		float 	fSlow475 = (0.005395082816674419f * sinf((0 - fSlow474)));
		float 	fSlow476 = min(fSlow1, (0 - fSlow475));
		float 	fSlow477 = (0.005395082816674419f * sinf(fSlow474));
		float 	fSlow478 = min(fSlow1, fSlow477);
		float 	fSlow479 = (2.3723641052712012f * fSlow3);
		float 	fSlow480 = faustpower<2>(fSlow479);
		float 	fSlow481 = min(1.0f, ((1 + (fSlow480 * ((((((((((((((0.25f + (0.0625f * fSlow480)) + (0.006944444444444444f * faustpower<4>(fSlow479))) + (0.00043402777777777775f * faustpower<6>(fSlow479))) + (1.736111111111111e-005f * faustpower<8>(fSlow479))) + (4.822530864197531e-007f * faustpower<10>(fSlow479))) + (9.841899722852104e-009f * faustpower<12>(fSlow479))) + (1.5377968316956413e-010f * faustpower<14>(fSlow479))) + (1.898514607031656e-012f * faustpower<16>(fSlow479))) + (1.898514607031656e-014f * faustpower<18>(fSlow479))) + (1.5690203363897983e-016f * faustpower<20>(fSlow479))) + (1.0895974558262487e-018f * faustpower<22>(fSlow479))) + (6.697330183385451e-020f * faustpower<24>(fSlow479))) + (1.5283966662112614e-019f * faustpower<26>(fSlow479))) + (6.223149226587858e-020f * faustpower<28>(fSlow479))))) / fSlow6));
		float 	fSlow482 = (fConst62 * fSlow0);
		float 	fSlow483 = (0.005305164769729845f * sinf((0 - fSlow482)));
		float 	fSlow484 = min(fSlow1, (0 - fSlow483));
		float 	fSlow485 = (0.005305164769729845f * sinf(fSlow482));
		float 	fSlow486 = min(fSlow1, fSlow485);
		float 	fSlow487 = (2.3416049103469088f * fSlow3);
		float 	fSlow488 = faustpower<2>(fSlow487);
		float 	fSlow489 = min(1.0f, ((1 + (fSlow488 * ((((((((((((((0.25f + (0.0625f * fSlow488)) + (0.006944444444444444f * faustpower<4>(fSlow487))) + (0.00043402777777777775f * faustpower<6>(fSlow487))) + (1.736111111111111e-005f * faustpower<8>(fSlow487))) + (4.822530864197531e-007f * faustpower<10>(fSlow487))) + (9.841899722852104e-009f * faustpower<12>(fSlow487))) + (1.5377968316956413e-010f * faustpower<14>(fSlow487))) + (1.898514607031656e-012f * faustpower<16>(fSlow487))) + (1.898514607031656e-014f * faustpower<18>(fSlow487))) + (1.5690203363897983e-016f * faustpower<20>(fSlow487))) + (1.0895974558262487e-018f * faustpower<22>(fSlow487))) + (6.697330183385451e-020f * faustpower<24>(fSlow487))) + (1.5283966662112614e-019f * faustpower<26>(fSlow487))) + (6.223149226587858e-020f * faustpower<28>(fSlow487))))) / fSlow6));
		float 	fSlow490 = (fConst63 * fSlow0);
		float 	fSlow491 = (0.005218194855471979f * sinf((0 - fSlow490)));
		float 	fSlow492 = min(fSlow1, (0 - fSlow491));
		float 	fSlow493 = (0.005218194855471979f * sinf(fSlow490));
		float 	fSlow494 = min(fSlow1, fSlow493);
		float 	fSlow495 = (2.3099088131318055f * fSlow3);
		float 	fSlow496 = faustpower<2>(fSlow495);
		float 	fSlow497 = min(1.0f, ((1 + (fSlow496 * ((((((((((((((0.25f + (0.0625f * fSlow496)) + (0.006944444444444444f * faustpower<4>(fSlow495))) + (0.00043402777777777775f * faustpower<6>(fSlow495))) + (1.736111111111111e-005f * faustpower<8>(fSlow495))) + (4.822530864197531e-007f * faustpower<10>(fSlow495))) + (9.841899722852104e-009f * faustpower<12>(fSlow495))) + (1.5377968316956413e-010f * faustpower<14>(fSlow495))) + (1.898514607031656e-012f * faustpower<16>(fSlow495))) + (1.898514607031656e-014f * faustpower<18>(fSlow495))) + (1.5690203363897983e-016f * faustpower<20>(fSlow495))) + (1.0895974558262487e-018f * faustpower<22>(fSlow495))) + (6.697330183385451e-020f * faustpower<24>(fSlow495))) + (1.5283966662112614e-019f * faustpower<26>(fSlow495))) + (6.223149226587858e-020f * faustpower<28>(fSlow495))))) / fSlow6));
		float 	fSlow498 = (fConst64 * fSlow0);
		float 	fSlow499 = (0.005134030422319205f * sinf((0 - fSlow498)));
		float 	fSlow500 = min(fSlow1, (0 - fSlow499));
		float 	fSlow501 = (0.005134030422319205f * sinf(fSlow498));
		float 	fSlow502 = min(fSlow1, fSlow501);
		float 	fSlow503 = (2.2772366926713894f * fSlow3);
		float 	fSlow504 = faustpower<2>(fSlow503);
		float 	fSlow505 = min(1.0f, ((1 + (fSlow504 * ((((((((((((((0.25f + (0.0625f * fSlow504)) + (0.006944444444444444f * faustpower<4>(fSlow503))) + (0.00043402777777777775f * faustpower<6>(fSlow503))) + (1.736111111111111e-005f * faustpower<8>(fSlow503))) + (4.822530864197531e-007f * faustpower<10>(fSlow503))) + (9.841899722852104e-009f * faustpower<12>(fSlow503))) + (1.5377968316956413e-010f * faustpower<14>(fSlow503))) + (1.898514607031656e-012f * faustpower<16>(fSlow503))) + (1.898514607031656e-014f * faustpower<18>(fSlow503))) + (1.5690203363897983e-016f * faustpower<20>(fSlow503))) + (1.0895974558262487e-018f * faustpower<22>(fSlow503))) + (6.697330183385451e-020f * faustpower<24>(fSlow503))) + (1.5283966662112614e-019f * faustpower<26>(fSlow503))) + (6.223149226587858e-020f * faustpower<28>(fSlow503))))) / fSlow6));
		float 	fSlow506 = (fConst65 * fSlow0);
		float 	fSlow507 = (0.0050525378759331855f * sinf((0 - fSlow506)));
		float 	fSlow508 = min(fSlow1, (0 - fSlow507));
		float 	fSlow509 = (0.0050525378759331855f * sinf(fSlow506));
		float 	fSlow510 = min(fSlow1, fSlow509);
		float 	fSlow511 = (2.2435459087247516f * fSlow3);
		float 	fSlow512 = faustpower<2>(fSlow511);
		float 	fSlow513 = min(1.0f, ((1 + (fSlow512 * ((((((((((((((0.25f + (0.0625f * fSlow512)) + (0.006944444444444444f * faustpower<4>(fSlow511))) + (0.00043402777777777775f * faustpower<6>(fSlow511))) + (1.736111111111111e-005f * faustpower<8>(fSlow511))) + (4.822530864197531e-007f * faustpower<10>(fSlow511))) + (9.841899722852104e-009f * faustpower<12>(fSlow511))) + (1.5377968316956413e-010f * faustpower<14>(fSlow511))) + (1.898514607031656e-012f * faustpower<16>(fSlow511))) + (1.898514607031656e-014f * faustpower<18>(fSlow511))) + (1.5690203363897983e-016f * faustpower<20>(fSlow511))) + (1.0895974558262487e-018f * faustpower<22>(fSlow511))) + (6.697330183385451e-020f * faustpower<24>(fSlow511))) + (1.5283966662112614e-019f * faustpower<26>(fSlow511))) + (6.223149226587858e-020f * faustpower<28>(fSlow511))))) / fSlow6));
		float 	fSlow514 = (fConst66 * fSlow0);
		float 	fSlow515 = (0.0049735919716217296f * sinf((0 - fSlow514)));
		float 	fSlow516 = min(fSlow1, (0 - fSlow515));
		float 	fSlow517 = (0.0049735919716217296f * sinf(fSlow514));
		float 	fSlow518 = min(fSlow1, fSlow517);
		float 	fSlow519 = (2.2087898486057753f * fSlow3);
		float 	fSlow520 = faustpower<2>(fSlow519);
		float 	fSlow521 = min(1.0f, ((1 + (fSlow520 * ((((((((((((((0.25f + (0.0625f * fSlow520)) + (0.006944444444444444f * faustpower<4>(fSlow519))) + (0.00043402777777777775f * faustpower<6>(fSlow519))) + (1.736111111111111e-005f * faustpower<8>(fSlow519))) + (4.822530864197531e-007f * faustpower<10>(fSlow519))) + (9.841899722852104e-009f * faustpower<12>(fSlow519))) + (1.5377968316956413e-010f * faustpower<14>(fSlow519))) + (1.898514607031656e-012f * faustpower<16>(fSlow519))) + (1.898514607031656e-014f * faustpower<18>(fSlow519))) + (1.5690203363897983e-016f * faustpower<20>(fSlow519))) + (1.0895974558262487e-018f * faustpower<22>(fSlow519))) + (6.697330183385451e-020f * faustpower<24>(fSlow519))) + (1.5283966662112614e-019f * faustpower<26>(fSlow519))) + (6.223149226587858e-020f * faustpower<28>(fSlow519))))) / fSlow6));
		float 	fSlow522 = (fConst67 * fSlow0);
		float 	fSlow523 = (0.004897075172058319f * sinf((0 - fSlow522)));
		float 	fSlow524 = min(fSlow1, (0 - fSlow523));
		float 	fSlow525 = (0.004897075172058319f * sinf(fSlow522));
		float 	fSlow526 = min(fSlow1, fSlow525);
		float 	fSlow527 = (2.172917395276218f * fSlow3);
		float 	fSlow528 = faustpower<2>(fSlow527);
		float 	fSlow529 = min(1.0f, ((1 + (fSlow528 * ((((((((((((((0.25f + (0.0625f * fSlow528)) + (0.006944444444444444f * faustpower<4>(fSlow527))) + (0.00043402777777777775f * faustpower<6>(fSlow527))) + (1.736111111111111e-005f * faustpower<8>(fSlow527))) + (4.822530864197531e-007f * faustpower<10>(fSlow527))) + (9.841899722852104e-009f * faustpower<12>(fSlow527))) + (1.5377968316956413e-010f * faustpower<14>(fSlow527))) + (1.898514607031656e-012f * faustpower<16>(fSlow527))) + (1.898514607031656e-014f * faustpower<18>(fSlow527))) + (1.5690203363897983e-016f * faustpower<20>(fSlow527))) + (1.0895974558262487e-018f * faustpower<22>(fSlow527))) + (6.697330183385451e-020f * faustpower<24>(fSlow527))) + (1.5283966662112614e-019f * faustpower<26>(fSlow527))) + (6.223149226587858e-020f * faustpower<28>(fSlow527))))) / fSlow6));
		float 	fSlow530 = (fConst68 * fSlow0);
		float 	fSlow531 = (0.004822877063390768f * sinf((0 - fSlow530)));
		float 	fSlow532 = min(fSlow1, (0 - fSlow531));
		float 	fSlow533 = (0.004822877063390768f * sinf(fSlow530));
		float 	fSlow534 = min(fSlow1, fSlow533);
		float 	fSlow535 = (2.1358722992552126f * fSlow3);
		float 	fSlow536 = faustpower<2>(fSlow535);
		float 	fSlow537 = min(1.0f, ((1 + (fSlow536 * ((((((((((((((0.25f + (0.0625f * fSlow536)) + (0.006944444444444444f * faustpower<4>(fSlow535))) + (0.00043402777777777775f * faustpower<6>(fSlow535))) + (1.736111111111111e-005f * faustpower<8>(fSlow535))) + (4.822530864197531e-007f * faustpower<10>(fSlow535))) + (9.841899722852104e-009f * faustpower<12>(fSlow535))) + (1.5377968316956413e-010f * faustpower<14>(fSlow535))) + (1.898514607031656e-012f * faustpower<16>(fSlow535))) + (1.898514607031656e-014f * faustpower<18>(fSlow535))) + (1.5690203363897983e-016f * faustpower<20>(fSlow535))) + (1.0895974558262487e-018f * faustpower<22>(fSlow535))) + (6.697330183385451e-020f * faustpower<24>(fSlow535))) + (1.5283966662112614e-019f * faustpower<26>(fSlow535))) + (6.223149226587858e-020f * faustpower<28>(fSlow535))))) / fSlow6));
		float 	fSlow538 = (fConst69 * fSlow0);
		float 	fSlow539 = (0.004750893823638667f * sinf((0 - fSlow538)));
		float 	fSlow540 = min(fSlow1, (0 - fSlow539));
		float 	fSlow541 = (0.004750893823638667f * sinf(fSlow538));
		float 	fSlow542 = min(fSlow1, fSlow541);
		float 	fSlow543 = (2.0975924321467265f * fSlow3);
		float 	fSlow544 = faustpower<2>(fSlow543);
		float 	fSlow545 = min(1.0f, ((1 + (fSlow544 * ((((((((((((((0.25f + (0.0625f * fSlow544)) + (0.006944444444444444f * faustpower<4>(fSlow543))) + (0.00043402777777777775f * faustpower<6>(fSlow543))) + (1.736111111111111e-005f * faustpower<8>(fSlow543))) + (4.822530864197531e-007f * faustpower<10>(fSlow543))) + (9.841899722852104e-009f * faustpower<12>(fSlow543))) + (1.5377968316956413e-010f * faustpower<14>(fSlow543))) + (1.898514607031656e-012f * faustpower<16>(fSlow543))) + (1.898514607031656e-014f * faustpower<18>(fSlow543))) + (1.5690203363897983e-016f * faustpower<20>(fSlow543))) + (1.0895974558262487e-018f * faustpower<22>(fSlow543))) + (6.697330183385451e-020f * faustpower<24>(fSlow543))) + (1.5283966662112614e-019f * faustpower<26>(fSlow543))) + (6.223149226587858e-020f * faustpower<28>(fSlow543))))) / fSlow6));
		float 	fSlow546 = (fConst70 * fSlow0);
		float 	fSlow547 = (0.004681027737996921f * sinf((0 - fSlow546)));
		float 	fSlow548 = min(fSlow1, (0 - fSlow547));
		float 	fSlow549 = (0.004681027737996921f * sinf(fSlow546));
		float 	fSlow550 = min(fSlow1, fSlow549);
		float 	fSlow551 = (2.0580088932544474f * fSlow3);
		float 	fSlow552 = faustpower<2>(fSlow551);
		float 	fSlow553 = min(1.0f, ((1 + (fSlow552 * ((((((((((((((0.25f + (0.0625f * fSlow552)) + (0.006944444444444444f * faustpower<4>(fSlow551))) + (0.00043402777777777775f * faustpower<6>(fSlow551))) + (1.736111111111111e-005f * faustpower<8>(fSlow551))) + (4.822530864197531e-007f * faustpower<10>(fSlow551))) + (9.841899722852104e-009f * faustpower<12>(fSlow551))) + (1.5377968316956413e-010f * faustpower<14>(fSlow551))) + (1.898514607031656e-012f * faustpower<16>(fSlow551))) + (1.898514607031656e-014f * faustpower<18>(fSlow551))) + (1.5690203363897983e-016f * faustpower<20>(fSlow551))) + (1.0895974558262487e-018f * faustpower<22>(fSlow551))) + (6.697330183385451e-020f * faustpower<24>(fSlow551))) + (1.5283966662112614e-019f * faustpower<26>(fSlow551))) + (6.223149226587858e-020f * faustpower<28>(fSlow551))))) / fSlow6));
		float 	fSlow554 = (fConst71 * fSlow0);
		float 	fSlow555 = (0.004613186756286821f * sinf((0 - fSlow554)));
		float 	fSlow556 = min(fSlow1, (0 - fSlow555));
		float 	fSlow557 = (0.004613186756286821f * sinf(fSlow554));
		float 	fSlow558 = min(fSlow1, fSlow557);
		float 	fSlow559 = (2.0170449322390613f * fSlow3);
		float 	fSlow560 = faustpower<2>(fSlow559);
		float 	fSlow561 = min(1.0f, ((1 + (fSlow560 * ((((((((((((((0.25f + (0.0625f * fSlow560)) + (0.006944444444444444f * faustpower<4>(fSlow559))) + (0.00043402777777777775f * faustpower<6>(fSlow559))) + (1.736111111111111e-005f * faustpower<8>(fSlow559))) + (4.822530864197531e-007f * faustpower<10>(fSlow559))) + (9.841899722852104e-009f * faustpower<12>(fSlow559))) + (1.5377968316956413e-010f * faustpower<14>(fSlow559))) + (1.898514607031656e-012f * faustpower<16>(fSlow559))) + (1.898514607031656e-014f * faustpower<18>(fSlow559))) + (1.5690203363897983e-016f * faustpower<20>(fSlow559))) + (1.0895974558262487e-018f * faustpower<22>(fSlow559))) + (6.697330183385451e-020f * faustpower<24>(fSlow559))) + (1.5283966662112614e-019f * faustpower<26>(fSlow559))) + (6.223149226587858e-020f * faustpower<28>(fSlow559))))) / fSlow6));
		float 	fSlow562 = (fConst72 * fSlow0);
		float 	fSlow563 = (0.004547284088339867f * sinf((0 - fSlow562)));
		float 	fSlow564 = min(fSlow1, (0 - fSlow563));
		float 	fSlow565 = (0.004547284088339867f * sinf(fSlow562));
		float 	fSlow566 = min(fSlow1, fSlow565);
		float 	fSlow567 = (1.9746146391814958f * fSlow3);
		float 	fSlow568 = faustpower<2>(fSlow567);
		float 	fSlow569 = min(1.0f, ((1 + (fSlow568 * ((((((((((((((0.25f + (0.0625f * fSlow568)) + (0.006944444444444444f * faustpower<4>(fSlow567))) + (0.00043402777777777775f * faustpower<6>(fSlow567))) + (1.736111111111111e-005f * faustpower<8>(fSlow567))) + (4.822530864197531e-007f * faustpower<10>(fSlow567))) + (9.841899722852104e-009f * faustpower<12>(fSlow567))) + (1.5377968316956413e-010f * faustpower<14>(fSlow567))) + (1.898514607031656e-012f * faustpower<16>(fSlow567))) + (1.898514607031656e-014f * faustpower<18>(fSlow567))) + (1.5690203363897983e-016f * faustpower<20>(fSlow567))) + (1.0895974558262487e-018f * faustpower<22>(fSlow567))) + (6.697330183385451e-020f * faustpower<24>(fSlow567))) + (1.5283966662112614e-019f * faustpower<26>(fSlow567))) + (6.223149226587858e-020f * faustpower<28>(fSlow567))))) / fSlow6));
		float 	fSlow570 = (fConst73 * fSlow0);
		float 	fSlow571 = (0.004483237833574517f * sinf((0 - fSlow570)));
		float 	fSlow572 = min(fSlow1, (0 - fSlow571));
		float 	fSlow573 = (0.004483237833574517f * sinf(fSlow570));
		float 	fSlow574 = min(fSlow1, fSlow573);
		float 	fSlow575 = (1.9306213374222734f * fSlow3);
		float 	fSlow576 = faustpower<2>(fSlow575);
		float 	fSlow577 = min(1.0f, ((1 + (fSlow576 * ((((((((((((((0.25f + (0.0625f * fSlow576)) + (0.006944444444444444f * faustpower<4>(fSlow575))) + (0.00043402777777777775f * faustpower<6>(fSlow575))) + (1.736111111111111e-005f * faustpower<8>(fSlow575))) + (4.822530864197531e-007f * faustpower<10>(fSlow575))) + (9.841899722852104e-009f * faustpower<12>(fSlow575))) + (1.5377968316956413e-010f * faustpower<14>(fSlow575))) + (1.898514607031656e-012f * faustpower<16>(fSlow575))) + (1.898514607031656e-014f * faustpower<18>(fSlow575))) + (1.5690203363897983e-016f * faustpower<20>(fSlow575))) + (1.0895974558262487e-018f * faustpower<22>(fSlow575))) + (6.697330183385451e-020f * faustpower<24>(fSlow575))) + (1.5283966662112614e-019f * faustpower<26>(fSlow575))) + (6.223149226587858e-020f * faustpower<28>(fSlow575))))) / fSlow6));
		float 	fSlow578 = (fConst74 * fSlow0);
		float 	fSlow579 = (0.004420970641441538f * sinf((0 - fSlow578)));
		float 	fSlow580 = min(fSlow1, (0 - fSlow579));
		float 	fSlow581 = (0.004420970641441538f * sinf(fSlow578));
		float 	fSlow582 = min(fSlow1, fSlow581);
		float 	fSlow583 = (1.8849555921538754f * fSlow3);
		float 	fSlow584 = faustpower<2>(fSlow583);
		float 	fSlow585 = min(1.0f, ((1 + (fSlow584 * ((((((((((((((0.25f + (0.0625f * fSlow584)) + (0.006944444444444444f * faustpower<4>(fSlow583))) + (0.00043402777777777775f * faustpower<6>(fSlow583))) + (1.736111111111111e-005f * faustpower<8>(fSlow583))) + (4.822530864197531e-007f * faustpower<10>(fSlow583))) + (9.841899722852104e-009f * faustpower<12>(fSlow583))) + (1.5377968316956413e-010f * faustpower<14>(fSlow583))) + (1.898514607031656e-012f * faustpower<16>(fSlow583))) + (1.898514607031656e-014f * faustpower<18>(fSlow583))) + (1.5690203363897983e-016f * faustpower<20>(fSlow583))) + (1.0895974558262487e-018f * faustpower<22>(fSlow583))) + (6.697330183385451e-020f * faustpower<24>(fSlow583))) + (1.5283966662112614e-019f * faustpower<26>(fSlow583))) + (6.223149226587858e-020f * faustpower<28>(fSlow583))))) / fSlow6));
		float 	fSlow586 = (fConst75 * fSlow0);
		float 	fSlow587 = (0.004360409399777955f * sinf((0 - fSlow586)));
		float 	fSlow588 = min(fSlow1, (0 - fSlow587));
		float 	fSlow589 = (0.004360409399777955f * sinf(fSlow586));
		float 	fSlow590 = min(fSlow1, fSlow589);
		float 	fSlow591 = (1.8374927158810392f * fSlow3);
		float 	fSlow592 = faustpower<2>(fSlow591);
		float 	fSlow593 = min(1.0f, ((1 + (fSlow592 * ((((((((((((((0.25f + (0.0625f * fSlow592)) + (0.006944444444444444f * faustpower<4>(fSlow591))) + (0.00043402777777777775f * faustpower<6>(fSlow591))) + (1.736111111111111e-005f * faustpower<8>(fSlow591))) + (4.822530864197531e-007f * faustpower<10>(fSlow591))) + (9.841899722852104e-009f * faustpower<12>(fSlow591))) + (1.5377968316956413e-010f * faustpower<14>(fSlow591))) + (1.898514607031656e-012f * faustpower<16>(fSlow591))) + (1.898514607031656e-014f * faustpower<18>(fSlow591))) + (1.5690203363897983e-016f * faustpower<20>(fSlow591))) + (1.0895974558262487e-018f * faustpower<22>(fSlow591))) + (6.697330183385451e-020f * faustpower<24>(fSlow591))) + (1.5283966662112614e-019f * faustpower<26>(fSlow591))) + (6.223149226587858e-020f * faustpower<28>(fSlow591))))) / fSlow6));
		float 	fSlow594 = (fConst76 * fSlow0);
		float 	fSlow595 = (0.0043014849484296035f * sinf((0 - fSlow594)));
		float 	fSlow596 = min(fSlow1, (0 - fSlow595));
		float 	fSlow597 = (0.0043014849484296035f * sinf(fSlow594));
		float 	fSlow598 = min(fSlow1, fSlow597);
		float 	fSlow599 = (1.78808960571927f * fSlow3);
		float 	fSlow600 = faustpower<2>(fSlow599);
		float 	fSlow601 = min(1.0f, ((1 + (fSlow600 * ((((((((((((((0.25f + (0.0625f * fSlow600)) + (0.006944444444444444f * faustpower<4>(fSlow599))) + (0.00043402777777777775f * faustpower<6>(fSlow599))) + (1.736111111111111e-005f * faustpower<8>(fSlow599))) + (4.822530864197531e-007f * faustpower<10>(fSlow599))) + (9.841899722852104e-009f * faustpower<12>(fSlow599))) + (1.5377968316956413e-010f * faustpower<14>(fSlow599))) + (1.898514607031656e-012f * faustpower<16>(fSlow599))) + (1.898514607031656e-014f * faustpower<18>(fSlow599))) + (1.5690203363897983e-016f * faustpower<20>(fSlow599))) + (1.0895974558262487e-018f * faustpower<22>(fSlow599))) + (6.697330183385451e-020f * faustpower<24>(fSlow599))) + (1.5283966662112614e-019f * faustpower<26>(fSlow599))) + (6.223149226587858e-020f * faustpower<28>(fSlow599))))) / fSlow6));
		float 	fSlow602 = (fConst77 * fSlow0);
		float 	fSlow603 = (0.004244131815783876f * sinf((0 - fSlow602)));
		float 	fSlow604 = min(fSlow1, (0 - fSlow603));
		float 	fSlow605 = (0.004244131815783876f * sinf(fSlow602));
		float 	fSlow606 = min(fSlow1, fSlow605);
		float 	fSlow607 = (1.736580679349052f * fSlow3);
		float 	fSlow608 = faustpower<2>(fSlow607);
		float 	fSlow609 = min(1.0f, ((1 + (fSlow608 * ((((((((((((((0.25f + (0.0625f * fSlow608)) + (0.006944444444444444f * faustpower<4>(fSlow607))) + (0.00043402777777777775f * faustpower<6>(fSlow607))) + (1.736111111111111e-005f * faustpower<8>(fSlow607))) + (4.822530864197531e-007f * faustpower<10>(fSlow607))) + (9.841899722852104e-009f * faustpower<12>(fSlow607))) + (1.5377968316956413e-010f * faustpower<14>(fSlow607))) + (1.898514607031656e-012f * faustpower<16>(fSlow607))) + (1.898514607031656e-014f * faustpower<18>(fSlow607))) + (1.5690203363897983e-016f * faustpower<20>(fSlow607))) + (1.0895974558262487e-018f * faustpower<22>(fSlow607))) + (6.697330183385451e-020f * faustpower<24>(fSlow607))) + (1.5283966662112614e-019f * faustpower<26>(fSlow607))) + (6.223149226587858e-020f * faustpower<28>(fSlow607))))) / fSlow6));
		float 	fSlow610 = (fConst78 * fSlow0);
		float 	fSlow611 = (0.004188287976102509f * sinf((0 - fSlow610)));
		float 	fSlow612 = min(fSlow1, (0 - fSlow611));
		float 	fSlow613 = (0.004188287976102509f * sinf(fSlow610));
		float 	fSlow614 = min(fSlow1, fSlow613);
		float 	fSlow615 = (1.6827725735634163f * fSlow3);
		float 	fSlow616 = faustpower<2>(fSlow615);
		float 	fSlow617 = min(1.0f, ((1 + (fSlow616 * ((((((((((((((0.25f + (0.0625f * fSlow616)) + (0.006944444444444444f * faustpower<4>(fSlow615))) + (0.00043402777777777775f * faustpower<6>(fSlow615))) + (1.736111111111111e-005f * faustpower<8>(fSlow615))) + (4.822530864197531e-007f * faustpower<10>(fSlow615))) + (9.841899722852104e-009f * faustpower<12>(fSlow615))) + (1.5377968316956413e-010f * faustpower<14>(fSlow615))) + (1.898514607031656e-012f * faustpower<16>(fSlow615))) + (1.898514607031656e-014f * faustpower<18>(fSlow615))) + (1.5690203363897983e-016f * faustpower<20>(fSlow615))) + (1.0895974558262487e-018f * faustpower<22>(fSlow615))) + (6.697330183385451e-020f * faustpower<24>(fSlow615))) + (1.5283966662112614e-019f * faustpower<26>(fSlow615))) + (6.223149226587858e-020f * faustpower<28>(fSlow615))))) / fSlow6));
		float 	fSlow618 = (fConst79 * fSlow0);
		float 	fSlow619 = (0.004133894625763516f * sinf((0 - fSlow618)));
		float 	fSlow620 = min(fSlow1, (0 - fSlow619));
		float 	fSlow621 = (0.004133894625763516f * sinf(fSlow618));
		float 	fSlow622 = min(fSlow1, fSlow621);
		float 	fSlow623 = (1.626437110197556f * fSlow3);
		float 	fSlow624 = faustpower<2>(fSlow623);
		float 	fSlow625 = min(1.0f, ((1 + (fSlow624 * ((((((((((((((0.25f + (0.0625f * fSlow624)) + (0.006944444444444444f * faustpower<4>(fSlow623))) + (0.00043402777777777775f * faustpower<6>(fSlow623))) + (1.736111111111111e-005f * faustpower<8>(fSlow623))) + (4.822530864197531e-007f * faustpower<10>(fSlow623))) + (9.841899722852104e-009f * faustpower<12>(fSlow623))) + (1.5377968316956413e-010f * faustpower<14>(fSlow623))) + (1.898514607031656e-012f * faustpower<16>(fSlow623))) + (1.898514607031656e-014f * faustpower<18>(fSlow623))) + (1.5690203363897983e-016f * faustpower<20>(fSlow623))) + (1.0895974558262487e-018f * faustpower<22>(fSlow623))) + (6.697330183385451e-020f * faustpower<24>(fSlow623))) + (1.5283966662112614e-019f * faustpower<26>(fSlow623))) + (6.223149226587858e-020f * faustpower<28>(fSlow623))))) / fSlow6));
		float 	fSlow626 = (fConst80 * fSlow0);
		float 	fSlow627 = (0.004080895976715265f * sinf((0 - fSlow626)));
		float 	fSlow628 = min(fSlow1, (0 - fSlow627));
		float 	fSlow629 = (0.004080895976715265f * sinf(fSlow626));
		float 	fSlow630 = min(fSlow1, fSlow629);
		float 	fSlow631 = (1.5673017811385328f * fSlow3);
		float 	fSlow632 = faustpower<2>(fSlow631);
		float 	fSlow633 = min(1.0f, ((1 + (fSlow632 * ((((((((((((((0.25f + (0.0625f * fSlow632)) + (0.006944444444444444f * faustpower<4>(fSlow631))) + (0.00043402777777777775f * faustpower<6>(fSlow631))) + (1.736111111111111e-005f * faustpower<8>(fSlow631))) + (4.822530864197531e-007f * faustpower<10>(fSlow631))) + (9.841899722852104e-009f * faustpower<12>(fSlow631))) + (1.5377968316956413e-010f * faustpower<14>(fSlow631))) + (1.898514607031656e-012f * faustpower<16>(fSlow631))) + (1.898514607031656e-014f * faustpower<18>(fSlow631))) + (1.5690203363897983e-016f * faustpower<20>(fSlow631))) + (1.0895974558262487e-018f * faustpower<22>(fSlow631))) + (6.697330183385451e-020f * faustpower<24>(fSlow631))) + (1.5283966662112614e-019f * faustpower<26>(fSlow631))) + (6.223149226587858e-020f * faustpower<28>(fSlow631))))) / fSlow6));
		float 	fSlow634 = (fConst81 * fSlow0);
		float 	fSlow635 = (0.004029239065617604f * sinf((0 - fSlow634)));
		float 	fSlow636 = min(fSlow1, (0 - fSlow635));
		float 	fSlow637 = (0.004029239065617604f * sinf(fSlow634));
		float 	fSlow638 = min(fSlow1, fSlow637);
		float 	fSlow639 = (1.5050365887691783f * fSlow3);
		float 	fSlow640 = faustpower<2>(fSlow639);
		float 	fSlow641 = min(1.0f, ((1 + (fSlow640 * ((((((((((((((0.25f + (0.0625f * fSlow640)) + (0.006944444444444444f * faustpower<4>(fSlow639))) + (0.00043402777777777775f * faustpower<6>(fSlow639))) + (1.736111111111111e-005f * faustpower<8>(fSlow639))) + (4.822530864197531e-007f * faustpower<10>(fSlow639))) + (9.841899722852104e-009f * faustpower<12>(fSlow639))) + (1.5377968316956413e-010f * faustpower<14>(fSlow639))) + (1.898514607031656e-012f * faustpower<16>(fSlow639))) + (1.898514607031656e-014f * faustpower<18>(fSlow639))) + (1.5690203363897983e-016f * faustpower<20>(fSlow639))) + (1.0895974558262487e-018f * faustpower<22>(fSlow639))) + (6.697330183385451e-020f * faustpower<24>(fSlow639))) + (1.5283966662112614e-019f * faustpower<26>(fSlow639))) + (6.223149226587858e-020f * faustpower<28>(fSlow639))))) / fSlow6));
		float 	fSlow642 = (fConst82 * fSlow0);
		float 	fSlow643 = (0.0039788735772973835f * sinf((0 - fSlow642)));
		float 	fSlow644 = min(fSlow1, (0 - fSlow643));
		float 	fSlow645 = (0.0039788735772973835f * sinf(fSlow642));
		float 	fSlow646 = min(fSlow1, fSlow645);
		float 	fSlow647 = (1.4392353714905768f * fSlow3);
		float 	fSlow648 = faustpower<2>(fSlow647);
		float 	fSlow649 = min(1.0f, ((1 + (fSlow648 * ((((((((((((((0.25f + (0.0625f * fSlow648)) + (0.006944444444444444f * faustpower<4>(fSlow647))) + (0.00043402777777777775f * faustpower<6>(fSlow647))) + (1.736111111111111e-005f * faustpower<8>(fSlow647))) + (4.822530864197531e-007f * faustpower<10>(fSlow647))) + (9.841899722852104e-009f * faustpower<12>(fSlow647))) + (1.5377968316956413e-010f * faustpower<14>(fSlow647))) + (1.898514607031656e-012f * faustpower<16>(fSlow647))) + (1.898514607031656e-014f * faustpower<18>(fSlow647))) + (1.5690203363897983e-016f * faustpower<20>(fSlow647))) + (1.0895974558262487e-018f * faustpower<22>(fSlow647))) + (6.697330183385451e-020f * faustpower<24>(fSlow647))) + (1.5283966662112614e-019f * faustpower<26>(fSlow647))) + (6.223149226587858e-020f * faustpower<28>(fSlow647))))) / fSlow6));
		float 	fSlow650 = (fConst83 * fSlow0);
		float 	fSlow651 = (0.003929751681281367f * sinf((0 - fSlow650)));
		float 	fSlow652 = min(fSlow1, (0 - fSlow651));
		float 	fSlow653 = (0.003929751681281367f * sinf(fSlow650));
		float 	fSlow654 = min(fSlow1, fSlow653);
		float 	fSlow655 = (1.3693884898767688f * fSlow3);
		float 	fSlow656 = faustpower<2>(fSlow655);
		float 	fSlow657 = min(1.0f, ((1 + (fSlow656 * ((((((((((((((0.25f + (0.0625f * fSlow656)) + (0.006944444444444444f * faustpower<4>(fSlow655))) + (0.00043402777777777775f * faustpower<6>(fSlow655))) + (1.736111111111111e-005f * faustpower<8>(fSlow655))) + (4.822530864197531e-007f * faustpower<10>(fSlow655))) + (9.841899722852104e-009f * faustpower<12>(fSlow655))) + (1.5377968316956413e-010f * faustpower<14>(fSlow655))) + (1.898514607031656e-012f * faustpower<16>(fSlow655))) + (1.898514607031656e-014f * faustpower<18>(fSlow655))) + (1.5690203363897983e-016f * faustpower<20>(fSlow655))) + (1.0895974558262487e-018f * faustpower<22>(fSlow655))) + (6.697330183385451e-020f * faustpower<24>(fSlow655))) + (1.5283966662112614e-019f * faustpower<26>(fSlow655))) + (6.223149226587858e-020f * faustpower<28>(fSlow655))))) / fSlow6));
		float 	fSlow658 = (fConst84 * fSlow0);
		float 	fSlow659 = (0.0038818278802901307f * sinf((0 - fSlow658)));
		float 	fSlow660 = min(fSlow1, (0 - fSlow659));
		float 	fSlow661 = (0.0038818278802901307f * sinf(fSlow658));
		float 	fSlow662 = min(fSlow1, fSlow661);
		float 	fSlow663 = (1.2948414105619437f * fSlow3);
		float 	fSlow664 = faustpower<2>(fSlow663);
		float 	fSlow665 = min(1.0f, ((1 + (fSlow664 * ((((((((((((((0.25f + (0.0625f * fSlow664)) + (0.006944444444444444f * faustpower<4>(fSlow663))) + (0.00043402777777777775f * faustpower<6>(fSlow663))) + (1.736111111111111e-005f * faustpower<8>(fSlow663))) + (4.822530864197531e-007f * faustpower<10>(fSlow663))) + (9.841899722852104e-009f * faustpower<12>(fSlow663))) + (1.5377968316956413e-010f * faustpower<14>(fSlow663))) + (1.898514607031656e-012f * faustpower<16>(fSlow663))) + (1.898514607031656e-014f * faustpower<18>(fSlow663))) + (1.5690203363897983e-016f * faustpower<20>(fSlow663))) + (1.0895974558262487e-018f * faustpower<22>(fSlow663))) + (6.697330183385451e-020f * faustpower<24>(fSlow663))) + (1.5283966662112614e-019f * faustpower<26>(fSlow663))) + (6.223149226587858e-020f * faustpower<28>(fSlow663))))) / fSlow6));
		float 	fSlow666 = (fConst85 * fSlow0);
		float 	fSlow667 = (0.003835058869684225f * sinf((0 - fSlow666)));
		float 	fSlow668 = min(fSlow1, (0 - fSlow667));
		float 	fSlow669 = (0.003835058869684225f * sinf(fSlow666));
		float 	fSlow670 = min(fSlow1, fSlow669);
		float 	fSlow671 = (1.214729097966627f * fSlow3);
		float 	fSlow672 = faustpower<2>(fSlow671);
		float 	fSlow673 = min(1.0f, ((1 + (fSlow672 * ((((((((((((((0.25f + (0.0625f * fSlow672)) + (0.006944444444444444f * faustpower<4>(fSlow671))) + (0.00043402777777777775f * faustpower<6>(fSlow671))) + (1.736111111111111e-005f * faustpower<8>(fSlow671))) + (4.822530864197531e-007f * faustpower<10>(fSlow671))) + (9.841899722852104e-009f * faustpower<12>(fSlow671))) + (1.5377968316956413e-010f * faustpower<14>(fSlow671))) + (1.898514607031656e-012f * faustpower<16>(fSlow671))) + (1.898514607031656e-014f * faustpower<18>(fSlow671))) + (1.5690203363897983e-016f * faustpower<20>(fSlow671))) + (1.0895974558262487e-018f * faustpower<22>(fSlow671))) + (6.697330183385451e-020f * faustpower<24>(fSlow671))) + (1.5283966662112614e-019f * faustpower<26>(fSlow671))) + (6.223149226587858e-020f * faustpower<28>(fSlow671))))) / fSlow6));
		float 	fSlow674 = (fConst86 * fSlow0);
		float 	fSlow675 = (0.003789403406949889f * sinf((0 - fSlow674)));
		float 	fSlow676 = min(fSlow1, (0 - fSlow675));
		float 	fSlow677 = (0.003789403406949889f * sinf(fSlow674));
		float 	fSlow678 = min(fSlow1, fSlow677);
		float 	fSlow679 = (1.12786627976427f * fSlow3);
		float 	fSlow680 = faustpower<2>(fSlow679);
		float 	fSlow681 = min(1.0f, ((1 + (fSlow680 * ((((((((((((((0.25f + (0.0625f * fSlow680)) + (0.006944444444444444f * faustpower<4>(fSlow679))) + (0.00043402777777777775f * faustpower<6>(fSlow679))) + (1.736111111111111e-005f * faustpower<8>(fSlow679))) + (4.822530864197531e-007f * faustpower<10>(fSlow679))) + (9.841899722852104e-009f * faustpower<12>(fSlow679))) + (1.5377968316956413e-010f * faustpower<14>(fSlow679))) + (1.898514607031656e-012f * faustpower<16>(fSlow679))) + (1.898514607031656e-014f * faustpower<18>(fSlow679))) + (1.5690203363897983e-016f * faustpower<20>(fSlow679))) + (1.0895974558262487e-018f * faustpower<22>(fSlow679))) + (6.697330183385451e-020f * faustpower<24>(fSlow679))) + (1.5283966662112614e-019f * faustpower<26>(fSlow679))) + (6.223149226587858e-020f * faustpower<28>(fSlow679))))) / fSlow6));
		float 	fSlow682 = (fConst87 * fSlow0);
		float 	fSlow683 = (0.0037448221903975372f * sinf((0 - fSlow682)));
		float 	fSlow684 = min(fSlow1, (0 - fSlow683));
		float 	fSlow685 = (0.0037448221903975372f * sinf(fSlow682));
		float 	fSlow686 = min(fSlow1, fSlow685);
		float 	fSlow687 = (1.032550710257603f * fSlow3);
		float 	fSlow688 = faustpower<2>(fSlow687);
		float 	fSlow689 = min(1.0f, ((1 + (fSlow688 * ((((((((((((((0.25f + (0.0625f * fSlow688)) + (0.006944444444444444f * faustpower<4>(fSlow687))) + (0.00043402777777777775f * faustpower<6>(fSlow687))) + (1.736111111111111e-005f * faustpower<8>(fSlow687))) + (4.822530864197531e-007f * faustpower<10>(fSlow687))) + (9.841899722852104e-009f * faustpower<12>(fSlow687))) + (1.5377968316956413e-010f * faustpower<14>(fSlow687))) + (1.898514607031656e-012f * faustpower<16>(fSlow687))) + (1.898514607031656e-014f * faustpower<18>(fSlow687))) + (1.5690203363897983e-016f * faustpower<20>(fSlow687))) + (1.0895974558262487e-018f * faustpower<22>(fSlow687))) + (6.697330183385451e-020f * faustpower<24>(fSlow687))) + (1.5283966662112614e-019f * faustpower<26>(fSlow687))) + (6.223149226587858e-020f * faustpower<28>(fSlow687))))) / fSlow6));
		float 	fSlow690 = (fConst88 * fSlow0);
		float 	fSlow691 = (0.0037012777463231476f * sinf((0 - fSlow690)));
		float 	fSlow692 = min(fSlow1, (0 - fSlow691));
		float 	fSlow693 = (0.0037012777463231476f * sinf(fSlow690));
		float 	fSlow694 = min(fSlow1, fSlow693);
		float 	fSlow695 = (0.9261763623194942f * fSlow3);
		float 	fSlow696 = faustpower<2>(fSlow695);
		float 	fSlow697 = min(1.0f, ((1 + (fSlow696 * ((((((((((((((0.25f + (0.0625f * fSlow696)) + (0.006944444444444444f * faustpower<4>(fSlow695))) + (0.00043402777777777775f * faustpower<6>(fSlow695))) + (1.736111111111111e-005f * faustpower<8>(fSlow695))) + (4.822530864197531e-007f * faustpower<10>(fSlow695))) + (9.841899722852104e-009f * faustpower<12>(fSlow695))) + (1.5377968316956413e-010f * faustpower<14>(fSlow695))) + (1.898514607031656e-012f * faustpower<16>(fSlow695))) + (1.898514607031656e-014f * faustpower<18>(fSlow695))) + (1.5690203363897983e-016f * faustpower<20>(fSlow695))) + (1.0895974558262487e-018f * faustpower<22>(fSlow695))) + (6.697330183385451e-020f * faustpower<24>(fSlow695))) + (1.5283966662112614e-019f * faustpower<26>(fSlow695))) + (6.223149226587858e-020f * faustpower<28>(fSlow695))))) / fSlow6));
		float 	fSlow698 = (fConst89 * fSlow0);
		float 	fSlow699 = (0.003658734323951617f * sinf((0 - fSlow698)));
		float 	fSlow700 = min(fSlow1, (0 - fSlow699));
		float 	fSlow701 = (0.003658734323951617f * sinf(fSlow698));
		float 	fSlow702 = min(fSlow1, fSlow701);
		float 	fSlow703 = (0.8043677017552168f * fSlow3);
		float 	fSlow704 = faustpower<2>(fSlow703);
		float 	fSlow705 = min(1.0f, ((1 + (fSlow704 * ((((((((((((((0.25f + (0.0625f * fSlow704)) + (0.006944444444444444f * faustpower<4>(fSlow703))) + (0.00043402777777777775f * faustpower<6>(fSlow703))) + (1.736111111111111e-005f * faustpower<8>(fSlow703))) + (4.822530864197531e-007f * faustpower<10>(fSlow703))) + (9.841899722852104e-009f * faustpower<12>(fSlow703))) + (1.5377968316956413e-010f * faustpower<14>(fSlow703))) + (1.898514607031656e-012f * faustpower<16>(fSlow703))) + (1.898514607031656e-014f * faustpower<18>(fSlow703))) + (1.5690203363897983e-016f * faustpower<20>(fSlow703))) + (1.0895974558262487e-018f * faustpower<22>(fSlow703))) + (6.697330183385451e-020f * faustpower<24>(fSlow703))) + (1.5283966662112614e-019f * faustpower<26>(fSlow703))) + (6.223149226587858e-020f * faustpower<28>(fSlow703))))) / fSlow6));
		float 	fSlow706 = (fConst90 * fSlow0);
		float 	fSlow707 = (0.0036171577975430765f * sinf((0 - fSlow706)));
		float 	fSlow708 = min(fSlow1, (0 - fSlow707));
		float 	fSlow709 = (0.0036171577975430765f * sinf(fSlow706));
		float 	fSlow710 = min(fSlow1, fSlow709);
		float 	fSlow711 = (0.6586161293016393f * fSlow3);
		float 	fSlow712 = faustpower<2>(fSlow711);
		float 	fSlow713 = min(1.0f, ((1 + (fSlow712 * ((((((((((((((0.25f + (0.0625f * fSlow712)) + (0.006944444444444444f * faustpower<4>(fSlow711))) + (0.00043402777777777775f * faustpower<6>(fSlow711))) + (1.736111111111111e-005f * faustpower<8>(fSlow711))) + (4.822530864197531e-007f * faustpower<10>(fSlow711))) + (9.841899722852104e-009f * faustpower<12>(fSlow711))) + (1.5377968316956413e-010f * faustpower<14>(fSlow711))) + (1.898514607031656e-012f * faustpower<16>(fSlow711))) + (1.898514607031656e-014f * faustpower<18>(fSlow711))) + (1.5690203363897983e-016f * faustpower<20>(fSlow711))) + (1.0895974558262487e-018f * faustpower<22>(fSlow711))) + (6.697330183385451e-020f * faustpower<24>(fSlow711))) + (1.5283966662112614e-019f * faustpower<26>(fSlow711))) + (6.223149226587858e-020f * faustpower<28>(fSlow711))))) / fSlow6));
		float 	fSlow714 = (fConst91 * fSlow0);
		float 	fSlow715 = (0.0035765155750987717f * sinf((0 - fSlow714)));
		float 	fSlow716 = min(fSlow1, (0 - fSlow715));
		float 	fSlow717 = (0.0035765155750987717f * sinf(fSlow714));
		float 	fSlow718 = min(fSlow1, fSlow717);
		float 	fSlow719 = (0.4670182786222422f * fSlow3);
		float 	fSlow720 = faustpower<2>(fSlow719);
		float 	fSlow721 = min(1.0f, ((1 + (fSlow720 * ((((((((((((((0.25f + (0.0625f * fSlow720)) + (0.006944444444444444f * faustpower<4>(fSlow719))) + (0.00043402777777777775f * faustpower<6>(fSlow719))) + (1.736111111111111e-005f * faustpower<8>(fSlow719))) + (4.822530864197531e-007f * faustpower<10>(fSlow719))) + (9.841899722852104e-009f * faustpower<12>(fSlow719))) + (1.5377968316956413e-010f * faustpower<14>(fSlow719))) + (1.898514607031656e-012f * faustpower<16>(fSlow719))) + (1.898514607031656e-014f * faustpower<18>(fSlow719))) + (1.5690203363897983e-016f * faustpower<20>(fSlow719))) + (1.0895974558262487e-018f * faustpower<22>(fSlow719))) + (6.697330183385451e-020f * faustpower<24>(fSlow719))) + (1.5283966662112614e-019f * faustpower<26>(fSlow719))) + (6.223149226587858e-020f * faustpower<28>(fSlow719))))) / fSlow6));
		float 	fSlow722 = powf(10,(0.05f * fentry2));
		float 	fSlow723 = (1 - fSlow1);
		float 	fSlow724 = (fSlow7 * min(fSlow723, fSlow2));
		float 	fSlow725 = min(fSlow723, fSlow723);
		float 	fSlow726 = min(fSlow723, fSlow11);
		float 	fSlow727 = min(fSlow723, (0 - fSlow13));
		float 	fSlow728 = min(fSlow723, fSlow19);
		float 	fSlow729 = min(fSlow723, (0 - fSlow21));
		float 	fSlow730 = min(fSlow723, fSlow27);
		float 	fSlow731 = min(fSlow723, (0 - fSlow29));
		float 	fSlow732 = min(fSlow723, fSlow35);
		float 	fSlow733 = min(fSlow723, (0 - fSlow37));
		float 	fSlow734 = min(fSlow723, fSlow43);
		float 	fSlow735 = min(fSlow723, (0 - fSlow45));
		float 	fSlow736 = min(fSlow723, fSlow51);
		float 	fSlow737 = min(fSlow723, (0 - fSlow53));
		float 	fSlow738 = min(fSlow723, fSlow59);
		float 	fSlow739 = min(fSlow723, (0 - fSlow61));
		float 	fSlow740 = min(fSlow723, fSlow67);
		float 	fSlow741 = min(fSlow723, (0 - fSlow69));
		float 	fSlow742 = min(fSlow723, fSlow75);
		float 	fSlow743 = min(fSlow723, (0 - fSlow77));
		float 	fSlow744 = min(fSlow723, fSlow83);
		float 	fSlow745 = min(fSlow723, (0 - fSlow85));
		float 	fSlow746 = min(fSlow723, fSlow91);
		float 	fSlow747 = min(fSlow723, (0 - fSlow93));
		float 	fSlow748 = min(fSlow723, fSlow99);
		float 	fSlow749 = min(fSlow723, (0 - fSlow101));
		float 	fSlow750 = min(fSlow723, fSlow107);
		float 	fSlow751 = min(fSlow723, (0 - fSlow109));
		float 	fSlow752 = min(fSlow723, fSlow115);
		float 	fSlow753 = min(fSlow723, (0 - fSlow117));
		float 	fSlow754 = min(fSlow723, fSlow123);
		float 	fSlow755 = min(fSlow723, (0 - fSlow125));
		float 	fSlow756 = min(fSlow723, fSlow131);
		float 	fSlow757 = min(fSlow723, (0 - fSlow133));
		float 	fSlow758 = min(fSlow723, fSlow139);
		float 	fSlow759 = min(fSlow723, (0 - fSlow141));
		float 	fSlow760 = min(fSlow723, fSlow147);
		float 	fSlow761 = min(fSlow723, (0 - fSlow149));
		float 	fSlow762 = min(fSlow723, fSlow155);
		float 	fSlow763 = min(fSlow723, (0 - fSlow157));
		float 	fSlow764 = min(fSlow723, fSlow163);
		float 	fSlow765 = min(fSlow723, (0 - fSlow165));
		float 	fSlow766 = min(fSlow723, fSlow171);
		float 	fSlow767 = min(fSlow723, (0 - fSlow173));
		float 	fSlow768 = min(fSlow723, fSlow179);
		float 	fSlow769 = min(fSlow723, (0 - fSlow181));
		float 	fSlow770 = min(fSlow723, fSlow187);
		float 	fSlow771 = min(fSlow723, (0 - fSlow189));
		float 	fSlow772 = min(fSlow723, fSlow195);
		float 	fSlow773 = min(fSlow723, (0 - fSlow197));
		float 	fSlow774 = min(fSlow723, fSlow203);
		float 	fSlow775 = min(fSlow723, (0 - fSlow205));
		float 	fSlow776 = min(fSlow723, fSlow211);
		float 	fSlow777 = min(fSlow723, (0 - fSlow213));
		float 	fSlow778 = min(fSlow723, fSlow219);
		float 	fSlow779 = min(fSlow723, (0 - fSlow221));
		float 	fSlow780 = min(fSlow723, fSlow227);
		float 	fSlow781 = min(fSlow723, (0 - fSlow229));
		float 	fSlow782 = min(fSlow723, fSlow235);
		float 	fSlow783 = min(fSlow723, (0 - fSlow237));
		float 	fSlow784 = min(fSlow723, fSlow243);
		float 	fSlow785 = min(fSlow723, (0 - fSlow245));
		float 	fSlow786 = min(fSlow723, fSlow251);
		float 	fSlow787 = min(fSlow723, (0 - fSlow253));
		float 	fSlow788 = min(fSlow723, fSlow259);
		float 	fSlow789 = min(fSlow723, (0 - fSlow261));
		float 	fSlow790 = min(fSlow723, fSlow267);
		float 	fSlow791 = min(fSlow723, (0 - fSlow269));
		float 	fSlow792 = min(fSlow723, fSlow275);
		float 	fSlow793 = min(fSlow723, (0 - fSlow277));
		float 	fSlow794 = min(fSlow723, fSlow283);
		float 	fSlow795 = min(fSlow723, (0 - fSlow285));
		float 	fSlow796 = min(fSlow723, fSlow291);
		float 	fSlow797 = min(fSlow723, (0 - fSlow293));
		float 	fSlow798 = min(fSlow723, fSlow299);
		float 	fSlow799 = min(fSlow723, (0 - fSlow301));
		float 	fSlow800 = min(fSlow723, fSlow307);
		float 	fSlow801 = min(fSlow723, (0 - fSlow309));
		float 	fSlow802 = min(fSlow723, fSlow315);
		float 	fSlow803 = min(fSlow723, (0 - fSlow317));
		float 	fSlow804 = min(fSlow723, fSlow323);
		float 	fSlow805 = min(fSlow723, (0 - fSlow325));
		float 	fSlow806 = min(fSlow723, fSlow331);
		float 	fSlow807 = min(fSlow723, (0 - fSlow333));
		float 	fSlow808 = min(fSlow723, fSlow339);
		float 	fSlow809 = min(fSlow723, (0 - fSlow341));
		float 	fSlow810 = min(fSlow723, fSlow347);
		float 	fSlow811 = min(fSlow723, (0 - fSlow349));
		float 	fSlow812 = min(fSlow723, fSlow355);
		float 	fSlow813 = min(fSlow723, (0 - fSlow357));
		float 	fSlow814 = min(fSlow723, fSlow363);
		float 	fSlow815 = min(fSlow723, (0 - fSlow365));
		float 	fSlow816 = min(fSlow723, fSlow371);
		float 	fSlow817 = min(fSlow723, (0 - fSlow373));
		float 	fSlow818 = min(fSlow723, fSlow379);
		float 	fSlow819 = min(fSlow723, (0 - fSlow381));
		float 	fSlow820 = min(fSlow723, fSlow387);
		float 	fSlow821 = min(fSlow723, (0 - fSlow389));
		float 	fSlow822 = min(fSlow723, fSlow395);
		float 	fSlow823 = min(fSlow723, (0 - fSlow397));
		float 	fSlow824 = min(fSlow723, fSlow403);
		float 	fSlow825 = min(fSlow723, (0 - fSlow405));
		float 	fSlow826 = min(fSlow723, fSlow411);
		float 	fSlow827 = min(fSlow723, (0 - fSlow413));
		float 	fSlow828 = min(fSlow723, fSlow419);
		float 	fSlow829 = min(fSlow723, (0 - fSlow421));
		float 	fSlow830 = min(fSlow723, fSlow427);
		float 	fSlow831 = min(fSlow723, (0 - fSlow429));
		float 	fSlow832 = min(fSlow723, fSlow435);
		float 	fSlow833 = min(fSlow723, (0 - fSlow437));
		float 	fSlow834 = min(fSlow723, fSlow443);
		float 	fSlow835 = min(fSlow723, (0 - fSlow445));
		float 	fSlow836 = min(fSlow723, fSlow451);
		float 	fSlow837 = min(fSlow723, (0 - fSlow453));
		float 	fSlow838 = min(fSlow723, fSlow459);
		float 	fSlow839 = min(fSlow723, (0 - fSlow461));
		float 	fSlow840 = min(fSlow723, fSlow467);
		float 	fSlow841 = min(fSlow723, (0 - fSlow469));
		float 	fSlow842 = min(fSlow723, fSlow475);
		float 	fSlow843 = min(fSlow723, (0 - fSlow477));
		float 	fSlow844 = min(fSlow723, fSlow483);
		float 	fSlow845 = min(fSlow723, (0 - fSlow485));
		float 	fSlow846 = min(fSlow723, fSlow491);
		float 	fSlow847 = min(fSlow723, (0 - fSlow493));
		float 	fSlow848 = min(fSlow723, fSlow499);
		float 	fSlow849 = min(fSlow723, (0 - fSlow501));
		float 	fSlow850 = min(fSlow723, fSlow507);
		float 	fSlow851 = min(fSlow723, (0 - fSlow509));
		float 	fSlow852 = min(fSlow723, fSlow515);
		float 	fSlow853 = min(fSlow723, (0 - fSlow517));
		float 	fSlow854 = min(fSlow723, fSlow523);
		float 	fSlow855 = min(fSlow723, (0 - fSlow525));
		float 	fSlow856 = min(fSlow723, fSlow531);
		float 	fSlow857 = min(fSlow723, (0 - fSlow533));
		float 	fSlow858 = min(fSlow723, fSlow539);
		float 	fSlow859 = min(fSlow723, (0 - fSlow541));
		float 	fSlow860 = min(fSlow723, fSlow547);
		float 	fSlow861 = min(fSlow723, (0 - fSlow549));
		float 	fSlow862 = min(fSlow723, fSlow555);
		float 	fSlow863 = min(fSlow723, (0 - fSlow557));
		float 	fSlow864 = min(fSlow723, fSlow563);
		float 	fSlow865 = min(fSlow723, (0 - fSlow565));
		float 	fSlow866 = min(fSlow723, fSlow571);
		float 	fSlow867 = min(fSlow723, (0 - fSlow573));
		float 	fSlow868 = min(fSlow723, fSlow579);
		float 	fSlow869 = min(fSlow723, (0 - fSlow581));
		float 	fSlow870 = min(fSlow723, fSlow587);
		float 	fSlow871 = min(fSlow723, (0 - fSlow589));
		float 	fSlow872 = min(fSlow723, fSlow595);
		float 	fSlow873 = min(fSlow723, (0 - fSlow597));
		float 	fSlow874 = min(fSlow723, fSlow603);
		float 	fSlow875 = min(fSlow723, (0 - fSlow605));
		float 	fSlow876 = min(fSlow723, fSlow611);
		float 	fSlow877 = min(fSlow723, (0 - fSlow613));
		float 	fSlow878 = min(fSlow723, fSlow619);
		float 	fSlow879 = min(fSlow723, (0 - fSlow621));
		float 	fSlow880 = min(fSlow723, fSlow627);
		float 	fSlow881 = min(fSlow723, (0 - fSlow629));
		float 	fSlow882 = min(fSlow723, fSlow635);
		float 	fSlow883 = min(fSlow723, (0 - fSlow637));
		float 	fSlow884 = min(fSlow723, fSlow643);
		float 	fSlow885 = min(fSlow723, (0 - fSlow645));
		float 	fSlow886 = min(fSlow723, fSlow651);
		float 	fSlow887 = min(fSlow723, (0 - fSlow653));
		float 	fSlow888 = min(fSlow723, fSlow659);
		float 	fSlow889 = min(fSlow723, (0 - fSlow661));
		float 	fSlow890 = min(fSlow723, fSlow667);
		float 	fSlow891 = min(fSlow723, (0 - fSlow669));
		float 	fSlow892 = min(fSlow723, fSlow675);
		float 	fSlow893 = min(fSlow723, (0 - fSlow677));
		float 	fSlow894 = min(fSlow723, fSlow683);
		float 	fSlow895 = min(fSlow723, (0 - fSlow685));
		float 	fSlow896 = min(fSlow723, fSlow691);
		float 	fSlow897 = min(fSlow723, (0 - fSlow693));
		float 	fSlow898 = min(fSlow723, fSlow699);
		float 	fSlow899 = min(fSlow723, (0 - fSlow701));
		float 	fSlow900 = min(fSlow723, fSlow707);
		float 	fSlow901 = min(fSlow723, (0 - fSlow709));
		float 	fSlow902 = min(fSlow723, fSlow715);
		float 	fSlow903 = min(fSlow723, (0 - fSlow717));
		float 	fSlow904 = powf(10,(0.05f * fentry3));
		float 	fSlow905 = (fConst92 * fentry4);
		int 	iSlow906 = int((fSlow905 - 1.99999f));
		int 	iSlow907 = (4 + iSlow906);
		int 	iSlow908 = int((int(iSlow907) & 511));
		float 	fSlow909 = (iSlow906 - fSlow905);
		int 	iSlow910 = (1 + iSlow906);
		float 	fSlow911 = (iSlow910 - fSlow905);
		float 	fSlow912 = (0 - fSlow911);
		int 	iSlow913 = (2 + iSlow906);
		float 	fSlow914 = (fSlow905 - iSlow913);
		int 	iSlow915 = (3 + iSlow906);
		float 	fSlow916 = (fSlow905 - iSlow915);
		float 	fSlow917 = (0.041666666666666664f * (((fSlow916 * fSlow914) * fSlow912) * fSlow909));
		int 	iSlow918 = int((int(iSlow915) & 511));
		float 	fSlow919 = (fSlow905 - iSlow906);
		float 	fSlow920 = (0.08333333333333333f * ((fSlow919 * fSlow914) * fSlow912));
		int 	iSlow921 = int((int(iSlow913) & 511));
		float 	fSlow922 = (0.08333333333333333f * (fSlow912 * fSlow909));
		int 	iSlow923 = int((iSlow906 & 511));
		float 	fSlow924 = (0.008333333333333333f * fSlow911);
		int 	iSlow925 = int((int(iSlow910) & 511));
		float 	fSlow926 = (0.041666666666666664f * fSlow919);
		float 	fSlow927 = (fSlow905 - iSlow907);
		int 	iSlow928 = (5 + iSlow906);
		float 	fSlow929 = (1.2e+002f * (fSlow905 - iSlow928));
		float 	fSlow930 = (0.01f * fentry5);
		float 	fSlow931 = (1.0f - fSlow930);
		int 	iSlow932 = int((int(iSlow928) & 511));
		float 	fSlow933 = ((((fSlow919 * fSlow927) * fSlow916) * fSlow914) * fSlow912);
		float 	fSlow934 = (0.008333333333333333f * powf(10,(0.05f * fentry6)));
		int index;
		for (index = 0; index <= fullcount - 32; index += 32) {
			// compute by blocks of 32 samples
			const int count = 32;
			FAUSTFLOAT* input0 = &input[0][index];
			FAUSTFLOAT* input1 = &input[1][index];
			FAUSTFLOAT* output0 = &output[0][index];
			FAUSTFLOAT* output1 = &output[1][index];
			// SECTION : 1
			// LOOP 0x17028f10
			// exec code
			for (int i=0; i<count; i++) {
				fZec0[i] = ((float)input0[i] + (float)input1[i]);
			}
			
			// SECTION : 2
			// LOOP 0x17028e98
			// exec code
			for (int i=0; i<count; i++) {
				fZec1[i] = faustpower<4>(fZec0[i]);
			}
			
			// LOOP 0x1742ddb8
			// exec code
			for (int i=0; i<count; i++) {
				fZec2[i] = ((float)input0[i] - (float)input1[i]);
			}
			
			// SECTION : 3
			// LOOP 0x17028cc0
			// pre processing
			fYec0_idx = (fYec0_idx+fYec0_idx_save)&255;
			// exec code
			for (int i=0; i<count; i++) {
				fYec0[(fYec0_idx+i)&255] = min(0.5f, max(-0.5f, (fZec1[i] * (0 - (0.03125f * ((float)input1[i] - (float)input0[i]))))));
			}
			// post processing
			fYec0_idx_save = count;
			
			// LOOP 0x1742dd40
			// exec code
			for (int i=0; i<count; i++) {
				fZec3[i] = (fSlow930 * min((float)1, max((float)-1, (fZec0[i] * (0 - (0.03125f * faustpower<4>(fZec2[i])))))));
			}
			
			// LOOP 0x1742e178
			// pre processing
			fYec3_idx = (fYec3_idx+fYec3_idx_save)&255;
			// exec code
			for (int i=0; i<count; i++) {
				fYec3[(fYec3_idx+i)&255] = min(0.5f, max(-0.5f, (fZec1[i] * (0 - (0.03125f * fZec2[i])))));
			}
			// post processing
			fYec3_idx_save = count;
			
			// SECTION : 4
			// LOOP 0x17028c48
			// pre processing
			fYec1_idx = (fYec1_idx+fYec1_idx_save)&1023;
			// exec code
			for (int i=0; i<count; i++) {
				fYec1[(fYec1_idx+i)&1023] = ((fSlow904 * ((fSlow721 * ((fSlow903 * fYec0[(fYec0_idx+i-179)&255]) + (fSlow902 * fYec0[(fYec0_idx+i-1)&255]))) + ((fSlow713 * ((fSlow901 * fYec0[(fYec0_idx+i-178)&255]) + (fSlow900 * fYec0[(fYec0_idx+i-2)&255]))) + ((fSlow705 * ((fSlow899 * fYec0[(fYec0_idx+i-177)&255]) + (fSlow898 * fYec0[(fYec0_idx+i-3)&255]))) + ((fSlow697 * ((fSlow897 * fYec0[(fYec0_idx+i-176)&255]) + (fSlow896 * fYec0[(fYec0_idx+i-4)&255]))) + ((fSlow689 * ((fSlow895 * fYec0[(fYec0_idx+i-175)&255]) + (fSlow894 * fYec0[(fYec0_idx+i-5)&255]))) + ((fSlow681 * ((fSlow893 * fYec0[(fYec0_idx+i-174)&255]) + (fSlow892 * fYec0[(fYec0_idx+i-6)&255]))) + ((fSlow673 * ((fSlow891 * fYec0[(fYec0_idx+i-173)&255]) + (fSlow890 * fYec0[(fYec0_idx+i-7)&255]))) + ((fSlow665 * ((fSlow889 * fYec0[(fYec0_idx+i-172)&255]) + (fSlow888 * fYec0[(fYec0_idx+i-8)&255]))) + ((fSlow657 * ((fSlow887 * fYec0[(fYec0_idx+i-171)&255]) + (fSlow886 * fYec0[(fYec0_idx+i-9)&255]))) + ((fSlow649 * ((fSlow885 * fYec0[(fYec0_idx+i-170)&255]) + (fSlow884 * fYec0[(fYec0_idx+i-10)&255]))) + ((fSlow641 * ((fSlow883 * fYec0[(fYec0_idx+i-169)&255]) + (fSlow882 * fYec0[(fYec0_idx+i-11)&255]))) + ((fSlow633 * ((fSlow881 * fYec0[(fYec0_idx+i-168)&255]) + (fSlow880 * fYec0[(fYec0_idx+i-12)&255]))) + ((fSlow625 * ((fSlow879 * fYec0[(fYec0_idx+i-167)&255]) + (fSlow878 * fYec0[(fYec0_idx+i-13)&255]))) + ((fSlow617 * ((fSlow877 * fYec0[(fYec0_idx+i-166)&255]) + (fSlow876 * fYec0[(fYec0_idx+i-14)&255]))) + ((fSlow609 * ((fSlow875 * fYec0[(fYec0_idx+i-165)&255]) + (fSlow874 * fYec0[(fYec0_idx+i-15)&255]))) + ((fSlow601 * ((fSlow873 * fYec0[(fYec0_idx+i-164)&255]) + (fSlow872 * fYec0[(fYec0_idx+i-16)&255]))) + ((fSlow593 * ((fSlow871 * fYec0[(fYec0_idx+i-163)&255]) + (fSlow870 * fYec0[(fYec0_idx+i-17)&255]))) + ((fSlow585 * ((fSlow869 * fYec0[(fYec0_idx+i-162)&255]) + (fSlow868 * fYec0[(fYec0_idx+i-18)&255]))) + ((fSlow577 * ((fSlow867 * fYec0[(fYec0_idx+i-161)&255]) + (fSlow866 * fYec0[(fYec0_idx+i-19)&255]))) + ((fSlow569 * ((fSlow865 * fYec0[(fYec0_idx+i-160)&255]) + (fSlow864 * fYec0[(fYec0_idx+i-20)&255]))) + ((fSlow561 * ((fSlow863 * fYec0[(fYec0_idx+i-159)&255]) + (fSlow862 * fYec0[(fYec0_idx+i-21)&255]))) + ((fSlow553 * ((fSlow861 * fYec0[(fYec0_idx+i-158)&255]) + (fSlow860 * fYec0[(fYec0_idx+i-22)&255]))) + ((fSlow545 * ((fSlow859 * fYec0[(fYec0_idx+i-157)&255]) + (fSlow858 * fYec0[(fYec0_idx+i-23)&255]))) + ((fSlow537 * ((fSlow857 * fYec0[(fYec0_idx+i-156)&255]) + (fSlow856 * fYec0[(fYec0_idx+i-24)&255]))) + ((fSlow529 * ((fSlow855 * fYec0[(fYec0_idx+i-155)&255]) + (fSlow854 * fYec0[(fYec0_idx+i-25)&255]))) + ((fSlow521 * ((fSlow853 * fYec0[(fYec0_idx+i-154)&255]) + (fSlow852 * fYec0[(fYec0_idx+i-26)&255]))) + ((fSlow513 * ((fSlow851 * fYec0[(fYec0_idx+i-153)&255]) + (fSlow850 * fYec0[(fYec0_idx+i-27)&255]))) + ((fSlow505 * ((fSlow849 * fYec0[(fYec0_idx+i-152)&255]) + (fSlow848 * fYec0[(fYec0_idx+i-28)&255]))) + ((fSlow497 * ((fSlow847 * fYec0[(fYec0_idx+i-151)&255]) + (fSlow846 * fYec0[(fYec0_idx+i-29)&255]))) + ((fSlow489 * ((fSlow845 * fYec0[(fYec0_idx+i-150)&255]) + (fSlow844 * fYec0[(fYec0_idx+i-30)&255]))) + ((fSlow481 * ((fSlow843 * fYec0[(fYec0_idx+i-149)&255]) + (fSlow842 * fYec0[(fYec0_idx+i-31)&255]))) + ((fSlow473 * ((fSlow841 * fYec0[(fYec0_idx+i-148)&255]) + (fSlow840 * fYec0[(fYec0_idx+i-32)&255]))) + ((fSlow465 * ((fSlow839 * fYec0[(fYec0_idx+i-147)&255]) + (fSlow838 * fYec0[(fYec0_idx+i-33)&255]))) + ((fSlow457 * ((fSlow837 * fYec0[(fYec0_idx+i-146)&255]) + (fSlow836 * fYec0[(fYec0_idx+i-34)&255]))) + ((fSlow449 * ((fSlow835 * fYec0[(fYec0_idx+i-145)&255]) + (fSlow834 * fYec0[(fYec0_idx+i-35)&255]))) + ((fSlow441 * ((fSlow833 * fYec0[(fYec0_idx+i-144)&255]) + (fSlow832 * fYec0[(fYec0_idx+i-36)&255]))) + ((fSlow433 * ((fSlow831 * fYec0[(fYec0_idx+i-143)&255]) + (fSlow830 * fYec0[(fYec0_idx+i-37)&255]))) + ((fSlow425 * ((fSlow829 * fYec0[(fYec0_idx+i-142)&255]) + (fSlow828 * fYec0[(fYec0_idx+i-38)&255]))) + ((fSlow417 * ((fSlow827 * fYec0[(fYec0_idx+i-141)&255]) + (fSlow826 * fYec0[(fYec0_idx+i-39)&255]))) + ((fSlow409 * ((fSlow825 * fYec0[(fYec0_idx+i-140)&255]) + (fSlow824 * fYec0[(fYec0_idx+i-40)&255]))) + ((fSlow401 * ((fSlow823 * fYec0[(fYec0_idx+i-139)&255]) + (fSlow822 * fYec0[(fYec0_idx+i-41)&255]))) + ((fSlow393 * ((fSlow821 * fYec0[(fYec0_idx+i-138)&255]) + (fSlow820 * fYec0[(fYec0_idx+i-42)&255]))) + ((fSlow385 * ((fSlow819 * fYec0[(fYec0_idx+i-137)&255]) + (fSlow818 * fYec0[(fYec0_idx+i-43)&255]))) + ((fSlow377 * ((fSlow817 * fYec0[(fYec0_idx+i-136)&255]) + (fSlow816 * fYec0[(fYec0_idx+i-44)&255]))) + ((fSlow369 * ((fSlow815 * fYec0[(fYec0_idx+i-135)&255]) + (fSlow814 * fYec0[(fYec0_idx+i-45)&255]))) + ((fSlow361 * ((fSlow813 * fYec0[(fYec0_idx+i-134)&255]) + (fSlow812 * fYec0[(fYec0_idx+i-46)&255]))) + ((fSlow353 * ((fSlow811 * fYec0[(fYec0_idx+i-133)&255]) + (fSlow810 * fYec0[(fYec0_idx+i-47)&255]))) + ((fSlow345 * ((fSlow809 * fYec0[(fYec0_idx+i-132)&255]) + (fSlow808 * fYec0[(fYec0_idx+i-48)&255]))) + ((fSlow337 * ((fSlow807 * fYec0[(fYec0_idx+i-131)&255]) + (fSlow806 * fYec0[(fYec0_idx+i-49)&255]))) + ((fSlow329 * ((fSlow805 * fYec0[(fYec0_idx+i-130)&255]) + (fSlow804 * fYec0[(fYec0_idx+i-50)&255]))) + ((fSlow321 * ((fSlow803 * fYec0[(fYec0_idx+i-129)&255]) + (fSlow802 * fYec0[(fYec0_idx+i-51)&255]))) + ((fSlow313 * ((fSlow801 * fYec0[(fYec0_idx+i-128)&255]) + (fSlow800 * fYec0[(fYec0_idx+i-52)&255]))) + ((fSlow305 * ((fSlow799 * fYec0[(fYec0_idx+i-127)&255]) + (fSlow798 * fYec0[(fYec0_idx+i-53)&255]))) + ((fSlow297 * ((fSlow797 * fYec0[(fYec0_idx+i-126)&255]) + (fSlow796 * fYec0[(fYec0_idx+i-54)&255]))) + ((fSlow289 * ((fSlow795 * fYec0[(fYec0_idx+i-125)&255]) + (fSlow794 * fYec0[(fYec0_idx+i-55)&255]))) + ((fSlow281 * ((fSlow793 * fYec0[(fYec0_idx+i-124)&255]) + (fSlow792 * fYec0[(fYec0_idx+i-56)&255]))) + ((fSlow273 * ((fSlow791 * fYec0[(fYec0_idx+i-123)&255]) + (fSlow790 * fYec0[(fYec0_idx+i-57)&255]))) + ((fSlow265 * ((fSlow789 * fYec0[(fYec0_idx+i-122)&255]) + (fSlow788 * fYec0[(fYec0_idx+i-58)&255]))) + ((fSlow257 * ((fSlow787 * fYec0[(fYec0_idx+i-121)&255]) + (fSlow786 * fYec0[(fYec0_idx+i-59)&255]))) + ((fSlow249 * ((fSlow785 * fYec0[(fYec0_idx+i-120)&255]) + (fSlow784 * fYec0[(fYec0_idx+i-60)&255]))) + ((fSlow241 * ((fSlow783 * fYec0[(fYec0_idx+i-119)&255]) + (fSlow782 * fYec0[(fYec0_idx+i-61)&255]))) + ((fSlow233 * ((fSlow781 * fYec0[(fYec0_idx+i-118)&255]) + (fSlow780 * fYec0[(fYec0_idx+i-62)&255]))) + ((fSlow225 * ((fSlow779 * fYec0[(fYec0_idx+i-117)&255]) + (fSlow778 * fYec0[(fYec0_idx+i-63)&255]))) + ((fSlow217 * ((fSlow777 * fYec0[(fYec0_idx+i-116)&255]) + (fSlow776 * fYec0[(fYec0_idx+i-64)&255]))) + ((fSlow209 * ((fSlow775 * fYec0[(fYec0_idx+i-115)&255]) + (fSlow774 * fYec0[(fYec0_idx+i-65)&255]))) + ((fSlow201 * ((fSlow773 * fYec0[(fYec0_idx+i-114)&255]) + (fSlow772 * fYec0[(fYec0_idx+i-66)&255]))) + ((fSlow193 * ((fSlow771 * fYec0[(fYec0_idx+i-113)&255]) + (fSlow770 * fYec0[(fYec0_idx+i-67)&255]))) + ((fSlow185 * ((fSlow769 * fYec0[(fYec0_idx+i-112)&255]) + (fSlow768 * fYec0[(fYec0_idx+i-68)&255]))) + ((fSlow177 * ((fSlow767 * fYec0[(fYec0_idx+i-111)&255]) + (fSlow766 * fYec0[(fYec0_idx+i-69)&255]))) + ((fSlow169 * ((fSlow765 * fYec0[(fYec0_idx+i-110)&255]) + (fSlow764 * fYec0[(fYec0_idx+i-70)&255]))) + ((fSlow161 * ((fSlow763 * fYec0[(fYec0_idx+i-109)&255]) + (fSlow762 * fYec0[(fYec0_idx+i-71)&255]))) + ((fSlow153 * ((fSlow761 * fYec0[(fYec0_idx+i-108)&255]) + (fSlow760 * fYec0[(fYec0_idx+i-72)&255]))) + ((fSlow145 * ((fSlow759 * fYec0[(fYec0_idx+i-107)&255]) + (fSlow758 * fYec0[(fYec0_idx+i-73)&255]))) + ((fSlow137 * ((fSlow757 * fYec0[(fYec0_idx+i-106)&255]) + (fSlow756 * fYec0[(fYec0_idx+i-74)&255]))) + ((fSlow129 * ((fSlow755 * fYec0[(fYec0_idx+i-105)&255]) + (fSlow754 * fYec0[(fYec0_idx+i-75)&255]))) + ((fSlow121 * ((fSlow753 * fYec0[(fYec0_idx+i-104)&255]) + (fSlow752 * fYec0[(fYec0_idx+i-76)&255]))) + ((fSlow113 * ((fSlow751 * fYec0[(fYec0_idx+i-103)&255]) + (fSlow750 * fYec0[(fYec0_idx+i-77)&255]))) + ((fSlow105 * ((fSlow749 * fYec0[(fYec0_idx+i-102)&255]) + (fSlow748 * fYec0[(fYec0_idx+i-78)&255]))) + ((fSlow97 * ((fSlow747 * fYec0[(fYec0_idx+i-101)&255]) + (fSlow746 * fYec0[(fYec0_idx+i-79)&255]))) + ((fSlow89 * ((fSlow745 * fYec0[(fYec0_idx+i-100)&255]) + (fSlow744 * fYec0[(fYec0_idx+i-80)&255]))) + ((fSlow81 * ((fSlow743 * fYec0[(fYec0_idx+i-99)&255]) + (fSlow742 * fYec0[(fYec0_idx+i-81)&255]))) + ((fSlow73 * ((fSlow741 * fYec0[(fYec0_idx+i-98)&255]) + (fSlow740 * fYec0[(fYec0_idx+i-82)&255]))) + ((fSlow65 * ((fSlow739 * fYec0[(fYec0_idx+i-97)&255]) + (fSlow738 * fYec0[(fYec0_idx+i-83)&255]))) + ((fSlow57 * ((fSlow737 * fYec0[(fYec0_idx+i-96)&255]) + (fSlow736 * fYec0[(fYec0_idx+i-84)&255]))) + ((fSlow49 * ((fSlow735 * fYec0[(fYec0_idx+i-95)&255]) + (fSlow734 * fYec0[(fYec0_idx+i-85)&255]))) + ((fSlow41 * ((fSlow733 * fYec0[(fYec0_idx+i-94)&255]) + (fSlow732 * fYec0[(fYec0_idx+i-86)&255]))) + ((fSlow33 * ((fSlow731 * fYec0[(fYec0_idx+i-93)&255]) + (fSlow730 * fYec0[(fYec0_idx+i-87)&255]))) + ((fSlow25 * ((fSlow729 * fYec0[(fYec0_idx+i-92)&255]) + (fSlow728 * fYec0[(fYec0_idx+i-88)&255]))) + ((fSlow17 * ((fSlow727 * fYec0[(fYec0_idx+i-91)&255]) + (fSlow726 * fYec0[(fYec0_idx+i-89)&255]))) + ((fSlow725 * fYec0[(fYec0_idx+i-90)&255]) + (fSlow724 * fYec0[(fYec0_idx+i) & 255])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (fSlow722 * ((fSlow721 * ((fSlow718 * fYec0[(fYec0_idx+i-179)&255]) + (fSlow716 * fYec0[(fYec0_idx+i-1)&255]))) + ((fSlow713 * ((fSlow710 * fYec0[(fYec0_idx+i-178)&255]) + (fSlow708 * fYec0[(fYec0_idx+i-2)&255]))) + ((fSlow705 * ((fSlow702 * fYec0[(fYec0_idx+i-177)&255]) + (fSlow700 * fYec0[(fYec0_idx+i-3)&255]))) + ((fSlow697 * ((fSlow694 * fYec0[(fYec0_idx+i-176)&255]) + (fSlow692 * fYec0[(fYec0_idx+i-4)&255]))) + ((fSlow689 * ((fSlow686 * fYec0[(fYec0_idx+i-175)&255]) + (fSlow684 * fYec0[(fYec0_idx+i-5)&255]))) + ((fSlow681 * ((fSlow678 * fYec0[(fYec0_idx+i-174)&255]) + (fSlow676 * fYec0[(fYec0_idx+i-6)&255]))) + ((fSlow673 * ((fSlow670 * fYec0[(fYec0_idx+i-173)&255]) + (fSlow668 * fYec0[(fYec0_idx+i-7)&255]))) + ((fSlow665 * ((fSlow662 * fYec0[(fYec0_idx+i-172)&255]) + (fSlow660 * fYec0[(fYec0_idx+i-8)&255]))) + ((fSlow657 * ((fSlow654 * fYec0[(fYec0_idx+i-171)&255]) + (fSlow652 * fYec0[(fYec0_idx+i-9)&255]))) + ((fSlow649 * ((fSlow646 * fYec0[(fYec0_idx+i-170)&255]) + (fSlow644 * fYec0[(fYec0_idx+i-10)&255]))) + ((fSlow641 * ((fSlow638 * fYec0[(fYec0_idx+i-169)&255]) + (fSlow636 * fYec0[(fYec0_idx+i-11)&255]))) + ((fSlow633 * ((fSlow630 * fYec0[(fYec0_idx+i-168)&255]) + (fSlow628 * fYec0[(fYec0_idx+i-12)&255]))) + ((fSlow625 * ((fSlow622 * fYec0[(fYec0_idx+i-167)&255]) + (fSlow620 * fYec0[(fYec0_idx+i-13)&255]))) + ((fSlow617 * ((fSlow614 * fYec0[(fYec0_idx+i-166)&255]) + (fSlow612 * fYec0[(fYec0_idx+i-14)&255]))) + ((fSlow609 * ((fSlow606 * fYec0[(fYec0_idx+i-165)&255]) + (fSlow604 * fYec0[(fYec0_idx+i-15)&255]))) + ((fSlow601 * ((fSlow598 * fYec0[(fYec0_idx+i-164)&255]) + (fSlow596 * fYec0[(fYec0_idx+i-16)&255]))) + ((fSlow593 * ((fSlow590 * fYec0[(fYec0_idx+i-163)&255]) + (fSlow588 * fYec0[(fYec0_idx+i-17)&255]))) + ((fSlow585 * ((fSlow582 * fYec0[(fYec0_idx+i-162)&255]) + (fSlow580 * fYec0[(fYec0_idx+i-18)&255]))) + ((fSlow577 * ((fSlow574 * fYec0[(fYec0_idx+i-161)&255]) + (fSlow572 * fYec0[(fYec0_idx+i-19)&255]))) + ((fSlow569 * ((fSlow566 * fYec0[(fYec0_idx+i-160)&255]) + (fSlow564 * fYec0[(fYec0_idx+i-20)&255]))) + ((fSlow561 * ((fSlow558 * fYec0[(fYec0_idx+i-159)&255]) + (fSlow556 * fYec0[(fYec0_idx+i-21)&255]))) + ((fSlow553 * ((fSlow550 * fYec0[(fYec0_idx+i-158)&255]) + (fSlow548 * fYec0[(fYec0_idx+i-22)&255]))) + ((fSlow545 * ((fSlow542 * fYec0[(fYec0_idx+i-157)&255]) + (fSlow540 * fYec0[(fYec0_idx+i-23)&255]))) + ((fSlow537 * ((fSlow534 * fYec0[(fYec0_idx+i-156)&255]) + (fSlow532 * fYec0[(fYec0_idx+i-24)&255]))) + ((fSlow529 * ((fSlow526 * fYec0[(fYec0_idx+i-155)&255]) + (fSlow524 * fYec0[(fYec0_idx+i-25)&255]))) + ((fSlow521 * ((fSlow518 * fYec0[(fYec0_idx+i-154)&255]) + (fSlow516 * fYec0[(fYec0_idx+i-26)&255]))) + ((fSlow513 * ((fSlow510 * fYec0[(fYec0_idx+i-153)&255]) + (fSlow508 * fYec0[(fYec0_idx+i-27)&255]))) + ((fSlow505 * ((fSlow502 * fYec0[(fYec0_idx+i-152)&255]) + (fSlow500 * fYec0[(fYec0_idx+i-28)&255]))) + ((fSlow497 * ((fSlow494 * fYec0[(fYec0_idx+i-151)&255]) + (fSlow492 * fYec0[(fYec0_idx+i-29)&255]))) + ((fSlow489 * ((fSlow486 * fYec0[(fYec0_idx+i-150)&255]) + (fSlow484 * fYec0[(fYec0_idx+i-30)&255]))) + ((fSlow481 * ((fSlow478 * fYec0[(fYec0_idx+i-149)&255]) + (fSlow476 * fYec0[(fYec0_idx+i-31)&255]))) + ((fSlow473 * ((fSlow470 * fYec0[(fYec0_idx+i-148)&255]) + (fSlow468 * fYec0[(fYec0_idx+i-32)&255]))) + ((fSlow465 * ((fSlow462 * fYec0[(fYec0_idx+i-147)&255]) + (fSlow460 * fYec0[(fYec0_idx+i-33)&255]))) + ((fSlow457 * ((fSlow454 * fYec0[(fYec0_idx+i-146)&255]) + (fSlow452 * fYec0[(fYec0_idx+i-34)&255]))) + ((fSlow449 * ((fSlow446 * fYec0[(fYec0_idx+i-145)&255]) + (fSlow444 * fYec0[(fYec0_idx+i-35)&255]))) + ((fSlow441 * ((fSlow438 * fYec0[(fYec0_idx+i-144)&255]) + (fSlow436 * fYec0[(fYec0_idx+i-36)&255]))) + ((fSlow433 * ((fSlow430 * fYec0[(fYec0_idx+i-143)&255]) + (fSlow428 * fYec0[(fYec0_idx+i-37)&255]))) + ((fSlow425 * ((fSlow422 * fYec0[(fYec0_idx+i-142)&255]) + (fSlow420 * fYec0[(fYec0_idx+i-38)&255]))) + ((fSlow417 * ((fSlow414 * fYec0[(fYec0_idx+i-141)&255]) + (fSlow412 * fYec0[(fYec0_idx+i-39)&255]))) + ((fSlow409 * ((fSlow406 * fYec0[(fYec0_idx+i-140)&255]) + (fSlow404 * fYec0[(fYec0_idx+i-40)&255]))) + ((fSlow401 * ((fSlow398 * fYec0[(fYec0_idx+i-139)&255]) + (fSlow396 * fYec0[(fYec0_idx+i-41)&255]))) + ((fSlow393 * ((fSlow390 * fYec0[(fYec0_idx+i-138)&255]) + (fSlow388 * fYec0[(fYec0_idx+i-42)&255]))) + ((fSlow385 * ((fSlow382 * fYec0[(fYec0_idx+i-137)&255]) + (fSlow380 * fYec0[(fYec0_idx+i-43)&255]))) + ((fSlow377 * ((fSlow374 * fYec0[(fYec0_idx+i-136)&255]) + (fSlow372 * fYec0[(fYec0_idx+i-44)&255]))) + ((fSlow369 * ((fSlow366 * fYec0[(fYec0_idx+i-135)&255]) + (fSlow364 * fYec0[(fYec0_idx+i-45)&255]))) + ((fSlow361 * ((fSlow358 * fYec0[(fYec0_idx+i-134)&255]) + (fSlow356 * fYec0[(fYec0_idx+i-46)&255]))) + ((fSlow353 * ((fSlow350 * fYec0[(fYec0_idx+i-133)&255]) + (fSlow348 * fYec0[(fYec0_idx+i-47)&255]))) + ((fSlow345 * ((fSlow342 * fYec0[(fYec0_idx+i-132)&255]) + (fSlow340 * fYec0[(fYec0_idx+i-48)&255]))) + ((fSlow337 * ((fSlow334 * fYec0[(fYec0_idx+i-131)&255]) + (fSlow332 * fYec0[(fYec0_idx+i-49)&255]))) + ((fSlow329 * ((fSlow326 * fYec0[(fYec0_idx+i-130)&255]) + (fSlow324 * fYec0[(fYec0_idx+i-50)&255]))) + ((fSlow321 * ((fSlow318 * fYec0[(fYec0_idx+i-129)&255]) + (fSlow316 * fYec0[(fYec0_idx+i-51)&255]))) + ((fSlow313 * ((fSlow310 * fYec0[(fYec0_idx+i-128)&255]) + (fSlow308 * fYec0[(fYec0_idx+i-52)&255]))) + ((fSlow305 * ((fSlow302 * fYec0[(fYec0_idx+i-127)&255]) + (fSlow300 * fYec0[(fYec0_idx+i-53)&255]))) + ((fSlow297 * ((fSlow294 * fYec0[(fYec0_idx+i-126)&255]) + (fSlow292 * fYec0[(fYec0_idx+i-54)&255]))) + ((fSlow289 * ((fSlow286 * fYec0[(fYec0_idx+i-125)&255]) + (fSlow284 * fYec0[(fYec0_idx+i-55)&255]))) + ((fSlow281 * ((fSlow278 * fYec0[(fYec0_idx+i-124)&255]) + (fSlow276 * fYec0[(fYec0_idx+i-56)&255]))) + ((fSlow273 * ((fSlow270 * fYec0[(fYec0_idx+i-123)&255]) + (fSlow268 * fYec0[(fYec0_idx+i-57)&255]))) + ((fSlow265 * ((fSlow262 * fYec0[(fYec0_idx+i-122)&255]) + (fSlow260 * fYec0[(fYec0_idx+i-58)&255]))) + ((fSlow257 * ((fSlow254 * fYec0[(fYec0_idx+i-121)&255]) + (fSlow252 * fYec0[(fYec0_idx+i-59)&255]))) + ((fSlow249 * ((fSlow246 * fYec0[(fYec0_idx+i-120)&255]) + (fSlow244 * fYec0[(fYec0_idx+i-60)&255]))) + ((fSlow241 * ((fSlow238 * fYec0[(fYec0_idx+i-119)&255]) + (fSlow236 * fYec0[(fYec0_idx+i-61)&255]))) + ((fSlow233 * ((fSlow230 * fYec0[(fYec0_idx+i-118)&255]) + (fSlow228 * fYec0[(fYec0_idx+i-62)&255]))) + ((fSlow225 * ((fSlow222 * fYec0[(fYec0_idx+i-117)&255]) + (fSlow220 * fYec0[(fYec0_idx+i-63)&255]))) + ((fSlow217 * ((fSlow214 * fYec0[(fYec0_idx+i-116)&255]) + (fSlow212 * fYec0[(fYec0_idx+i-64)&255]))) + ((fSlow209 * ((fSlow206 * fYec0[(fYec0_idx+i-115)&255]) + (fSlow204 * fYec0[(fYec0_idx+i-65)&255]))) + ((fSlow201 * ((fSlow198 * fYec0[(fYec0_idx+i-114)&255]) + (fSlow196 * fYec0[(fYec0_idx+i-66)&255]))) + ((fSlow193 * ((fSlow190 * fYec0[(fYec0_idx+i-113)&255]) + (fSlow188 * fYec0[(fYec0_idx+i-67)&255]))) + ((fSlow185 * ((fSlow182 * fYec0[(fYec0_idx+i-112)&255]) + (fSlow180 * fYec0[(fYec0_idx+i-68)&255]))) + ((fSlow177 * ((fSlow174 * fYec0[(fYec0_idx+i-111)&255]) + (fSlow172 * fYec0[(fYec0_idx+i-69)&255]))) + ((fSlow169 * ((fSlow166 * fYec0[(fYec0_idx+i-110)&255]) + (fSlow164 * fYec0[(fYec0_idx+i-70)&255]))) + ((fSlow161 * ((fSlow158 * fYec0[(fYec0_idx+i-109)&255]) + (fSlow156 * fYec0[(fYec0_idx+i-71)&255]))) + ((fSlow153 * ((fSlow150 * fYec0[(fYec0_idx+i-108)&255]) + (fSlow148 * fYec0[(fYec0_idx+i-72)&255]))) + ((fSlow145 * ((fSlow142 * fYec0[(fYec0_idx+i-107)&255]) + (fSlow140 * fYec0[(fYec0_idx+i-73)&255]))) + ((fSlow137 * ((fSlow134 * fYec0[(fYec0_idx+i-106)&255]) + (fSlow132 * fYec0[(fYec0_idx+i-74)&255]))) + ((fSlow129 * ((fSlow126 * fYec0[(fYec0_idx+i-105)&255]) + (fSlow124 * fYec0[(fYec0_idx+i-75)&255]))) + ((fSlow121 * ((fSlow118 * fYec0[(fYec0_idx+i-104)&255]) + (fSlow116 * fYec0[(fYec0_idx+i-76)&255]))) + ((fSlow113 * ((fSlow110 * fYec0[(fYec0_idx+i-103)&255]) + (fSlow108 * fYec0[(fYec0_idx+i-77)&255]))) + ((fSlow105 * ((fSlow102 * fYec0[(fYec0_idx+i-102)&255]) + (fSlow100 * fYec0[(fYec0_idx+i-78)&255]))) + ((fSlow97 * ((fSlow94 * fYec0[(fYec0_idx+i-101)&255]) + (fSlow92 * fYec0[(fYec0_idx+i-79)&255]))) + ((fSlow89 * ((fSlow86 * fYec0[(fYec0_idx+i-100)&255]) + (fSlow84 * fYec0[(fYec0_idx+i-80)&255]))) + ((fSlow81 * ((fSlow78 * fYec0[(fYec0_idx+i-99)&255]) + (fSlow76 * fYec0[(fYec0_idx+i-81)&255]))) + ((fSlow73 * ((fSlow70 * fYec0[(fYec0_idx+i-98)&255]) + (fSlow68 * fYec0[(fYec0_idx+i-82)&255]))) + ((fSlow65 * ((fSlow62 * fYec0[(fYec0_idx+i-97)&255]) + (fSlow60 * fYec0[(fYec0_idx+i-83)&255]))) + ((fSlow57 * ((fSlow54 * fYec0[(fYec0_idx+i-96)&255]) + (fSlow52 * fYec0[(fYec0_idx+i-84)&255]))) + ((fSlow49 * ((fSlow46 * fYec0[(fYec0_idx+i-95)&255]) + (fSlow44 * fYec0[(fYec0_idx+i-85)&255]))) + ((fSlow41 * ((fSlow38 * fYec0[(fYec0_idx+i-94)&255]) + (fSlow36 * fYec0[(fYec0_idx+i-86)&255]))) + ((fSlow33 * ((fSlow30 * fYec0[(fYec0_idx+i-93)&255]) + (fSlow28 * fYec0[(fYec0_idx+i-87)&255]))) + ((fSlow25 * ((fSlow22 * fYec0[(fYec0_idx+i-92)&255]) + (fSlow20 * fYec0[(fYec0_idx+i-88)&255]))) + ((fSlow17 * ((fSlow14 * fYec0[(fYec0_idx+i-91)&255]) + (fSlow12 * fYec0[(fYec0_idx+i-89)&255]))) + ((fSlow9 * fYec0[(fYec0_idx+i-90)&255]) + (fSlow8 * fYec0[(fYec0_idx+i) & 255])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))));
			}
			// post processing
			fYec1_idx_save = count;
			
			// LOOP 0x1742dcc8
			// pre processing
			fYec2_idx = (fYec2_idx+fYec2_idx_save)&127;
			// exec code
			for (int i=0; i<count; i++) {
				fYec2[(fYec2_idx+i)&127] = (fZec3[i] + (fSlow931 * (float)input0[i]));
			}
			// post processing
			fYec2_idx_save = count;
			
			// LOOP 0x1742e100
			// pre processing
			fYec4_idx = (fYec4_idx+fYec4_idx_save)&1023;
			// exec code
			for (int i=0; i<count; i++) {
				fYec4[(fYec4_idx+i)&1023] = ((fSlow904 * ((fSlow721 * ((fSlow903 * fYec3[(fYec3_idx+i-179)&255]) + (fSlow902 * fYec3[(fYec3_idx+i-1)&255]))) + ((fSlow713 * ((fSlow901 * fYec3[(fYec3_idx+i-178)&255]) + (fSlow900 * fYec3[(fYec3_idx+i-2)&255]))) + ((fSlow705 * ((fSlow899 * fYec3[(fYec3_idx+i-177)&255]) + (fSlow898 * fYec3[(fYec3_idx+i-3)&255]))) + ((fSlow697 * ((fSlow897 * fYec3[(fYec3_idx+i-176)&255]) + (fSlow896 * fYec3[(fYec3_idx+i-4)&255]))) + ((fSlow689 * ((fSlow895 * fYec3[(fYec3_idx+i-175)&255]) + (fSlow894 * fYec3[(fYec3_idx+i-5)&255]))) + ((fSlow681 * ((fSlow893 * fYec3[(fYec3_idx+i-174)&255]) + (fSlow892 * fYec3[(fYec3_idx+i-6)&255]))) + ((fSlow673 * ((fSlow891 * fYec3[(fYec3_idx+i-173)&255]) + (fSlow890 * fYec3[(fYec3_idx+i-7)&255]))) + ((fSlow665 * ((fSlow889 * fYec3[(fYec3_idx+i-172)&255]) + (fSlow888 * fYec3[(fYec3_idx+i-8)&255]))) + ((fSlow657 * ((fSlow887 * fYec3[(fYec3_idx+i-171)&255]) + (fSlow886 * fYec3[(fYec3_idx+i-9)&255]))) + ((fSlow649 * ((fSlow885 * fYec3[(fYec3_idx+i-170)&255]) + (fSlow884 * fYec3[(fYec3_idx+i-10)&255]))) + ((fSlow641 * ((fSlow883 * fYec3[(fYec3_idx+i-169)&255]) + (fSlow882 * fYec3[(fYec3_idx+i-11)&255]))) + ((fSlow633 * ((fSlow881 * fYec3[(fYec3_idx+i-168)&255]) + (fSlow880 * fYec3[(fYec3_idx+i-12)&255]))) + ((fSlow625 * ((fSlow879 * fYec3[(fYec3_idx+i-167)&255]) + (fSlow878 * fYec3[(fYec3_idx+i-13)&255]))) + ((fSlow617 * ((fSlow877 * fYec3[(fYec3_idx+i-166)&255]) + (fSlow876 * fYec3[(fYec3_idx+i-14)&255]))) + ((fSlow609 * ((fSlow875 * fYec3[(fYec3_idx+i-165)&255]) + (fSlow874 * fYec3[(fYec3_idx+i-15)&255]))) + ((fSlow601 * ((fSlow873 * fYec3[(fYec3_idx+i-164)&255]) + (fSlow872 * fYec3[(fYec3_idx+i-16)&255]))) + ((fSlow593 * ((fSlow871 * fYec3[(fYec3_idx+i-163)&255]) + (fSlow870 * fYec3[(fYec3_idx+i-17)&255]))) + ((fSlow585 * ((fSlow869 * fYec3[(fYec3_idx+i-162)&255]) + (fSlow868 * fYec3[(fYec3_idx+i-18)&255]))) + ((fSlow577 * ((fSlow867 * fYec3[(fYec3_idx+i-161)&255]) + (fSlow866 * fYec3[(fYec3_idx+i-19)&255]))) + ((fSlow569 * ((fSlow865 * fYec3[(fYec3_idx+i-160)&255]) + (fSlow864 * fYec3[(fYec3_idx+i-20)&255]))) + ((fSlow561 * ((fSlow863 * fYec3[(fYec3_idx+i-159)&255]) + (fSlow862 * fYec3[(fYec3_idx+i-21)&255]))) + ((fSlow553 * ((fSlow861 * fYec3[(fYec3_idx+i-158)&255]) + (fSlow860 * fYec3[(fYec3_idx+i-22)&255]))) + ((fSlow545 * ((fSlow859 * fYec3[(fYec3_idx+i-157)&255]) + (fSlow858 * fYec3[(fYec3_idx+i-23)&255]))) + ((fSlow537 * ((fSlow857 * fYec3[(fYec3_idx+i-156)&255]) + (fSlow856 * fYec3[(fYec3_idx+i-24)&255]))) + ((fSlow529 * ((fSlow855 * fYec3[(fYec3_idx+i-155)&255]) + (fSlow854 * fYec3[(fYec3_idx+i-25)&255]))) + ((fSlow521 * ((fSlow853 * fYec3[(fYec3_idx+i-154)&255]) + (fSlow852 * fYec3[(fYec3_idx+i-26)&255]))) + ((fSlow513 * ((fSlow851 * fYec3[(fYec3_idx+i-153)&255]) + (fSlow850 * fYec3[(fYec3_idx+i-27)&255]))) + ((fSlow505 * ((fSlow849 * fYec3[(fYec3_idx+i-152)&255]) + (fSlow848 * fYec3[(fYec3_idx+i-28)&255]))) + ((fSlow497 * ((fSlow847 * fYec3[(fYec3_idx+i-151)&255]) + (fSlow846 * fYec3[(fYec3_idx+i-29)&255]))) + ((fSlow489 * ((fSlow845 * fYec3[(fYec3_idx+i-150)&255]) + (fSlow844 * fYec3[(fYec3_idx+i-30)&255]))) + ((fSlow481 * ((fSlow843 * fYec3[(fYec3_idx+i-149)&255]) + (fSlow842 * fYec3[(fYec3_idx+i-31)&255]))) + ((fSlow473 * ((fSlow841 * fYec3[(fYec3_idx+i-148)&255]) + (fSlow840 * fYec3[(fYec3_idx+i-32)&255]))) + ((fSlow465 * ((fSlow839 * fYec3[(fYec3_idx+i-147)&255]) + (fSlow838 * fYec3[(fYec3_idx+i-33)&255]))) + ((fSlow457 * ((fSlow837 * fYec3[(fYec3_idx+i-146)&255]) + (fSlow836 * fYec3[(fYec3_idx+i-34)&255]))) + ((fSlow449 * ((fSlow835 * fYec3[(fYec3_idx+i-145)&255]) + (fSlow834 * fYec3[(fYec3_idx+i-35)&255]))) + ((fSlow441 * ((fSlow833 * fYec3[(fYec3_idx+i-144)&255]) + (fSlow832 * fYec3[(fYec3_idx+i-36)&255]))) + ((fSlow433 * ((fSlow831 * fYec3[(fYec3_idx+i-143)&255]) + (fSlow830 * fYec3[(fYec3_idx+i-37)&255]))) + ((fSlow425 * ((fSlow829 * fYec3[(fYec3_idx+i-142)&255]) + (fSlow828 * fYec3[(fYec3_idx+i-38)&255]))) + ((fSlow417 * ((fSlow827 * fYec3[(fYec3_idx+i-141)&255]) + (fSlow826 * fYec3[(fYec3_idx+i-39)&255]))) + ((fSlow409 * ((fSlow825 * fYec3[(fYec3_idx+i-140)&255]) + (fSlow824 * fYec3[(fYec3_idx+i-40)&255]))) + ((fSlow401 * ((fSlow823 * fYec3[(fYec3_idx+i-139)&255]) + (fSlow822 * fYec3[(fYec3_idx+i-41)&255]))) + ((fSlow393 * ((fSlow821 * fYec3[(fYec3_idx+i-138)&255]) + (fSlow820 * fYec3[(fYec3_idx+i-42)&255]))) + ((fSlow385 * ((fSlow819 * fYec3[(fYec3_idx+i-137)&255]) + (fSlow818 * fYec3[(fYec3_idx+i-43)&255]))) + ((fSlow377 * ((fSlow817 * fYec3[(fYec3_idx+i-136)&255]) + (fSlow816 * fYec3[(fYec3_idx+i-44)&255]))) + ((fSlow369 * ((fSlow815 * fYec3[(fYec3_idx+i-135)&255]) + (fSlow814 * fYec3[(fYec3_idx+i-45)&255]))) + ((fSlow361 * ((fSlow813 * fYec3[(fYec3_idx+i-134)&255]) + (fSlow812 * fYec3[(fYec3_idx+i-46)&255]))) + ((fSlow353 * ((fSlow811 * fYec3[(fYec3_idx+i-133)&255]) + (fSlow810 * fYec3[(fYec3_idx+i-47)&255]))) + ((fSlow345 * ((fSlow809 * fYec3[(fYec3_idx+i-132)&255]) + (fSlow808 * fYec3[(fYec3_idx+i-48)&255]))) + ((fSlow337 * ((fSlow807 * fYec3[(fYec3_idx+i-131)&255]) + (fSlow806 * fYec3[(fYec3_idx+i-49)&255]))) + ((fSlow329 * ((fSlow805 * fYec3[(fYec3_idx+i-130)&255]) + (fSlow804 * fYec3[(fYec3_idx+i-50)&255]))) + ((fSlow321 * ((fSlow803 * fYec3[(fYec3_idx+i-129)&255]) + (fSlow802 * fYec3[(fYec3_idx+i-51)&255]))) + ((fSlow313 * ((fSlow801 * fYec3[(fYec3_idx+i-128)&255]) + (fSlow800 * fYec3[(fYec3_idx+i-52)&255]))) + ((fSlow305 * ((fSlow799 * fYec3[(fYec3_idx+i-127)&255]) + (fSlow798 * fYec3[(fYec3_idx+i-53)&255]))) + ((fSlow297 * ((fSlow797 * fYec3[(fYec3_idx+i-126)&255]) + (fSlow796 * fYec3[(fYec3_idx+i-54)&255]))) + ((fSlow289 * ((fSlow795 * fYec3[(fYec3_idx+i-125)&255]) + (fSlow794 * fYec3[(fYec3_idx+i-55)&255]))) + ((fSlow281 * ((fSlow793 * fYec3[(fYec3_idx+i-124)&255]) + (fSlow792 * fYec3[(fYec3_idx+i-56)&255]))) + ((fSlow273 * ((fSlow791 * fYec3[(fYec3_idx+i-123)&255]) + (fSlow790 * fYec3[(fYec3_idx+i-57)&255]))) + ((fSlow265 * ((fSlow789 * fYec3[(fYec3_idx+i-122)&255]) + (fSlow788 * fYec3[(fYec3_idx+i-58)&255]))) + ((fSlow257 * ((fSlow787 * fYec3[(fYec3_idx+i-121)&255]) + (fSlow786 * fYec3[(fYec3_idx+i-59)&255]))) + ((fSlow249 * ((fSlow785 * fYec3[(fYec3_idx+i-120)&255]) + (fSlow784 * fYec3[(fYec3_idx+i-60)&255]))) + ((fSlow241 * ((fSlow783 * fYec3[(fYec3_idx+i-119)&255]) + (fSlow782 * fYec3[(fYec3_idx+i-61)&255]))) + ((fSlow233 * ((fSlow781 * fYec3[(fYec3_idx+i-118)&255]) + (fSlow780 * fYec3[(fYec3_idx+i-62)&255]))) + ((fSlow225 * ((fSlow779 * fYec3[(fYec3_idx+i-117)&255]) + (fSlow778 * fYec3[(fYec3_idx+i-63)&255]))) + ((fSlow217 * ((fSlow777 * fYec3[(fYec3_idx+i-116)&255]) + (fSlow776 * fYec3[(fYec3_idx+i-64)&255]))) + ((fSlow209 * ((fSlow775 * fYec3[(fYec3_idx+i-115)&255]) + (fSlow774 * fYec3[(fYec3_idx+i-65)&255]))) + ((fSlow201 * ((fSlow773 * fYec3[(fYec3_idx+i-114)&255]) + (fSlow772 * fYec3[(fYec3_idx+i-66)&255]))) + ((fSlow193 * ((fSlow771 * fYec3[(fYec3_idx+i-113)&255]) + (fSlow770 * fYec3[(fYec3_idx+i-67)&255]))) + ((fSlow185 * ((fSlow769 * fYec3[(fYec3_idx+i-112)&255]) + (fSlow768 * fYec3[(fYec3_idx+i-68)&255]))) + ((fSlow177 * ((fSlow767 * fYec3[(fYec3_idx+i-111)&255]) + (fSlow766 * fYec3[(fYec3_idx+i-69)&255]))) + ((fSlow169 * ((fSlow765 * fYec3[(fYec3_idx+i-110)&255]) + (fSlow764 * fYec3[(fYec3_idx+i-70)&255]))) + ((fSlow161 * ((fSlow763 * fYec3[(fYec3_idx+i-109)&255]) + (fSlow762 * fYec3[(fYec3_idx+i-71)&255]))) + ((fSlow153 * ((fSlow761 * fYec3[(fYec3_idx+i-108)&255]) + (fSlow760 * fYec3[(fYec3_idx+i-72)&255]))) + ((fSlow145 * ((fSlow759 * fYec3[(fYec3_idx+i-107)&255]) + (fSlow758 * fYec3[(fYec3_idx+i-73)&255]))) + ((fSlow137 * ((fSlow757 * fYec3[(fYec3_idx+i-106)&255]) + (fSlow756 * fYec3[(fYec3_idx+i-74)&255]))) + ((fSlow129 * ((fSlow755 * fYec3[(fYec3_idx+i-105)&255]) + (fSlow754 * fYec3[(fYec3_idx+i-75)&255]))) + ((fSlow121 * ((fSlow753 * fYec3[(fYec3_idx+i-104)&255]) + (fSlow752 * fYec3[(fYec3_idx+i-76)&255]))) + ((fSlow113 * ((fSlow751 * fYec3[(fYec3_idx+i-103)&255]) + (fSlow750 * fYec3[(fYec3_idx+i-77)&255]))) + ((fSlow105 * ((fSlow749 * fYec3[(fYec3_idx+i-102)&255]) + (fSlow748 * fYec3[(fYec3_idx+i-78)&255]))) + ((fSlow97 * ((fSlow747 * fYec3[(fYec3_idx+i-101)&255]) + (fSlow746 * fYec3[(fYec3_idx+i-79)&255]))) + ((fSlow89 * ((fSlow745 * fYec3[(fYec3_idx+i-100)&255]) + (fSlow744 * fYec3[(fYec3_idx+i-80)&255]))) + ((fSlow81 * ((fSlow743 * fYec3[(fYec3_idx+i-99)&255]) + (fSlow742 * fYec3[(fYec3_idx+i-81)&255]))) + ((fSlow73 * ((fSlow741 * fYec3[(fYec3_idx+i-98)&255]) + (fSlow740 * fYec3[(fYec3_idx+i-82)&255]))) + ((fSlow65 * ((fSlow739 * fYec3[(fYec3_idx+i-97)&255]) + (fSlow738 * fYec3[(fYec3_idx+i-83)&255]))) + ((fSlow57 * ((fSlow737 * fYec3[(fYec3_idx+i-96)&255]) + (fSlow736 * fYec3[(fYec3_idx+i-84)&255]))) + ((fSlow49 * ((fSlow735 * fYec3[(fYec3_idx+i-95)&255]) + (fSlow734 * fYec3[(fYec3_idx+i-85)&255]))) + ((fSlow41 * ((fSlow733 * fYec3[(fYec3_idx+i-94)&255]) + (fSlow732 * fYec3[(fYec3_idx+i-86)&255]))) + ((fSlow33 * ((fSlow731 * fYec3[(fYec3_idx+i-93)&255]) + (fSlow730 * fYec3[(fYec3_idx+i-87)&255]))) + ((fSlow25 * ((fSlow729 * fYec3[(fYec3_idx+i-92)&255]) + (fSlow728 * fYec3[(fYec3_idx+i-88)&255]))) + ((fSlow17 * ((fSlow727 * fYec3[(fYec3_idx+i-91)&255]) + (fSlow726 * fYec3[(fYec3_idx+i-89)&255]))) + ((fSlow725 * fYec3[(fYec3_idx+i-90)&255]) + (fSlow724 * fYec3[(fYec3_idx+i) & 255])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (fSlow722 * ((fSlow721 * ((fSlow718 * fYec3[(fYec3_idx+i-179)&255]) + (fSlow716 * fYec3[(fYec3_idx+i-1)&255]))) + ((fSlow713 * ((fSlow710 * fYec3[(fYec3_idx+i-178)&255]) + (fSlow708 * fYec3[(fYec3_idx+i-2)&255]))) + ((fSlow705 * ((fSlow702 * fYec3[(fYec3_idx+i-177)&255]) + (fSlow700 * fYec3[(fYec3_idx+i-3)&255]))) + ((fSlow697 * ((fSlow694 * fYec3[(fYec3_idx+i-176)&255]) + (fSlow692 * fYec3[(fYec3_idx+i-4)&255]))) + ((fSlow689 * ((fSlow686 * fYec3[(fYec3_idx+i-175)&255]) + (fSlow684 * fYec3[(fYec3_idx+i-5)&255]))) + ((fSlow681 * ((fSlow678 * fYec3[(fYec3_idx+i-174)&255]) + (fSlow676 * fYec3[(fYec3_idx+i-6)&255]))) + ((fSlow673 * ((fSlow670 * fYec3[(fYec3_idx+i-173)&255]) + (fSlow668 * fYec3[(fYec3_idx+i-7)&255]))) + ((fSlow665 * ((fSlow662 * fYec3[(fYec3_idx+i-172)&255]) + (fSlow660 * fYec3[(fYec3_idx+i-8)&255]))) + ((fSlow657 * ((fSlow654 * fYec3[(fYec3_idx+i-171)&255]) + (fSlow652 * fYec3[(fYec3_idx+i-9)&255]))) + ((fSlow649 * ((fSlow646 * fYec3[(fYec3_idx+i-170)&255]) + (fSlow644 * fYec3[(fYec3_idx+i-10)&255]))) + ((fSlow641 * ((fSlow638 * fYec3[(fYec3_idx+i-169)&255]) + (fSlow636 * fYec3[(fYec3_idx+i-11)&255]))) + ((fSlow633 * ((fSlow630 * fYec3[(fYec3_idx+i-168)&255]) + (fSlow628 * fYec3[(fYec3_idx+i-12)&255]))) + ((fSlow625 * ((fSlow622 * fYec3[(fYec3_idx+i-167)&255]) + (fSlow620 * fYec3[(fYec3_idx+i-13)&255]))) + ((fSlow617 * ((fSlow614 * fYec3[(fYec3_idx+i-166)&255]) + (fSlow612 * fYec3[(fYec3_idx+i-14)&255]))) + ((fSlow609 * ((fSlow606 * fYec3[(fYec3_idx+i-165)&255]) + (fSlow604 * fYec3[(fYec3_idx+i-15)&255]))) + ((fSlow601 * ((fSlow598 * fYec3[(fYec3_idx+i-164)&255]) + (fSlow596 * fYec3[(fYec3_idx+i-16)&255]))) + ((fSlow593 * ((fSlow590 * fYec3[(fYec3_idx+i-163)&255]) + (fSlow588 * fYec3[(fYec3_idx+i-17)&255]))) + ((fSlow585 * ((fSlow582 * fYec3[(fYec3_idx+i-162)&255]) + (fSlow580 * fYec3[(fYec3_idx+i-18)&255]))) + ((fSlow577 * ((fSlow574 * fYec3[(fYec3_idx+i-161)&255]) + (fSlow572 * fYec3[(fYec3_idx+i-19)&255]))) + ((fSlow569 * ((fSlow566 * fYec3[(fYec3_idx+i-160)&255]) + (fSlow564 * fYec3[(fYec3_idx+i-20)&255]))) + ((fSlow561 * ((fSlow558 * fYec3[(fYec3_idx+i-159)&255]) + (fSlow556 * fYec3[(fYec3_idx+i-21)&255]))) + ((fSlow553 * ((fSlow550 * fYec3[(fYec3_idx+i-158)&255]) + (fSlow548 * fYec3[(fYec3_idx+i-22)&255]))) + ((fSlow545 * ((fSlow542 * fYec3[(fYec3_idx+i-157)&255]) + (fSlow540 * fYec3[(fYec3_idx+i-23)&255]))) + ((fSlow537 * ((fSlow534 * fYec3[(fYec3_idx+i-156)&255]) + (fSlow532 * fYec3[(fYec3_idx+i-24)&255]))) + ((fSlow529 * ((fSlow526 * fYec3[(fYec3_idx+i-155)&255]) + (fSlow524 * fYec3[(fYec3_idx+i-25)&255]))) + ((fSlow521 * ((fSlow518 * fYec3[(fYec3_idx+i-154)&255]) + (fSlow516 * fYec3[(fYec3_idx+i-26)&255]))) + ((fSlow513 * ((fSlow510 * fYec3[(fYec3_idx+i-153)&255]) + (fSlow508 * fYec3[(fYec3_idx+i-27)&255]))) + ((fSlow505 * ((fSlow502 * fYec3[(fYec3_idx+i-152)&255]) + (fSlow500 * fYec3[(fYec3_idx+i-28)&255]))) + ((fSlow497 * ((fSlow494 * fYec3[(fYec3_idx+i-151)&255]) + (fSlow492 * fYec3[(fYec3_idx+i-29)&255]))) + ((fSlow489 * ((fSlow486 * fYec3[(fYec3_idx+i-150)&255]) + (fSlow484 * fYec3[(fYec3_idx+i-30)&255]))) + ((fSlow481 * ((fSlow478 * fYec3[(fYec3_idx+i-149)&255]) + (fSlow476 * fYec3[(fYec3_idx+i-31)&255]))) + ((fSlow473 * ((fSlow470 * fYec3[(fYec3_idx+i-148)&255]) + (fSlow468 * fYec3[(fYec3_idx+i-32)&255]))) + ((fSlow465 * ((fSlow462 * fYec3[(fYec3_idx+i-147)&255]) + (fSlow460 * fYec3[(fYec3_idx+i-33)&255]))) + ((fSlow457 * ((fSlow454 * fYec3[(fYec3_idx+i-146)&255]) + (fSlow452 * fYec3[(fYec3_idx+i-34)&255]))) + ((fSlow449 * ((fSlow446 * fYec3[(fYec3_idx+i-145)&255]) + (fSlow444 * fYec3[(fYec3_idx+i-35)&255]))) + ((fSlow441 * ((fSlow438 * fYec3[(fYec3_idx+i-144)&255]) + (fSlow436 * fYec3[(fYec3_idx+i-36)&255]))) + ((fSlow433 * ((fSlow430 * fYec3[(fYec3_idx+i-143)&255]) + (fSlow428 * fYec3[(fYec3_idx+i-37)&255]))) + ((fSlow425 * ((fSlow422 * fYec3[(fYec3_idx+i-142)&255]) + (fSlow420 * fYec3[(fYec3_idx+i-38)&255]))) + ((fSlow417 * ((fSlow414 * fYec3[(fYec3_idx+i-141)&255]) + (fSlow412 * fYec3[(fYec3_idx+i-39)&255]))) + ((fSlow409 * ((fSlow406 * fYec3[(fYec3_idx+i-140)&255]) + (fSlow404 * fYec3[(fYec3_idx+i-40)&255]))) + ((fSlow401 * ((fSlow398 * fYec3[(fYec3_idx+i-139)&255]) + (fSlow396 * fYec3[(fYec3_idx+i-41)&255]))) + ((fSlow393 * ((fSlow390 * fYec3[(fYec3_idx+i-138)&255]) + (fSlow388 * fYec3[(fYec3_idx+i-42)&255]))) + ((fSlow385 * ((fSlow382 * fYec3[(fYec3_idx+i-137)&255]) + (fSlow380 * fYec3[(fYec3_idx+i-43)&255]))) + ((fSlow377 * ((fSlow374 * fYec3[(fYec3_idx+i-136)&255]) + (fSlow372 * fYec3[(fYec3_idx+i-44)&255]))) + ((fSlow369 * ((fSlow366 * fYec3[(fYec3_idx+i-135)&255]) + (fSlow364 * fYec3[(fYec3_idx+i-45)&255]))) + ((fSlow361 * ((fSlow358 * fYec3[(fYec3_idx+i-134)&255]) + (fSlow356 * fYec3[(fYec3_idx+i-46)&255]))) + ((fSlow353 * ((fSlow350 * fYec3[(fYec3_idx+i-133)&255]) + (fSlow348 * fYec3[(fYec3_idx+i-47)&255]))) + ((fSlow345 * ((fSlow342 * fYec3[(fYec3_idx+i-132)&255]) + (fSlow340 * fYec3[(fYec3_idx+i-48)&255]))) + ((fSlow337 * ((fSlow334 * fYec3[(fYec3_idx+i-131)&255]) + (fSlow332 * fYec3[(fYec3_idx+i-49)&255]))) + ((fSlow329 * ((fSlow326 * fYec3[(fYec3_idx+i-130)&255]) + (fSlow324 * fYec3[(fYec3_idx+i-50)&255]))) + ((fSlow321 * ((fSlow318 * fYec3[(fYec3_idx+i-129)&255]) + (fSlow316 * fYec3[(fYec3_idx+i-51)&255]))) + ((fSlow313 * ((fSlow310 * fYec3[(fYec3_idx+i-128)&255]) + (fSlow308 * fYec3[(fYec3_idx+i-52)&255]))) + ((fSlow305 * ((fSlow302 * fYec3[(fYec3_idx+i-127)&255]) + (fSlow300 * fYec3[(fYec3_idx+i-53)&255]))) + ((fSlow297 * ((fSlow294 * fYec3[(fYec3_idx+i-126)&255]) + (fSlow292 * fYec3[(fYec3_idx+i-54)&255]))) + ((fSlow289 * ((fSlow286 * fYec3[(fYec3_idx+i-125)&255]) + (fSlow284 * fYec3[(fYec3_idx+i-55)&255]))) + ((fSlow281 * ((fSlow278 * fYec3[(fYec3_idx+i-124)&255]) + (fSlow276 * fYec3[(fYec3_idx+i-56)&255]))) + ((fSlow273 * ((fSlow270 * fYec3[(fYec3_idx+i-123)&255]) + (fSlow268 * fYec3[(fYec3_idx+i-57)&255]))) + ((fSlow265 * ((fSlow262 * fYec3[(fYec3_idx+i-122)&255]) + (fSlow260 * fYec3[(fYec3_idx+i-58)&255]))) + ((fSlow257 * ((fSlow254 * fYec3[(fYec3_idx+i-121)&255]) + (fSlow252 * fYec3[(fYec3_idx+i-59)&255]))) + ((fSlow249 * ((fSlow246 * fYec3[(fYec3_idx+i-120)&255]) + (fSlow244 * fYec3[(fYec3_idx+i-60)&255]))) + ((fSlow241 * ((fSlow238 * fYec3[(fYec3_idx+i-119)&255]) + (fSlow236 * fYec3[(fYec3_idx+i-61)&255]))) + ((fSlow233 * ((fSlow230 * fYec3[(fYec3_idx+i-118)&255]) + (fSlow228 * fYec3[(fYec3_idx+i-62)&255]))) + ((fSlow225 * ((fSlow222 * fYec3[(fYec3_idx+i-117)&255]) + (fSlow220 * fYec3[(fYec3_idx+i-63)&255]))) + ((fSlow217 * ((fSlow214 * fYec3[(fYec3_idx+i-116)&255]) + (fSlow212 * fYec3[(fYec3_idx+i-64)&255]))) + ((fSlow209 * ((fSlow206 * fYec3[(fYec3_idx+i-115)&255]) + (fSlow204 * fYec3[(fYec3_idx+i-65)&255]))) + ((fSlow201 * ((fSlow198 * fYec3[(fYec3_idx+i-114)&255]) + (fSlow196 * fYec3[(fYec3_idx+i-66)&255]))) + ((fSlow193 * ((fSlow190 * fYec3[(fYec3_idx+i-113)&255]) + (fSlow188 * fYec3[(fYec3_idx+i-67)&255]))) + ((fSlow185 * ((fSlow182 * fYec3[(fYec3_idx+i-112)&255]) + (fSlow180 * fYec3[(fYec3_idx+i-68)&255]))) + ((fSlow177 * ((fSlow174 * fYec3[(fYec3_idx+i-111)&255]) + (fSlow172 * fYec3[(fYec3_idx+i-69)&255]))) + ((fSlow169 * ((fSlow166 * fYec3[(fYec3_idx+i-110)&255]) + (fSlow164 * fYec3[(fYec3_idx+i-70)&255]))) + ((fSlow161 * ((fSlow158 * fYec3[(fYec3_idx+i-109)&255]) + (fSlow156 * fYec3[(fYec3_idx+i-71)&255]))) + ((fSlow153 * ((fSlow150 * fYec3[(fYec3_idx+i-108)&255]) + (fSlow148 * fYec3[(fYec3_idx+i-72)&255]))) + ((fSlow145 * ((fSlow142 * fYec3[(fYec3_idx+i-107)&255]) + (fSlow140 * fYec3[(fYec3_idx+i-73)&255]))) + ((fSlow137 * ((fSlow134 * fYec3[(fYec3_idx+i-106)&255]) + (fSlow132 * fYec3[(fYec3_idx+i-74)&255]))) + ((fSlow129 * ((fSlow126 * fYec3[(fYec3_idx+i-105)&255]) + (fSlow124 * fYec3[(fYec3_idx+i-75)&255]))) + ((fSlow121 * ((fSlow118 * fYec3[(fYec3_idx+i-104)&255]) + (fSlow116 * fYec3[(fYec3_idx+i-76)&255]))) + ((fSlow113 * ((fSlow110 * fYec3[(fYec3_idx+i-103)&255]) + (fSlow108 * fYec3[(fYec3_idx+i-77)&255]))) + ((fSlow105 * ((fSlow102 * fYec3[(fYec3_idx+i-102)&255]) + (fSlow100 * fYec3[(fYec3_idx+i-78)&255]))) + ((fSlow97 * ((fSlow94 * fYec3[(fYec3_idx+i-101)&255]) + (fSlow92 * fYec3[(fYec3_idx+i-79)&255]))) + ((fSlow89 * ((fSlow86 * fYec3[(fYec3_idx+i-100)&255]) + (fSlow84 * fYec3[(fYec3_idx+i-80)&255]))) + ((fSlow81 * ((fSlow78 * fYec3[(fYec3_idx+i-99)&255]) + (fSlow76 * fYec3[(fYec3_idx+i-81)&255]))) + ((fSlow73 * ((fSlow70 * fYec3[(fYec3_idx+i-98)&255]) + (fSlow68 * fYec3[(fYec3_idx+i-82)&255]))) + ((fSlow65 * ((fSlow62 * fYec3[(fYec3_idx+i-97)&255]) + (fSlow60 * fYec3[(fYec3_idx+i-83)&255]))) + ((fSlow57 * ((fSlow54 * fYec3[(fYec3_idx+i-96)&255]) + (fSlow52 * fYec3[(fYec3_idx+i-84)&255]))) + ((fSlow49 * ((fSlow46 * fYec3[(fYec3_idx+i-95)&255]) + (fSlow44 * fYec3[(fYec3_idx+i-85)&255]))) + ((fSlow41 * ((fSlow38 * fYec3[(fYec3_idx+i-94)&255]) + (fSlow36 * fYec3[(fYec3_idx+i-86)&255]))) + ((fSlow33 * ((fSlow30 * fYec3[(fYec3_idx+i-93)&255]) + (fSlow28 * fYec3[(fYec3_idx+i-87)&255]))) + ((fSlow25 * ((fSlow22 * fYec3[(fYec3_idx+i-92)&255]) + (fSlow20 * fYec3[(fYec3_idx+i-88)&255]))) + ((fSlow17 * ((fSlow14 * fYec3[(fYec3_idx+i-91)&255]) + (fSlow12 * fYec3[(fYec3_idx+i-89)&255]))) + ((fSlow9 * fYec3[(fYec3_idx+i-90)&255]) + (fSlow8 * fYec3[(fYec3_idx+i) & 255])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))));
			}
			// post processing
			fYec4_idx_save = count;
			
			// LOOP 0x17676688
			// pre processing
			fYec5_idx = (fYec5_idx+fYec5_idx_save)&127;
			// exec code
			for (int i=0; i<count; i++) {
				fYec5[(fYec5_idx+i)&127] = (fZec3[i] + (fSlow931 * (float)input1[i]));
			}
			// post processing
			fYec5_idx_save = count;
			
			// SECTION : 5
			// LOOP 0x1209dd8
			// exec code
			for (int i=0; i<count; i++) {
				output0[i] = (FAUSTFLOAT)(fSlow934 * (((fSlow933 * fYec1[(fYec1_idx+i-iSlow932)&1023]) + (((0 - (1.999999999999997f * (0 - (6.217248937900886e-015f * fYec2[(fYec2_idx+i-93)&127])))) + (5.0f * (0 - (2.999999999999997f * (0 - (3.1086244689504383e-015f * (0 - (2.000000000000003f * fYec2[(fYec2_idx+i-92)&127])))))))) + (1e+001f * ((((0 - (2.999999999999997f * (0 - (1.2434497875801793e-014f * fYec2[(fYec2_idx+i-91)&127])))) + (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (0 - (2.000000000000003f * fYec2[(fYec2_idx+i-90)&127])))))))) + (0.5f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (6.217248937900867e-015f * fYec2[(fYec2_idx+i-89)&127])))))))) + (0.1f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (3.108624468950429e-015f * (0 - (1.000000000000003f * fYec2[(fYec2_idx+i-88)&127]))))))))))))) + (fSlow929 * ((fSlow927 * ((fSlow916 * ((fSlow914 * ((fSlow926 * fYec1[(fYec1_idx+i-iSlow925)&1023]) + (fSlow924 * fYec1[(fYec1_idx+i-iSlow923)&1023]))) + (fSlow922 * fYec1[(fYec1_idx+i-iSlow921)&1023]))) + (fSlow920 * fYec1[(fYec1_idx+i-iSlow918)&1023]))) + (fSlow917 * fYec1[(fYec1_idx+i-iSlow908)&1023])))));
			}
			
			// LOOP 0x1742e088
			// exec code
			for (int i=0; i<count; i++) {
				output1[i] = (FAUSTFLOAT)(fSlow934 * (((fSlow933 * fYec4[(fYec4_idx+i-iSlow932)&1023]) + (((0 - (1.999999999999997f * (0 - (6.217248937900886e-015f * fYec5[(fYec5_idx+i-93)&127])))) + (5.0f * (0 - (2.999999999999997f * (0 - (3.1086244689504383e-015f * (0 - (2.000000000000003f * fYec5[(fYec5_idx+i-92)&127])))))))) + (1e+001f * ((((0 - (2.999999999999997f * (0 - (1.2434497875801793e-014f * fYec5[(fYec5_idx+i-91)&127])))) + (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (0 - (2.000000000000003f * fYec5[(fYec5_idx+i-90)&127])))))))) + (0.5f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (6.217248937900867e-015f * fYec5[(fYec5_idx+i-89)&127])))))))) + (0.1f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (3.108624468950429e-015f * (0 - (1.000000000000003f * fYec5[(fYec5_idx+i-88)&127]))))))))))))) + (fSlow929 * ((fSlow927 * ((fSlow916 * ((fSlow914 * ((fSlow926 * fYec4[(fYec4_idx+i-iSlow925)&1023]) + (fSlow924 * fYec4[(fYec4_idx+i-iSlow923)&1023]))) + (fSlow922 * fYec4[(fYec4_idx+i-iSlow921)&1023]))) + (fSlow920 * fYec4[(fYec4_idx+i-iSlow918)&1023]))) + (fSlow917 * fYec4[(fYec4_idx+i-iSlow908)&1023])))));
			}
			
		}
		if (index < fullcount) {
			// compute the remaining samples if any
			int count = fullcount-index;
			FAUSTFLOAT* input0 = &input[0][index];
			FAUSTFLOAT* input1 = &input[1][index];
			FAUSTFLOAT* output0 = &output[0][index];
			FAUSTFLOAT* output1 = &output[1][index];
			// SECTION : 1
			// LOOP 0x17028f10
			// exec code
			for (int i=0; i<count; i++) {
				fZec0[i] = ((float)input0[i] + (float)input1[i]);
			}
			
			// SECTION : 2
			// LOOP 0x17028e98
			// exec code
			for (int i=0; i<count; i++) {
				fZec1[i] = faustpower<4>(fZec0[i]);
			}
			
			// LOOP 0x1742ddb8
			// exec code
			for (int i=0; i<count; i++) {
				fZec2[i] = ((float)input0[i] - (float)input1[i]);
			}
			
			// SECTION : 3
			// LOOP 0x17028cc0
			// pre processing
			fYec0_idx = (fYec0_idx+fYec0_idx_save)&255;
			// exec code
			for (int i=0; i<count; i++) {
				fYec0[(fYec0_idx+i)&255] = min(0.5f, max(-0.5f, (fZec1[i] * (0 - (0.03125f * ((float)input1[i] - (float)input0[i]))))));
			}
			// post processing
			fYec0_idx_save = count;
			
			// LOOP 0x1742dd40
			// exec code
			for (int i=0; i<count; i++) {
				fZec3[i] = (fSlow930 * min((float)1, max((float)-1, (fZec0[i] * (0 - (0.03125f * faustpower<4>(fZec2[i])))))));
			}
			
			// LOOP 0x1742e178
			// pre processing
			fYec3_idx = (fYec3_idx+fYec3_idx_save)&255;
			// exec code
			for (int i=0; i<count; i++) {
				fYec3[(fYec3_idx+i)&255] = min(0.5f, max(-0.5f, (fZec1[i] * (0 - (0.03125f * fZec2[i])))));
			}
			// post processing
			fYec3_idx_save = count;
			
			// SECTION : 4
			// LOOP 0x17028c48
			// pre processing
			fYec1_idx = (fYec1_idx+fYec1_idx_save)&1023;
			// exec code
			for (int i=0; i<count; i++) {
				fYec1[(fYec1_idx+i)&1023] = ((fSlow904 * ((fSlow721 * ((fSlow903 * fYec0[(fYec0_idx+i-179)&255]) + (fSlow902 * fYec0[(fYec0_idx+i-1)&255]))) + ((fSlow713 * ((fSlow901 * fYec0[(fYec0_idx+i-178)&255]) + (fSlow900 * fYec0[(fYec0_idx+i-2)&255]))) + ((fSlow705 * ((fSlow899 * fYec0[(fYec0_idx+i-177)&255]) + (fSlow898 * fYec0[(fYec0_idx+i-3)&255]))) + ((fSlow697 * ((fSlow897 * fYec0[(fYec0_idx+i-176)&255]) + (fSlow896 * fYec0[(fYec0_idx+i-4)&255]))) + ((fSlow689 * ((fSlow895 * fYec0[(fYec0_idx+i-175)&255]) + (fSlow894 * fYec0[(fYec0_idx+i-5)&255]))) + ((fSlow681 * ((fSlow893 * fYec0[(fYec0_idx+i-174)&255]) + (fSlow892 * fYec0[(fYec0_idx+i-6)&255]))) + ((fSlow673 * ((fSlow891 * fYec0[(fYec0_idx+i-173)&255]) + (fSlow890 * fYec0[(fYec0_idx+i-7)&255]))) + ((fSlow665 * ((fSlow889 * fYec0[(fYec0_idx+i-172)&255]) + (fSlow888 * fYec0[(fYec0_idx+i-8)&255]))) + ((fSlow657 * ((fSlow887 * fYec0[(fYec0_idx+i-171)&255]) + (fSlow886 * fYec0[(fYec0_idx+i-9)&255]))) + ((fSlow649 * ((fSlow885 * fYec0[(fYec0_idx+i-170)&255]) + (fSlow884 * fYec0[(fYec0_idx+i-10)&255]))) + ((fSlow641 * ((fSlow883 * fYec0[(fYec0_idx+i-169)&255]) + (fSlow882 * fYec0[(fYec0_idx+i-11)&255]))) + ((fSlow633 * ((fSlow881 * fYec0[(fYec0_idx+i-168)&255]) + (fSlow880 * fYec0[(fYec0_idx+i-12)&255]))) + ((fSlow625 * ((fSlow879 * fYec0[(fYec0_idx+i-167)&255]) + (fSlow878 * fYec0[(fYec0_idx+i-13)&255]))) + ((fSlow617 * ((fSlow877 * fYec0[(fYec0_idx+i-166)&255]) + (fSlow876 * fYec0[(fYec0_idx+i-14)&255]))) + ((fSlow609 * ((fSlow875 * fYec0[(fYec0_idx+i-165)&255]) + (fSlow874 * fYec0[(fYec0_idx+i-15)&255]))) + ((fSlow601 * ((fSlow873 * fYec0[(fYec0_idx+i-164)&255]) + (fSlow872 * fYec0[(fYec0_idx+i-16)&255]))) + ((fSlow593 * ((fSlow871 * fYec0[(fYec0_idx+i-163)&255]) + (fSlow870 * fYec0[(fYec0_idx+i-17)&255]))) + ((fSlow585 * ((fSlow869 * fYec0[(fYec0_idx+i-162)&255]) + (fSlow868 * fYec0[(fYec0_idx+i-18)&255]))) + ((fSlow577 * ((fSlow867 * fYec0[(fYec0_idx+i-161)&255]) + (fSlow866 * fYec0[(fYec0_idx+i-19)&255]))) + ((fSlow569 * ((fSlow865 * fYec0[(fYec0_idx+i-160)&255]) + (fSlow864 * fYec0[(fYec0_idx+i-20)&255]))) + ((fSlow561 * ((fSlow863 * fYec0[(fYec0_idx+i-159)&255]) + (fSlow862 * fYec0[(fYec0_idx+i-21)&255]))) + ((fSlow553 * ((fSlow861 * fYec0[(fYec0_idx+i-158)&255]) + (fSlow860 * fYec0[(fYec0_idx+i-22)&255]))) + ((fSlow545 * ((fSlow859 * fYec0[(fYec0_idx+i-157)&255]) + (fSlow858 * fYec0[(fYec0_idx+i-23)&255]))) + ((fSlow537 * ((fSlow857 * fYec0[(fYec0_idx+i-156)&255]) + (fSlow856 * fYec0[(fYec0_idx+i-24)&255]))) + ((fSlow529 * ((fSlow855 * fYec0[(fYec0_idx+i-155)&255]) + (fSlow854 * fYec0[(fYec0_idx+i-25)&255]))) + ((fSlow521 * ((fSlow853 * fYec0[(fYec0_idx+i-154)&255]) + (fSlow852 * fYec0[(fYec0_idx+i-26)&255]))) + ((fSlow513 * ((fSlow851 * fYec0[(fYec0_idx+i-153)&255]) + (fSlow850 * fYec0[(fYec0_idx+i-27)&255]))) + ((fSlow505 * ((fSlow849 * fYec0[(fYec0_idx+i-152)&255]) + (fSlow848 * fYec0[(fYec0_idx+i-28)&255]))) + ((fSlow497 * ((fSlow847 * fYec0[(fYec0_idx+i-151)&255]) + (fSlow846 * fYec0[(fYec0_idx+i-29)&255]))) + ((fSlow489 * ((fSlow845 * fYec0[(fYec0_idx+i-150)&255]) + (fSlow844 * fYec0[(fYec0_idx+i-30)&255]))) + ((fSlow481 * ((fSlow843 * fYec0[(fYec0_idx+i-149)&255]) + (fSlow842 * fYec0[(fYec0_idx+i-31)&255]))) + ((fSlow473 * ((fSlow841 * fYec0[(fYec0_idx+i-148)&255]) + (fSlow840 * fYec0[(fYec0_idx+i-32)&255]))) + ((fSlow465 * ((fSlow839 * fYec0[(fYec0_idx+i-147)&255]) + (fSlow838 * fYec0[(fYec0_idx+i-33)&255]))) + ((fSlow457 * ((fSlow837 * fYec0[(fYec0_idx+i-146)&255]) + (fSlow836 * fYec0[(fYec0_idx+i-34)&255]))) + ((fSlow449 * ((fSlow835 * fYec0[(fYec0_idx+i-145)&255]) + (fSlow834 * fYec0[(fYec0_idx+i-35)&255]))) + ((fSlow441 * ((fSlow833 * fYec0[(fYec0_idx+i-144)&255]) + (fSlow832 * fYec0[(fYec0_idx+i-36)&255]))) + ((fSlow433 * ((fSlow831 * fYec0[(fYec0_idx+i-143)&255]) + (fSlow830 * fYec0[(fYec0_idx+i-37)&255]))) + ((fSlow425 * ((fSlow829 * fYec0[(fYec0_idx+i-142)&255]) + (fSlow828 * fYec0[(fYec0_idx+i-38)&255]))) + ((fSlow417 * ((fSlow827 * fYec0[(fYec0_idx+i-141)&255]) + (fSlow826 * fYec0[(fYec0_idx+i-39)&255]))) + ((fSlow409 * ((fSlow825 * fYec0[(fYec0_idx+i-140)&255]) + (fSlow824 * fYec0[(fYec0_idx+i-40)&255]))) + ((fSlow401 * ((fSlow823 * fYec0[(fYec0_idx+i-139)&255]) + (fSlow822 * fYec0[(fYec0_idx+i-41)&255]))) + ((fSlow393 * ((fSlow821 * fYec0[(fYec0_idx+i-138)&255]) + (fSlow820 * fYec0[(fYec0_idx+i-42)&255]))) + ((fSlow385 * ((fSlow819 * fYec0[(fYec0_idx+i-137)&255]) + (fSlow818 * fYec0[(fYec0_idx+i-43)&255]))) + ((fSlow377 * ((fSlow817 * fYec0[(fYec0_idx+i-136)&255]) + (fSlow816 * fYec0[(fYec0_idx+i-44)&255]))) + ((fSlow369 * ((fSlow815 * fYec0[(fYec0_idx+i-135)&255]) + (fSlow814 * fYec0[(fYec0_idx+i-45)&255]))) + ((fSlow361 * ((fSlow813 * fYec0[(fYec0_idx+i-134)&255]) + (fSlow812 * fYec0[(fYec0_idx+i-46)&255]))) + ((fSlow353 * ((fSlow811 * fYec0[(fYec0_idx+i-133)&255]) + (fSlow810 * fYec0[(fYec0_idx+i-47)&255]))) + ((fSlow345 * ((fSlow809 * fYec0[(fYec0_idx+i-132)&255]) + (fSlow808 * fYec0[(fYec0_idx+i-48)&255]))) + ((fSlow337 * ((fSlow807 * fYec0[(fYec0_idx+i-131)&255]) + (fSlow806 * fYec0[(fYec0_idx+i-49)&255]))) + ((fSlow329 * ((fSlow805 * fYec0[(fYec0_idx+i-130)&255]) + (fSlow804 * fYec0[(fYec0_idx+i-50)&255]))) + ((fSlow321 * ((fSlow803 * fYec0[(fYec0_idx+i-129)&255]) + (fSlow802 * fYec0[(fYec0_idx+i-51)&255]))) + ((fSlow313 * ((fSlow801 * fYec0[(fYec0_idx+i-128)&255]) + (fSlow800 * fYec0[(fYec0_idx+i-52)&255]))) + ((fSlow305 * ((fSlow799 * fYec0[(fYec0_idx+i-127)&255]) + (fSlow798 * fYec0[(fYec0_idx+i-53)&255]))) + ((fSlow297 * ((fSlow797 * fYec0[(fYec0_idx+i-126)&255]) + (fSlow796 * fYec0[(fYec0_idx+i-54)&255]))) + ((fSlow289 * ((fSlow795 * fYec0[(fYec0_idx+i-125)&255]) + (fSlow794 * fYec0[(fYec0_idx+i-55)&255]))) + ((fSlow281 * ((fSlow793 * fYec0[(fYec0_idx+i-124)&255]) + (fSlow792 * fYec0[(fYec0_idx+i-56)&255]))) + ((fSlow273 * ((fSlow791 * fYec0[(fYec0_idx+i-123)&255]) + (fSlow790 * fYec0[(fYec0_idx+i-57)&255]))) + ((fSlow265 * ((fSlow789 * fYec0[(fYec0_idx+i-122)&255]) + (fSlow788 * fYec0[(fYec0_idx+i-58)&255]))) + ((fSlow257 * ((fSlow787 * fYec0[(fYec0_idx+i-121)&255]) + (fSlow786 * fYec0[(fYec0_idx+i-59)&255]))) + ((fSlow249 * ((fSlow785 * fYec0[(fYec0_idx+i-120)&255]) + (fSlow784 * fYec0[(fYec0_idx+i-60)&255]))) + ((fSlow241 * ((fSlow783 * fYec0[(fYec0_idx+i-119)&255]) + (fSlow782 * fYec0[(fYec0_idx+i-61)&255]))) + ((fSlow233 * ((fSlow781 * fYec0[(fYec0_idx+i-118)&255]) + (fSlow780 * fYec0[(fYec0_idx+i-62)&255]))) + ((fSlow225 * ((fSlow779 * fYec0[(fYec0_idx+i-117)&255]) + (fSlow778 * fYec0[(fYec0_idx+i-63)&255]))) + ((fSlow217 * ((fSlow777 * fYec0[(fYec0_idx+i-116)&255]) + (fSlow776 * fYec0[(fYec0_idx+i-64)&255]))) + ((fSlow209 * ((fSlow775 * fYec0[(fYec0_idx+i-115)&255]) + (fSlow774 * fYec0[(fYec0_idx+i-65)&255]))) + ((fSlow201 * ((fSlow773 * fYec0[(fYec0_idx+i-114)&255]) + (fSlow772 * fYec0[(fYec0_idx+i-66)&255]))) + ((fSlow193 * ((fSlow771 * fYec0[(fYec0_idx+i-113)&255]) + (fSlow770 * fYec0[(fYec0_idx+i-67)&255]))) + ((fSlow185 * ((fSlow769 * fYec0[(fYec0_idx+i-112)&255]) + (fSlow768 * fYec0[(fYec0_idx+i-68)&255]))) + ((fSlow177 * ((fSlow767 * fYec0[(fYec0_idx+i-111)&255]) + (fSlow766 * fYec0[(fYec0_idx+i-69)&255]))) + ((fSlow169 * ((fSlow765 * fYec0[(fYec0_idx+i-110)&255]) + (fSlow764 * fYec0[(fYec0_idx+i-70)&255]))) + ((fSlow161 * ((fSlow763 * fYec0[(fYec0_idx+i-109)&255]) + (fSlow762 * fYec0[(fYec0_idx+i-71)&255]))) + ((fSlow153 * ((fSlow761 * fYec0[(fYec0_idx+i-108)&255]) + (fSlow760 * fYec0[(fYec0_idx+i-72)&255]))) + ((fSlow145 * ((fSlow759 * fYec0[(fYec0_idx+i-107)&255]) + (fSlow758 * fYec0[(fYec0_idx+i-73)&255]))) + ((fSlow137 * ((fSlow757 * fYec0[(fYec0_idx+i-106)&255]) + (fSlow756 * fYec0[(fYec0_idx+i-74)&255]))) + ((fSlow129 * ((fSlow755 * fYec0[(fYec0_idx+i-105)&255]) + (fSlow754 * fYec0[(fYec0_idx+i-75)&255]))) + ((fSlow121 * ((fSlow753 * fYec0[(fYec0_idx+i-104)&255]) + (fSlow752 * fYec0[(fYec0_idx+i-76)&255]))) + ((fSlow113 * ((fSlow751 * fYec0[(fYec0_idx+i-103)&255]) + (fSlow750 * fYec0[(fYec0_idx+i-77)&255]))) + ((fSlow105 * ((fSlow749 * fYec0[(fYec0_idx+i-102)&255]) + (fSlow748 * fYec0[(fYec0_idx+i-78)&255]))) + ((fSlow97 * ((fSlow747 * fYec0[(fYec0_idx+i-101)&255]) + (fSlow746 * fYec0[(fYec0_idx+i-79)&255]))) + ((fSlow89 * ((fSlow745 * fYec0[(fYec0_idx+i-100)&255]) + (fSlow744 * fYec0[(fYec0_idx+i-80)&255]))) + ((fSlow81 * ((fSlow743 * fYec0[(fYec0_idx+i-99)&255]) + (fSlow742 * fYec0[(fYec0_idx+i-81)&255]))) + ((fSlow73 * ((fSlow741 * fYec0[(fYec0_idx+i-98)&255]) + (fSlow740 * fYec0[(fYec0_idx+i-82)&255]))) + ((fSlow65 * ((fSlow739 * fYec0[(fYec0_idx+i-97)&255]) + (fSlow738 * fYec0[(fYec0_idx+i-83)&255]))) + ((fSlow57 * ((fSlow737 * fYec0[(fYec0_idx+i-96)&255]) + (fSlow736 * fYec0[(fYec0_idx+i-84)&255]))) + ((fSlow49 * ((fSlow735 * fYec0[(fYec0_idx+i-95)&255]) + (fSlow734 * fYec0[(fYec0_idx+i-85)&255]))) + ((fSlow41 * ((fSlow733 * fYec0[(fYec0_idx+i-94)&255]) + (fSlow732 * fYec0[(fYec0_idx+i-86)&255]))) + ((fSlow33 * ((fSlow731 * fYec0[(fYec0_idx+i-93)&255]) + (fSlow730 * fYec0[(fYec0_idx+i-87)&255]))) + ((fSlow25 * ((fSlow729 * fYec0[(fYec0_idx+i-92)&255]) + (fSlow728 * fYec0[(fYec0_idx+i-88)&255]))) + ((fSlow17 * ((fSlow727 * fYec0[(fYec0_idx+i-91)&255]) + (fSlow726 * fYec0[(fYec0_idx+i-89)&255]))) + ((fSlow725 * fYec0[(fYec0_idx+i-90)&255]) + (fSlow724 * fYec0[(fYec0_idx+i) & 255])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (fSlow722 * ((fSlow721 * ((fSlow718 * fYec0[(fYec0_idx+i-179)&255]) + (fSlow716 * fYec0[(fYec0_idx+i-1)&255]))) + ((fSlow713 * ((fSlow710 * fYec0[(fYec0_idx+i-178)&255]) + (fSlow708 * fYec0[(fYec0_idx+i-2)&255]))) + ((fSlow705 * ((fSlow702 * fYec0[(fYec0_idx+i-177)&255]) + (fSlow700 * fYec0[(fYec0_idx+i-3)&255]))) + ((fSlow697 * ((fSlow694 * fYec0[(fYec0_idx+i-176)&255]) + (fSlow692 * fYec0[(fYec0_idx+i-4)&255]))) + ((fSlow689 * ((fSlow686 * fYec0[(fYec0_idx+i-175)&255]) + (fSlow684 * fYec0[(fYec0_idx+i-5)&255]))) + ((fSlow681 * ((fSlow678 * fYec0[(fYec0_idx+i-174)&255]) + (fSlow676 * fYec0[(fYec0_idx+i-6)&255]))) + ((fSlow673 * ((fSlow670 * fYec0[(fYec0_idx+i-173)&255]) + (fSlow668 * fYec0[(fYec0_idx+i-7)&255]))) + ((fSlow665 * ((fSlow662 * fYec0[(fYec0_idx+i-172)&255]) + (fSlow660 * fYec0[(fYec0_idx+i-8)&255]))) + ((fSlow657 * ((fSlow654 * fYec0[(fYec0_idx+i-171)&255]) + (fSlow652 * fYec0[(fYec0_idx+i-9)&255]))) + ((fSlow649 * ((fSlow646 * fYec0[(fYec0_idx+i-170)&255]) + (fSlow644 * fYec0[(fYec0_idx+i-10)&255]))) + ((fSlow641 * ((fSlow638 * fYec0[(fYec0_idx+i-169)&255]) + (fSlow636 * fYec0[(fYec0_idx+i-11)&255]))) + ((fSlow633 * ((fSlow630 * fYec0[(fYec0_idx+i-168)&255]) + (fSlow628 * fYec0[(fYec0_idx+i-12)&255]))) + ((fSlow625 * ((fSlow622 * fYec0[(fYec0_idx+i-167)&255]) + (fSlow620 * fYec0[(fYec0_idx+i-13)&255]))) + ((fSlow617 * ((fSlow614 * fYec0[(fYec0_idx+i-166)&255]) + (fSlow612 * fYec0[(fYec0_idx+i-14)&255]))) + ((fSlow609 * ((fSlow606 * fYec0[(fYec0_idx+i-165)&255]) + (fSlow604 * fYec0[(fYec0_idx+i-15)&255]))) + ((fSlow601 * ((fSlow598 * fYec0[(fYec0_idx+i-164)&255]) + (fSlow596 * fYec0[(fYec0_idx+i-16)&255]))) + ((fSlow593 * ((fSlow590 * fYec0[(fYec0_idx+i-163)&255]) + (fSlow588 * fYec0[(fYec0_idx+i-17)&255]))) + ((fSlow585 * ((fSlow582 * fYec0[(fYec0_idx+i-162)&255]) + (fSlow580 * fYec0[(fYec0_idx+i-18)&255]))) + ((fSlow577 * ((fSlow574 * fYec0[(fYec0_idx+i-161)&255]) + (fSlow572 * fYec0[(fYec0_idx+i-19)&255]))) + ((fSlow569 * ((fSlow566 * fYec0[(fYec0_idx+i-160)&255]) + (fSlow564 * fYec0[(fYec0_idx+i-20)&255]))) + ((fSlow561 * ((fSlow558 * fYec0[(fYec0_idx+i-159)&255]) + (fSlow556 * fYec0[(fYec0_idx+i-21)&255]))) + ((fSlow553 * ((fSlow550 * fYec0[(fYec0_idx+i-158)&255]) + (fSlow548 * fYec0[(fYec0_idx+i-22)&255]))) + ((fSlow545 * ((fSlow542 * fYec0[(fYec0_idx+i-157)&255]) + (fSlow540 * fYec0[(fYec0_idx+i-23)&255]))) + ((fSlow537 * ((fSlow534 * fYec0[(fYec0_idx+i-156)&255]) + (fSlow532 * fYec0[(fYec0_idx+i-24)&255]))) + ((fSlow529 * ((fSlow526 * fYec0[(fYec0_idx+i-155)&255]) + (fSlow524 * fYec0[(fYec0_idx+i-25)&255]))) + ((fSlow521 * ((fSlow518 * fYec0[(fYec0_idx+i-154)&255]) + (fSlow516 * fYec0[(fYec0_idx+i-26)&255]))) + ((fSlow513 * ((fSlow510 * fYec0[(fYec0_idx+i-153)&255]) + (fSlow508 * fYec0[(fYec0_idx+i-27)&255]))) + ((fSlow505 * ((fSlow502 * fYec0[(fYec0_idx+i-152)&255]) + (fSlow500 * fYec0[(fYec0_idx+i-28)&255]))) + ((fSlow497 * ((fSlow494 * fYec0[(fYec0_idx+i-151)&255]) + (fSlow492 * fYec0[(fYec0_idx+i-29)&255]))) + ((fSlow489 * ((fSlow486 * fYec0[(fYec0_idx+i-150)&255]) + (fSlow484 * fYec0[(fYec0_idx+i-30)&255]))) + ((fSlow481 * ((fSlow478 * fYec0[(fYec0_idx+i-149)&255]) + (fSlow476 * fYec0[(fYec0_idx+i-31)&255]))) + ((fSlow473 * ((fSlow470 * fYec0[(fYec0_idx+i-148)&255]) + (fSlow468 * fYec0[(fYec0_idx+i-32)&255]))) + ((fSlow465 * ((fSlow462 * fYec0[(fYec0_idx+i-147)&255]) + (fSlow460 * fYec0[(fYec0_idx+i-33)&255]))) + ((fSlow457 * ((fSlow454 * fYec0[(fYec0_idx+i-146)&255]) + (fSlow452 * fYec0[(fYec0_idx+i-34)&255]))) + ((fSlow449 * ((fSlow446 * fYec0[(fYec0_idx+i-145)&255]) + (fSlow444 * fYec0[(fYec0_idx+i-35)&255]))) + ((fSlow441 * ((fSlow438 * fYec0[(fYec0_idx+i-144)&255]) + (fSlow436 * fYec0[(fYec0_idx+i-36)&255]))) + ((fSlow433 * ((fSlow430 * fYec0[(fYec0_idx+i-143)&255]) + (fSlow428 * fYec0[(fYec0_idx+i-37)&255]))) + ((fSlow425 * ((fSlow422 * fYec0[(fYec0_idx+i-142)&255]) + (fSlow420 * fYec0[(fYec0_idx+i-38)&255]))) + ((fSlow417 * ((fSlow414 * fYec0[(fYec0_idx+i-141)&255]) + (fSlow412 * fYec0[(fYec0_idx+i-39)&255]))) + ((fSlow409 * ((fSlow406 * fYec0[(fYec0_idx+i-140)&255]) + (fSlow404 * fYec0[(fYec0_idx+i-40)&255]))) + ((fSlow401 * ((fSlow398 * fYec0[(fYec0_idx+i-139)&255]) + (fSlow396 * fYec0[(fYec0_idx+i-41)&255]))) + ((fSlow393 * ((fSlow390 * fYec0[(fYec0_idx+i-138)&255]) + (fSlow388 * fYec0[(fYec0_idx+i-42)&255]))) + ((fSlow385 * ((fSlow382 * fYec0[(fYec0_idx+i-137)&255]) + (fSlow380 * fYec0[(fYec0_idx+i-43)&255]))) + ((fSlow377 * ((fSlow374 * fYec0[(fYec0_idx+i-136)&255]) + (fSlow372 * fYec0[(fYec0_idx+i-44)&255]))) + ((fSlow369 * ((fSlow366 * fYec0[(fYec0_idx+i-135)&255]) + (fSlow364 * fYec0[(fYec0_idx+i-45)&255]))) + ((fSlow361 * ((fSlow358 * fYec0[(fYec0_idx+i-134)&255]) + (fSlow356 * fYec0[(fYec0_idx+i-46)&255]))) + ((fSlow353 * ((fSlow350 * fYec0[(fYec0_idx+i-133)&255]) + (fSlow348 * fYec0[(fYec0_idx+i-47)&255]))) + ((fSlow345 * ((fSlow342 * fYec0[(fYec0_idx+i-132)&255]) + (fSlow340 * fYec0[(fYec0_idx+i-48)&255]))) + ((fSlow337 * ((fSlow334 * fYec0[(fYec0_idx+i-131)&255]) + (fSlow332 * fYec0[(fYec0_idx+i-49)&255]))) + ((fSlow329 * ((fSlow326 * fYec0[(fYec0_idx+i-130)&255]) + (fSlow324 * fYec0[(fYec0_idx+i-50)&255]))) + ((fSlow321 * ((fSlow318 * fYec0[(fYec0_idx+i-129)&255]) + (fSlow316 * fYec0[(fYec0_idx+i-51)&255]))) + ((fSlow313 * ((fSlow310 * fYec0[(fYec0_idx+i-128)&255]) + (fSlow308 * fYec0[(fYec0_idx+i-52)&255]))) + ((fSlow305 * ((fSlow302 * fYec0[(fYec0_idx+i-127)&255]) + (fSlow300 * fYec0[(fYec0_idx+i-53)&255]))) + ((fSlow297 * ((fSlow294 * fYec0[(fYec0_idx+i-126)&255]) + (fSlow292 * fYec0[(fYec0_idx+i-54)&255]))) + ((fSlow289 * ((fSlow286 * fYec0[(fYec0_idx+i-125)&255]) + (fSlow284 * fYec0[(fYec0_idx+i-55)&255]))) + ((fSlow281 * ((fSlow278 * fYec0[(fYec0_idx+i-124)&255]) + (fSlow276 * fYec0[(fYec0_idx+i-56)&255]))) + ((fSlow273 * ((fSlow270 * fYec0[(fYec0_idx+i-123)&255]) + (fSlow268 * fYec0[(fYec0_idx+i-57)&255]))) + ((fSlow265 * ((fSlow262 * fYec0[(fYec0_idx+i-122)&255]) + (fSlow260 * fYec0[(fYec0_idx+i-58)&255]))) + ((fSlow257 * ((fSlow254 * fYec0[(fYec0_idx+i-121)&255]) + (fSlow252 * fYec0[(fYec0_idx+i-59)&255]))) + ((fSlow249 * ((fSlow246 * fYec0[(fYec0_idx+i-120)&255]) + (fSlow244 * fYec0[(fYec0_idx+i-60)&255]))) + ((fSlow241 * ((fSlow238 * fYec0[(fYec0_idx+i-119)&255]) + (fSlow236 * fYec0[(fYec0_idx+i-61)&255]))) + ((fSlow233 * ((fSlow230 * fYec0[(fYec0_idx+i-118)&255]) + (fSlow228 * fYec0[(fYec0_idx+i-62)&255]))) + ((fSlow225 * ((fSlow222 * fYec0[(fYec0_idx+i-117)&255]) + (fSlow220 * fYec0[(fYec0_idx+i-63)&255]))) + ((fSlow217 * ((fSlow214 * fYec0[(fYec0_idx+i-116)&255]) + (fSlow212 * fYec0[(fYec0_idx+i-64)&255]))) + ((fSlow209 * ((fSlow206 * fYec0[(fYec0_idx+i-115)&255]) + (fSlow204 * fYec0[(fYec0_idx+i-65)&255]))) + ((fSlow201 * ((fSlow198 * fYec0[(fYec0_idx+i-114)&255]) + (fSlow196 * fYec0[(fYec0_idx+i-66)&255]))) + ((fSlow193 * ((fSlow190 * fYec0[(fYec0_idx+i-113)&255]) + (fSlow188 * fYec0[(fYec0_idx+i-67)&255]))) + ((fSlow185 * ((fSlow182 * fYec0[(fYec0_idx+i-112)&255]) + (fSlow180 * fYec0[(fYec0_idx+i-68)&255]))) + ((fSlow177 * ((fSlow174 * fYec0[(fYec0_idx+i-111)&255]) + (fSlow172 * fYec0[(fYec0_idx+i-69)&255]))) + ((fSlow169 * ((fSlow166 * fYec0[(fYec0_idx+i-110)&255]) + (fSlow164 * fYec0[(fYec0_idx+i-70)&255]))) + ((fSlow161 * ((fSlow158 * fYec0[(fYec0_idx+i-109)&255]) + (fSlow156 * fYec0[(fYec0_idx+i-71)&255]))) + ((fSlow153 * ((fSlow150 * fYec0[(fYec0_idx+i-108)&255]) + (fSlow148 * fYec0[(fYec0_idx+i-72)&255]))) + ((fSlow145 * ((fSlow142 * fYec0[(fYec0_idx+i-107)&255]) + (fSlow140 * fYec0[(fYec0_idx+i-73)&255]))) + ((fSlow137 * ((fSlow134 * fYec0[(fYec0_idx+i-106)&255]) + (fSlow132 * fYec0[(fYec0_idx+i-74)&255]))) + ((fSlow129 * ((fSlow126 * fYec0[(fYec0_idx+i-105)&255]) + (fSlow124 * fYec0[(fYec0_idx+i-75)&255]))) + ((fSlow121 * ((fSlow118 * fYec0[(fYec0_idx+i-104)&255]) + (fSlow116 * fYec0[(fYec0_idx+i-76)&255]))) + ((fSlow113 * ((fSlow110 * fYec0[(fYec0_idx+i-103)&255]) + (fSlow108 * fYec0[(fYec0_idx+i-77)&255]))) + ((fSlow105 * ((fSlow102 * fYec0[(fYec0_idx+i-102)&255]) + (fSlow100 * fYec0[(fYec0_idx+i-78)&255]))) + ((fSlow97 * ((fSlow94 * fYec0[(fYec0_idx+i-101)&255]) + (fSlow92 * fYec0[(fYec0_idx+i-79)&255]))) + ((fSlow89 * ((fSlow86 * fYec0[(fYec0_idx+i-100)&255]) + (fSlow84 * fYec0[(fYec0_idx+i-80)&255]))) + ((fSlow81 * ((fSlow78 * fYec0[(fYec0_idx+i-99)&255]) + (fSlow76 * fYec0[(fYec0_idx+i-81)&255]))) + ((fSlow73 * ((fSlow70 * fYec0[(fYec0_idx+i-98)&255]) + (fSlow68 * fYec0[(fYec0_idx+i-82)&255]))) + ((fSlow65 * ((fSlow62 * fYec0[(fYec0_idx+i-97)&255]) + (fSlow60 * fYec0[(fYec0_idx+i-83)&255]))) + ((fSlow57 * ((fSlow54 * fYec0[(fYec0_idx+i-96)&255]) + (fSlow52 * fYec0[(fYec0_idx+i-84)&255]))) + ((fSlow49 * ((fSlow46 * fYec0[(fYec0_idx+i-95)&255]) + (fSlow44 * fYec0[(fYec0_idx+i-85)&255]))) + ((fSlow41 * ((fSlow38 * fYec0[(fYec0_idx+i-94)&255]) + (fSlow36 * fYec0[(fYec0_idx+i-86)&255]))) + ((fSlow33 * ((fSlow30 * fYec0[(fYec0_idx+i-93)&255]) + (fSlow28 * fYec0[(fYec0_idx+i-87)&255]))) + ((fSlow25 * ((fSlow22 * fYec0[(fYec0_idx+i-92)&255]) + (fSlow20 * fYec0[(fYec0_idx+i-88)&255]))) + ((fSlow17 * ((fSlow14 * fYec0[(fYec0_idx+i-91)&255]) + (fSlow12 * fYec0[(fYec0_idx+i-89)&255]))) + ((fSlow9 * fYec0[(fYec0_idx+i-90)&255]) + (fSlow8 * fYec0[(fYec0_idx+i) & 255])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))));
			}
			// post processing
			fYec1_idx_save = count;
			
			// LOOP 0x1742dcc8
			// pre processing
			fYec2_idx = (fYec2_idx+fYec2_idx_save)&127;
			// exec code
			for (int i=0; i<count; i++) {
				fYec2[(fYec2_idx+i)&127] = (fZec3[i] + (fSlow931 * (float)input0[i]));
			}
			// post processing
			fYec2_idx_save = count;
			
			// LOOP 0x1742e100
			// pre processing
			fYec4_idx = (fYec4_idx+fYec4_idx_save)&1023;
			// exec code
			for (int i=0; i<count; i++) {
				fYec4[(fYec4_idx+i)&1023] = ((fSlow904 * ((fSlow721 * ((fSlow903 * fYec3[(fYec3_idx+i-179)&255]) + (fSlow902 * fYec3[(fYec3_idx+i-1)&255]))) + ((fSlow713 * ((fSlow901 * fYec3[(fYec3_idx+i-178)&255]) + (fSlow900 * fYec3[(fYec3_idx+i-2)&255]))) + ((fSlow705 * ((fSlow899 * fYec3[(fYec3_idx+i-177)&255]) + (fSlow898 * fYec3[(fYec3_idx+i-3)&255]))) + ((fSlow697 * ((fSlow897 * fYec3[(fYec3_idx+i-176)&255]) + (fSlow896 * fYec3[(fYec3_idx+i-4)&255]))) + ((fSlow689 * ((fSlow895 * fYec3[(fYec3_idx+i-175)&255]) + (fSlow894 * fYec3[(fYec3_idx+i-5)&255]))) + ((fSlow681 * ((fSlow893 * fYec3[(fYec3_idx+i-174)&255]) + (fSlow892 * fYec3[(fYec3_idx+i-6)&255]))) + ((fSlow673 * ((fSlow891 * fYec3[(fYec3_idx+i-173)&255]) + (fSlow890 * fYec3[(fYec3_idx+i-7)&255]))) + ((fSlow665 * ((fSlow889 * fYec3[(fYec3_idx+i-172)&255]) + (fSlow888 * fYec3[(fYec3_idx+i-8)&255]))) + ((fSlow657 * ((fSlow887 * fYec3[(fYec3_idx+i-171)&255]) + (fSlow886 * fYec3[(fYec3_idx+i-9)&255]))) + ((fSlow649 * ((fSlow885 * fYec3[(fYec3_idx+i-170)&255]) + (fSlow884 * fYec3[(fYec3_idx+i-10)&255]))) + ((fSlow641 * ((fSlow883 * fYec3[(fYec3_idx+i-169)&255]) + (fSlow882 * fYec3[(fYec3_idx+i-11)&255]))) + ((fSlow633 * ((fSlow881 * fYec3[(fYec3_idx+i-168)&255]) + (fSlow880 * fYec3[(fYec3_idx+i-12)&255]))) + ((fSlow625 * ((fSlow879 * fYec3[(fYec3_idx+i-167)&255]) + (fSlow878 * fYec3[(fYec3_idx+i-13)&255]))) + ((fSlow617 * ((fSlow877 * fYec3[(fYec3_idx+i-166)&255]) + (fSlow876 * fYec3[(fYec3_idx+i-14)&255]))) + ((fSlow609 * ((fSlow875 * fYec3[(fYec3_idx+i-165)&255]) + (fSlow874 * fYec3[(fYec3_idx+i-15)&255]))) + ((fSlow601 * ((fSlow873 * fYec3[(fYec3_idx+i-164)&255]) + (fSlow872 * fYec3[(fYec3_idx+i-16)&255]))) + ((fSlow593 * ((fSlow871 * fYec3[(fYec3_idx+i-163)&255]) + (fSlow870 * fYec3[(fYec3_idx+i-17)&255]))) + ((fSlow585 * ((fSlow869 * fYec3[(fYec3_idx+i-162)&255]) + (fSlow868 * fYec3[(fYec3_idx+i-18)&255]))) + ((fSlow577 * ((fSlow867 * fYec3[(fYec3_idx+i-161)&255]) + (fSlow866 * fYec3[(fYec3_idx+i-19)&255]))) + ((fSlow569 * ((fSlow865 * fYec3[(fYec3_idx+i-160)&255]) + (fSlow864 * fYec3[(fYec3_idx+i-20)&255]))) + ((fSlow561 * ((fSlow863 * fYec3[(fYec3_idx+i-159)&255]) + (fSlow862 * fYec3[(fYec3_idx+i-21)&255]))) + ((fSlow553 * ((fSlow861 * fYec3[(fYec3_idx+i-158)&255]) + (fSlow860 * fYec3[(fYec3_idx+i-22)&255]))) + ((fSlow545 * ((fSlow859 * fYec3[(fYec3_idx+i-157)&255]) + (fSlow858 * fYec3[(fYec3_idx+i-23)&255]))) + ((fSlow537 * ((fSlow857 * fYec3[(fYec3_idx+i-156)&255]) + (fSlow856 * fYec3[(fYec3_idx+i-24)&255]))) + ((fSlow529 * ((fSlow855 * fYec3[(fYec3_idx+i-155)&255]) + (fSlow854 * fYec3[(fYec3_idx+i-25)&255]))) + ((fSlow521 * ((fSlow853 * fYec3[(fYec3_idx+i-154)&255]) + (fSlow852 * fYec3[(fYec3_idx+i-26)&255]))) + ((fSlow513 * ((fSlow851 * fYec3[(fYec3_idx+i-153)&255]) + (fSlow850 * fYec3[(fYec3_idx+i-27)&255]))) + ((fSlow505 * ((fSlow849 * fYec3[(fYec3_idx+i-152)&255]) + (fSlow848 * fYec3[(fYec3_idx+i-28)&255]))) + ((fSlow497 * ((fSlow847 * fYec3[(fYec3_idx+i-151)&255]) + (fSlow846 * fYec3[(fYec3_idx+i-29)&255]))) + ((fSlow489 * ((fSlow845 * fYec3[(fYec3_idx+i-150)&255]) + (fSlow844 * fYec3[(fYec3_idx+i-30)&255]))) + ((fSlow481 * ((fSlow843 * fYec3[(fYec3_idx+i-149)&255]) + (fSlow842 * fYec3[(fYec3_idx+i-31)&255]))) + ((fSlow473 * ((fSlow841 * fYec3[(fYec3_idx+i-148)&255]) + (fSlow840 * fYec3[(fYec3_idx+i-32)&255]))) + ((fSlow465 * ((fSlow839 * fYec3[(fYec3_idx+i-147)&255]) + (fSlow838 * fYec3[(fYec3_idx+i-33)&255]))) + ((fSlow457 * ((fSlow837 * fYec3[(fYec3_idx+i-146)&255]) + (fSlow836 * fYec3[(fYec3_idx+i-34)&255]))) + ((fSlow449 * ((fSlow835 * fYec3[(fYec3_idx+i-145)&255]) + (fSlow834 * fYec3[(fYec3_idx+i-35)&255]))) + ((fSlow441 * ((fSlow833 * fYec3[(fYec3_idx+i-144)&255]) + (fSlow832 * fYec3[(fYec3_idx+i-36)&255]))) + ((fSlow433 * ((fSlow831 * fYec3[(fYec3_idx+i-143)&255]) + (fSlow830 * fYec3[(fYec3_idx+i-37)&255]))) + ((fSlow425 * ((fSlow829 * fYec3[(fYec3_idx+i-142)&255]) + (fSlow828 * fYec3[(fYec3_idx+i-38)&255]))) + ((fSlow417 * ((fSlow827 * fYec3[(fYec3_idx+i-141)&255]) + (fSlow826 * fYec3[(fYec3_idx+i-39)&255]))) + ((fSlow409 * ((fSlow825 * fYec3[(fYec3_idx+i-140)&255]) + (fSlow824 * fYec3[(fYec3_idx+i-40)&255]))) + ((fSlow401 * ((fSlow823 * fYec3[(fYec3_idx+i-139)&255]) + (fSlow822 * fYec3[(fYec3_idx+i-41)&255]))) + ((fSlow393 * ((fSlow821 * fYec3[(fYec3_idx+i-138)&255]) + (fSlow820 * fYec3[(fYec3_idx+i-42)&255]))) + ((fSlow385 * ((fSlow819 * fYec3[(fYec3_idx+i-137)&255]) + (fSlow818 * fYec3[(fYec3_idx+i-43)&255]))) + ((fSlow377 * ((fSlow817 * fYec3[(fYec3_idx+i-136)&255]) + (fSlow816 * fYec3[(fYec3_idx+i-44)&255]))) + ((fSlow369 * ((fSlow815 * fYec3[(fYec3_idx+i-135)&255]) + (fSlow814 * fYec3[(fYec3_idx+i-45)&255]))) + ((fSlow361 * ((fSlow813 * fYec3[(fYec3_idx+i-134)&255]) + (fSlow812 * fYec3[(fYec3_idx+i-46)&255]))) + ((fSlow353 * ((fSlow811 * fYec3[(fYec3_idx+i-133)&255]) + (fSlow810 * fYec3[(fYec3_idx+i-47)&255]))) + ((fSlow345 * ((fSlow809 * fYec3[(fYec3_idx+i-132)&255]) + (fSlow808 * fYec3[(fYec3_idx+i-48)&255]))) + ((fSlow337 * ((fSlow807 * fYec3[(fYec3_idx+i-131)&255]) + (fSlow806 * fYec3[(fYec3_idx+i-49)&255]))) + ((fSlow329 * ((fSlow805 * fYec3[(fYec3_idx+i-130)&255]) + (fSlow804 * fYec3[(fYec3_idx+i-50)&255]))) + ((fSlow321 * ((fSlow803 * fYec3[(fYec3_idx+i-129)&255]) + (fSlow802 * fYec3[(fYec3_idx+i-51)&255]))) + ((fSlow313 * ((fSlow801 * fYec3[(fYec3_idx+i-128)&255]) + (fSlow800 * fYec3[(fYec3_idx+i-52)&255]))) + ((fSlow305 * ((fSlow799 * fYec3[(fYec3_idx+i-127)&255]) + (fSlow798 * fYec3[(fYec3_idx+i-53)&255]))) + ((fSlow297 * ((fSlow797 * fYec3[(fYec3_idx+i-126)&255]) + (fSlow796 * fYec3[(fYec3_idx+i-54)&255]))) + ((fSlow289 * ((fSlow795 * fYec3[(fYec3_idx+i-125)&255]) + (fSlow794 * fYec3[(fYec3_idx+i-55)&255]))) + ((fSlow281 * ((fSlow793 * fYec3[(fYec3_idx+i-124)&255]) + (fSlow792 * fYec3[(fYec3_idx+i-56)&255]))) + ((fSlow273 * ((fSlow791 * fYec3[(fYec3_idx+i-123)&255]) + (fSlow790 * fYec3[(fYec3_idx+i-57)&255]))) + ((fSlow265 * ((fSlow789 * fYec3[(fYec3_idx+i-122)&255]) + (fSlow788 * fYec3[(fYec3_idx+i-58)&255]))) + ((fSlow257 * ((fSlow787 * fYec3[(fYec3_idx+i-121)&255]) + (fSlow786 * fYec3[(fYec3_idx+i-59)&255]))) + ((fSlow249 * ((fSlow785 * fYec3[(fYec3_idx+i-120)&255]) + (fSlow784 * fYec3[(fYec3_idx+i-60)&255]))) + ((fSlow241 * ((fSlow783 * fYec3[(fYec3_idx+i-119)&255]) + (fSlow782 * fYec3[(fYec3_idx+i-61)&255]))) + ((fSlow233 * ((fSlow781 * fYec3[(fYec3_idx+i-118)&255]) + (fSlow780 * fYec3[(fYec3_idx+i-62)&255]))) + ((fSlow225 * ((fSlow779 * fYec3[(fYec3_idx+i-117)&255]) + (fSlow778 * fYec3[(fYec3_idx+i-63)&255]))) + ((fSlow217 * ((fSlow777 * fYec3[(fYec3_idx+i-116)&255]) + (fSlow776 * fYec3[(fYec3_idx+i-64)&255]))) + ((fSlow209 * ((fSlow775 * fYec3[(fYec3_idx+i-115)&255]) + (fSlow774 * fYec3[(fYec3_idx+i-65)&255]))) + ((fSlow201 * ((fSlow773 * fYec3[(fYec3_idx+i-114)&255]) + (fSlow772 * fYec3[(fYec3_idx+i-66)&255]))) + ((fSlow193 * ((fSlow771 * fYec3[(fYec3_idx+i-113)&255]) + (fSlow770 * fYec3[(fYec3_idx+i-67)&255]))) + ((fSlow185 * ((fSlow769 * fYec3[(fYec3_idx+i-112)&255]) + (fSlow768 * fYec3[(fYec3_idx+i-68)&255]))) + ((fSlow177 * ((fSlow767 * fYec3[(fYec3_idx+i-111)&255]) + (fSlow766 * fYec3[(fYec3_idx+i-69)&255]))) + ((fSlow169 * ((fSlow765 * fYec3[(fYec3_idx+i-110)&255]) + (fSlow764 * fYec3[(fYec3_idx+i-70)&255]))) + ((fSlow161 * ((fSlow763 * fYec3[(fYec3_idx+i-109)&255]) + (fSlow762 * fYec3[(fYec3_idx+i-71)&255]))) + ((fSlow153 * ((fSlow761 * fYec3[(fYec3_idx+i-108)&255]) + (fSlow760 * fYec3[(fYec3_idx+i-72)&255]))) + ((fSlow145 * ((fSlow759 * fYec3[(fYec3_idx+i-107)&255]) + (fSlow758 * fYec3[(fYec3_idx+i-73)&255]))) + ((fSlow137 * ((fSlow757 * fYec3[(fYec3_idx+i-106)&255]) + (fSlow756 * fYec3[(fYec3_idx+i-74)&255]))) + ((fSlow129 * ((fSlow755 * fYec3[(fYec3_idx+i-105)&255]) + (fSlow754 * fYec3[(fYec3_idx+i-75)&255]))) + ((fSlow121 * ((fSlow753 * fYec3[(fYec3_idx+i-104)&255]) + (fSlow752 * fYec3[(fYec3_idx+i-76)&255]))) + ((fSlow113 * ((fSlow751 * fYec3[(fYec3_idx+i-103)&255]) + (fSlow750 * fYec3[(fYec3_idx+i-77)&255]))) + ((fSlow105 * ((fSlow749 * fYec3[(fYec3_idx+i-102)&255]) + (fSlow748 * fYec3[(fYec3_idx+i-78)&255]))) + ((fSlow97 * ((fSlow747 * fYec3[(fYec3_idx+i-101)&255]) + (fSlow746 * fYec3[(fYec3_idx+i-79)&255]))) + ((fSlow89 * ((fSlow745 * fYec3[(fYec3_idx+i-100)&255]) + (fSlow744 * fYec3[(fYec3_idx+i-80)&255]))) + ((fSlow81 * ((fSlow743 * fYec3[(fYec3_idx+i-99)&255]) + (fSlow742 * fYec3[(fYec3_idx+i-81)&255]))) + ((fSlow73 * ((fSlow741 * fYec3[(fYec3_idx+i-98)&255]) + (fSlow740 * fYec3[(fYec3_idx+i-82)&255]))) + ((fSlow65 * ((fSlow739 * fYec3[(fYec3_idx+i-97)&255]) + (fSlow738 * fYec3[(fYec3_idx+i-83)&255]))) + ((fSlow57 * ((fSlow737 * fYec3[(fYec3_idx+i-96)&255]) + (fSlow736 * fYec3[(fYec3_idx+i-84)&255]))) + ((fSlow49 * ((fSlow735 * fYec3[(fYec3_idx+i-95)&255]) + (fSlow734 * fYec3[(fYec3_idx+i-85)&255]))) + ((fSlow41 * ((fSlow733 * fYec3[(fYec3_idx+i-94)&255]) + (fSlow732 * fYec3[(fYec3_idx+i-86)&255]))) + ((fSlow33 * ((fSlow731 * fYec3[(fYec3_idx+i-93)&255]) + (fSlow730 * fYec3[(fYec3_idx+i-87)&255]))) + ((fSlow25 * ((fSlow729 * fYec3[(fYec3_idx+i-92)&255]) + (fSlow728 * fYec3[(fYec3_idx+i-88)&255]))) + ((fSlow17 * ((fSlow727 * fYec3[(fYec3_idx+i-91)&255]) + (fSlow726 * fYec3[(fYec3_idx+i-89)&255]))) + ((fSlow725 * fYec3[(fYec3_idx+i-90)&255]) + (fSlow724 * fYec3[(fYec3_idx+i) & 255])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))) + (fSlow722 * ((fSlow721 * ((fSlow718 * fYec3[(fYec3_idx+i-179)&255]) + (fSlow716 * fYec3[(fYec3_idx+i-1)&255]))) + ((fSlow713 * ((fSlow710 * fYec3[(fYec3_idx+i-178)&255]) + (fSlow708 * fYec3[(fYec3_idx+i-2)&255]))) + ((fSlow705 * ((fSlow702 * fYec3[(fYec3_idx+i-177)&255]) + (fSlow700 * fYec3[(fYec3_idx+i-3)&255]))) + ((fSlow697 * ((fSlow694 * fYec3[(fYec3_idx+i-176)&255]) + (fSlow692 * fYec3[(fYec3_idx+i-4)&255]))) + ((fSlow689 * ((fSlow686 * fYec3[(fYec3_idx+i-175)&255]) + (fSlow684 * fYec3[(fYec3_idx+i-5)&255]))) + ((fSlow681 * ((fSlow678 * fYec3[(fYec3_idx+i-174)&255]) + (fSlow676 * fYec3[(fYec3_idx+i-6)&255]))) + ((fSlow673 * ((fSlow670 * fYec3[(fYec3_idx+i-173)&255]) + (fSlow668 * fYec3[(fYec3_idx+i-7)&255]))) + ((fSlow665 * ((fSlow662 * fYec3[(fYec3_idx+i-172)&255]) + (fSlow660 * fYec3[(fYec3_idx+i-8)&255]))) + ((fSlow657 * ((fSlow654 * fYec3[(fYec3_idx+i-171)&255]) + (fSlow652 * fYec3[(fYec3_idx+i-9)&255]))) + ((fSlow649 * ((fSlow646 * fYec3[(fYec3_idx+i-170)&255]) + (fSlow644 * fYec3[(fYec3_idx+i-10)&255]))) + ((fSlow641 * ((fSlow638 * fYec3[(fYec3_idx+i-169)&255]) + (fSlow636 * fYec3[(fYec3_idx+i-11)&255]))) + ((fSlow633 * ((fSlow630 * fYec3[(fYec3_idx+i-168)&255]) + (fSlow628 * fYec3[(fYec3_idx+i-12)&255]))) + ((fSlow625 * ((fSlow622 * fYec3[(fYec3_idx+i-167)&255]) + (fSlow620 * fYec3[(fYec3_idx+i-13)&255]))) + ((fSlow617 * ((fSlow614 * fYec3[(fYec3_idx+i-166)&255]) + (fSlow612 * fYec3[(fYec3_idx+i-14)&255]))) + ((fSlow609 * ((fSlow606 * fYec3[(fYec3_idx+i-165)&255]) + (fSlow604 * fYec3[(fYec3_idx+i-15)&255]))) + ((fSlow601 * ((fSlow598 * fYec3[(fYec3_idx+i-164)&255]) + (fSlow596 * fYec3[(fYec3_idx+i-16)&255]))) + ((fSlow593 * ((fSlow590 * fYec3[(fYec3_idx+i-163)&255]) + (fSlow588 * fYec3[(fYec3_idx+i-17)&255]))) + ((fSlow585 * ((fSlow582 * fYec3[(fYec3_idx+i-162)&255]) + (fSlow580 * fYec3[(fYec3_idx+i-18)&255]))) + ((fSlow577 * ((fSlow574 * fYec3[(fYec3_idx+i-161)&255]) + (fSlow572 * fYec3[(fYec3_idx+i-19)&255]))) + ((fSlow569 * ((fSlow566 * fYec3[(fYec3_idx+i-160)&255]) + (fSlow564 * fYec3[(fYec3_idx+i-20)&255]))) + ((fSlow561 * ((fSlow558 * fYec3[(fYec3_idx+i-159)&255]) + (fSlow556 * fYec3[(fYec3_idx+i-21)&255]))) + ((fSlow553 * ((fSlow550 * fYec3[(fYec3_idx+i-158)&255]) + (fSlow548 * fYec3[(fYec3_idx+i-22)&255]))) + ((fSlow545 * ((fSlow542 * fYec3[(fYec3_idx+i-157)&255]) + (fSlow540 * fYec3[(fYec3_idx+i-23)&255]))) + ((fSlow537 * ((fSlow534 * fYec3[(fYec3_idx+i-156)&255]) + (fSlow532 * fYec3[(fYec3_idx+i-24)&255]))) + ((fSlow529 * ((fSlow526 * fYec3[(fYec3_idx+i-155)&255]) + (fSlow524 * fYec3[(fYec3_idx+i-25)&255]))) + ((fSlow521 * ((fSlow518 * fYec3[(fYec3_idx+i-154)&255]) + (fSlow516 * fYec3[(fYec3_idx+i-26)&255]))) + ((fSlow513 * ((fSlow510 * fYec3[(fYec3_idx+i-153)&255]) + (fSlow508 * fYec3[(fYec3_idx+i-27)&255]))) + ((fSlow505 * ((fSlow502 * fYec3[(fYec3_idx+i-152)&255]) + (fSlow500 * fYec3[(fYec3_idx+i-28)&255]))) + ((fSlow497 * ((fSlow494 * fYec3[(fYec3_idx+i-151)&255]) + (fSlow492 * fYec3[(fYec3_idx+i-29)&255]))) + ((fSlow489 * ((fSlow486 * fYec3[(fYec3_idx+i-150)&255]) + (fSlow484 * fYec3[(fYec3_idx+i-30)&255]))) + ((fSlow481 * ((fSlow478 * fYec3[(fYec3_idx+i-149)&255]) + (fSlow476 * fYec3[(fYec3_idx+i-31)&255]))) + ((fSlow473 * ((fSlow470 * fYec3[(fYec3_idx+i-148)&255]) + (fSlow468 * fYec3[(fYec3_idx+i-32)&255]))) + ((fSlow465 * ((fSlow462 * fYec3[(fYec3_idx+i-147)&255]) + (fSlow460 * fYec3[(fYec3_idx+i-33)&255]))) + ((fSlow457 * ((fSlow454 * fYec3[(fYec3_idx+i-146)&255]) + (fSlow452 * fYec3[(fYec3_idx+i-34)&255]))) + ((fSlow449 * ((fSlow446 * fYec3[(fYec3_idx+i-145)&255]) + (fSlow444 * fYec3[(fYec3_idx+i-35)&255]))) + ((fSlow441 * ((fSlow438 * fYec3[(fYec3_idx+i-144)&255]) + (fSlow436 * fYec3[(fYec3_idx+i-36)&255]))) + ((fSlow433 * ((fSlow430 * fYec3[(fYec3_idx+i-143)&255]) + (fSlow428 * fYec3[(fYec3_idx+i-37)&255]))) + ((fSlow425 * ((fSlow422 * fYec3[(fYec3_idx+i-142)&255]) + (fSlow420 * fYec3[(fYec3_idx+i-38)&255]))) + ((fSlow417 * ((fSlow414 * fYec3[(fYec3_idx+i-141)&255]) + (fSlow412 * fYec3[(fYec3_idx+i-39)&255]))) + ((fSlow409 * ((fSlow406 * fYec3[(fYec3_idx+i-140)&255]) + (fSlow404 * fYec3[(fYec3_idx+i-40)&255]))) + ((fSlow401 * ((fSlow398 * fYec3[(fYec3_idx+i-139)&255]) + (fSlow396 * fYec3[(fYec3_idx+i-41)&255]))) + ((fSlow393 * ((fSlow390 * fYec3[(fYec3_idx+i-138)&255]) + (fSlow388 * fYec3[(fYec3_idx+i-42)&255]))) + ((fSlow385 * ((fSlow382 * fYec3[(fYec3_idx+i-137)&255]) + (fSlow380 * fYec3[(fYec3_idx+i-43)&255]))) + ((fSlow377 * ((fSlow374 * fYec3[(fYec3_idx+i-136)&255]) + (fSlow372 * fYec3[(fYec3_idx+i-44)&255]))) + ((fSlow369 * ((fSlow366 * fYec3[(fYec3_idx+i-135)&255]) + (fSlow364 * fYec3[(fYec3_idx+i-45)&255]))) + ((fSlow361 * ((fSlow358 * fYec3[(fYec3_idx+i-134)&255]) + (fSlow356 * fYec3[(fYec3_idx+i-46)&255]))) + ((fSlow353 * ((fSlow350 * fYec3[(fYec3_idx+i-133)&255]) + (fSlow348 * fYec3[(fYec3_idx+i-47)&255]))) + ((fSlow345 * ((fSlow342 * fYec3[(fYec3_idx+i-132)&255]) + (fSlow340 * fYec3[(fYec3_idx+i-48)&255]))) + ((fSlow337 * ((fSlow334 * fYec3[(fYec3_idx+i-131)&255]) + (fSlow332 * fYec3[(fYec3_idx+i-49)&255]))) + ((fSlow329 * ((fSlow326 * fYec3[(fYec3_idx+i-130)&255]) + (fSlow324 * fYec3[(fYec3_idx+i-50)&255]))) + ((fSlow321 * ((fSlow318 * fYec3[(fYec3_idx+i-129)&255]) + (fSlow316 * fYec3[(fYec3_idx+i-51)&255]))) + ((fSlow313 * ((fSlow310 * fYec3[(fYec3_idx+i-128)&255]) + (fSlow308 * fYec3[(fYec3_idx+i-52)&255]))) + ((fSlow305 * ((fSlow302 * fYec3[(fYec3_idx+i-127)&255]) + (fSlow300 * fYec3[(fYec3_idx+i-53)&255]))) + ((fSlow297 * ((fSlow294 * fYec3[(fYec3_idx+i-126)&255]) + (fSlow292 * fYec3[(fYec3_idx+i-54)&255]))) + ((fSlow289 * ((fSlow286 * fYec3[(fYec3_idx+i-125)&255]) + (fSlow284 * fYec3[(fYec3_idx+i-55)&255]))) + ((fSlow281 * ((fSlow278 * fYec3[(fYec3_idx+i-124)&255]) + (fSlow276 * fYec3[(fYec3_idx+i-56)&255]))) + ((fSlow273 * ((fSlow270 * fYec3[(fYec3_idx+i-123)&255]) + (fSlow268 * fYec3[(fYec3_idx+i-57)&255]))) + ((fSlow265 * ((fSlow262 * fYec3[(fYec3_idx+i-122)&255]) + (fSlow260 * fYec3[(fYec3_idx+i-58)&255]))) + ((fSlow257 * ((fSlow254 * fYec3[(fYec3_idx+i-121)&255]) + (fSlow252 * fYec3[(fYec3_idx+i-59)&255]))) + ((fSlow249 * ((fSlow246 * fYec3[(fYec3_idx+i-120)&255]) + (fSlow244 * fYec3[(fYec3_idx+i-60)&255]))) + ((fSlow241 * ((fSlow238 * fYec3[(fYec3_idx+i-119)&255]) + (fSlow236 * fYec3[(fYec3_idx+i-61)&255]))) + ((fSlow233 * ((fSlow230 * fYec3[(fYec3_idx+i-118)&255]) + (fSlow228 * fYec3[(fYec3_idx+i-62)&255]))) + ((fSlow225 * ((fSlow222 * fYec3[(fYec3_idx+i-117)&255]) + (fSlow220 * fYec3[(fYec3_idx+i-63)&255]))) + ((fSlow217 * ((fSlow214 * fYec3[(fYec3_idx+i-116)&255]) + (fSlow212 * fYec3[(fYec3_idx+i-64)&255]))) + ((fSlow209 * ((fSlow206 * fYec3[(fYec3_idx+i-115)&255]) + (fSlow204 * fYec3[(fYec3_idx+i-65)&255]))) + ((fSlow201 * ((fSlow198 * fYec3[(fYec3_idx+i-114)&255]) + (fSlow196 * fYec3[(fYec3_idx+i-66)&255]))) + ((fSlow193 * ((fSlow190 * fYec3[(fYec3_idx+i-113)&255]) + (fSlow188 * fYec3[(fYec3_idx+i-67)&255]))) + ((fSlow185 * ((fSlow182 * fYec3[(fYec3_idx+i-112)&255]) + (fSlow180 * fYec3[(fYec3_idx+i-68)&255]))) + ((fSlow177 * ((fSlow174 * fYec3[(fYec3_idx+i-111)&255]) + (fSlow172 * fYec3[(fYec3_idx+i-69)&255]))) + ((fSlow169 * ((fSlow166 * fYec3[(fYec3_idx+i-110)&255]) + (fSlow164 * fYec3[(fYec3_idx+i-70)&255]))) + ((fSlow161 * ((fSlow158 * fYec3[(fYec3_idx+i-109)&255]) + (fSlow156 * fYec3[(fYec3_idx+i-71)&255]))) + ((fSlow153 * ((fSlow150 * fYec3[(fYec3_idx+i-108)&255]) + (fSlow148 * fYec3[(fYec3_idx+i-72)&255]))) + ((fSlow145 * ((fSlow142 * fYec3[(fYec3_idx+i-107)&255]) + (fSlow140 * fYec3[(fYec3_idx+i-73)&255]))) + ((fSlow137 * ((fSlow134 * fYec3[(fYec3_idx+i-106)&255]) + (fSlow132 * fYec3[(fYec3_idx+i-74)&255]))) + ((fSlow129 * ((fSlow126 * fYec3[(fYec3_idx+i-105)&255]) + (fSlow124 * fYec3[(fYec3_idx+i-75)&255]))) + ((fSlow121 * ((fSlow118 * fYec3[(fYec3_idx+i-104)&255]) + (fSlow116 * fYec3[(fYec3_idx+i-76)&255]))) + ((fSlow113 * ((fSlow110 * fYec3[(fYec3_idx+i-103)&255]) + (fSlow108 * fYec3[(fYec3_idx+i-77)&255]))) + ((fSlow105 * ((fSlow102 * fYec3[(fYec3_idx+i-102)&255]) + (fSlow100 * fYec3[(fYec3_idx+i-78)&255]))) + ((fSlow97 * ((fSlow94 * fYec3[(fYec3_idx+i-101)&255]) + (fSlow92 * fYec3[(fYec3_idx+i-79)&255]))) + ((fSlow89 * ((fSlow86 * fYec3[(fYec3_idx+i-100)&255]) + (fSlow84 * fYec3[(fYec3_idx+i-80)&255]))) + ((fSlow81 * ((fSlow78 * fYec3[(fYec3_idx+i-99)&255]) + (fSlow76 * fYec3[(fYec3_idx+i-81)&255]))) + ((fSlow73 * ((fSlow70 * fYec3[(fYec3_idx+i-98)&255]) + (fSlow68 * fYec3[(fYec3_idx+i-82)&255]))) + ((fSlow65 * ((fSlow62 * fYec3[(fYec3_idx+i-97)&255]) + (fSlow60 * fYec3[(fYec3_idx+i-83)&255]))) + ((fSlow57 * ((fSlow54 * fYec3[(fYec3_idx+i-96)&255]) + (fSlow52 * fYec3[(fYec3_idx+i-84)&255]))) + ((fSlow49 * ((fSlow46 * fYec3[(fYec3_idx+i-95)&255]) + (fSlow44 * fYec3[(fYec3_idx+i-85)&255]))) + ((fSlow41 * ((fSlow38 * fYec3[(fYec3_idx+i-94)&255]) + (fSlow36 * fYec3[(fYec3_idx+i-86)&255]))) + ((fSlow33 * ((fSlow30 * fYec3[(fYec3_idx+i-93)&255]) + (fSlow28 * fYec3[(fYec3_idx+i-87)&255]))) + ((fSlow25 * ((fSlow22 * fYec3[(fYec3_idx+i-92)&255]) + (fSlow20 * fYec3[(fYec3_idx+i-88)&255]))) + ((fSlow17 * ((fSlow14 * fYec3[(fYec3_idx+i-91)&255]) + (fSlow12 * fYec3[(fYec3_idx+i-89)&255]))) + ((fSlow9 * fYec3[(fYec3_idx+i-90)&255]) + (fSlow8 * fYec3[(fYec3_idx+i) & 255])))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))));
			}
			// post processing
			fYec4_idx_save = count;
			
			// LOOP 0x17676688
			// pre processing
			fYec5_idx = (fYec5_idx+fYec5_idx_save)&127;
			// exec code
			for (int i=0; i<count; i++) {
				fYec5[(fYec5_idx+i)&127] = (fZec3[i] + (fSlow931 * (float)input1[i]));
			}
			// post processing
			fYec5_idx_save = count;
			
			// SECTION : 5
			// LOOP 0x1209dd8
			// exec code
			for (int i=0; i<count; i++) {
				output0[i] = (FAUSTFLOAT)(fSlow934 * (((fSlow933 * fYec1[(fYec1_idx+i-iSlow932)&1023]) + (((0 - (1.999999999999997f * (0 - (6.217248937900886e-015f * fYec2[(fYec2_idx+i-93)&127])))) + (5.0f * (0 - (2.999999999999997f * (0 - (3.1086244689504383e-015f * (0 - (2.000000000000003f * fYec2[(fYec2_idx+i-92)&127])))))))) + (1e+001f * ((((0 - (2.999999999999997f * (0 - (1.2434497875801793e-014f * fYec2[(fYec2_idx+i-91)&127])))) + (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (0 - (2.000000000000003f * fYec2[(fYec2_idx+i-90)&127])))))))) + (0.5f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (6.217248937900867e-015f * fYec2[(fYec2_idx+i-89)&127])))))))) + (0.1f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (3.108624468950429e-015f * (0 - (1.000000000000003f * fYec2[(fYec2_idx+i-88)&127]))))))))))))) + (fSlow929 * ((fSlow927 * ((fSlow916 * ((fSlow914 * ((fSlow926 * fYec1[(fYec1_idx+i-iSlow925)&1023]) + (fSlow924 * fYec1[(fYec1_idx+i-iSlow923)&1023]))) + (fSlow922 * fYec1[(fYec1_idx+i-iSlow921)&1023]))) + (fSlow920 * fYec1[(fYec1_idx+i-iSlow918)&1023]))) + (fSlow917 * fYec1[(fYec1_idx+i-iSlow908)&1023])))));
			}
			
			// LOOP 0x1742e088
			// exec code
			for (int i=0; i<count; i++) {
				output1[i] = (FAUSTFLOAT)(fSlow934 * (((fSlow933 * fYec4[(fYec4_idx+i-iSlow932)&1023]) + (((0 - (1.999999999999997f * (0 - (6.217248937900886e-015f * fYec5[(fYec5_idx+i-93)&127])))) + (5.0f * (0 - (2.999999999999997f * (0 - (3.1086244689504383e-015f * (0 - (2.000000000000003f * fYec5[(fYec5_idx+i-92)&127])))))))) + (1e+001f * ((((0 - (2.999999999999997f * (0 - (1.2434497875801793e-014f * fYec5[(fYec5_idx+i-91)&127])))) + (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (0 - (2.000000000000003f * fYec5[(fYec5_idx+i-90)&127])))))))) + (0.5f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (6.217248937900867e-015f * fYec5[(fYec5_idx+i-89)&127])))))))) + (0.1f * (0 - (2.999999999999997f * (0 - (1.999999999999997f * (0 - (3.108624468950429e-015f * (0 - (1.000000000000003f * fYec5[(fYec5_idx+i-88)&127]))))))))))))) + (fSlow929 * ((fSlow927 * ((fSlow916 * ((fSlow914 * ((fSlow926 * fYec4[(fYec4_idx+i-iSlow925)&1023]) + (fSlow924 * fYec4[(fYec4_idx+i-iSlow923)&1023]))) + (fSlow922 * fYec4[(fYec4_idx+i-iSlow921)&1023]))) + (fSlow920 * fYec4[(fYec4_idx+i-iSlow918)&1023]))) + (fSlow917 * fYec4[(fYec4_idx+i-iSlow908)&1023])))));
			}
			
		}
	}
};



/***************************END USER SECTION ***************************/

/*******************BEGIN ARCHITECTURE SECTION (part 2/2)***************/
					

/******************************************************************************
 *
 * VST wrapper
 * 
 ******************************************************************************/

#include "audioeffectx.h" 

class vstUI;

class Faust : public AudioEffectX
{

private:
  mydsp*    dsp;
  vstUI*    dspUI;
  char      programName[kVstMaxProgNameLen + 1];
  Meta      meta;

public:
  Faust(audioMasterCallback audioMaster, mydsp* dspi, vstUI* dspUIi);
  virtual ~Faust();

  virtual void	processReplacing(float **inputs, float **outputs, VstInt32 sampleFrames);

  virtual void	setProgramName(char *name);
  virtual void	getProgramName(char *name);

  virtual void	setParameter(VstInt32 index, float value);
  virtual float	getParameter(VstInt32 index);
  virtual void	getParameterLabel(VstInt32 index, char *label);
  virtual void	getParameterDisplay(VstInt32 index, char *text);
  virtual void	getParameterName(VstInt32 index, char *text);

  virtual void	setSampleRate(float sampleRate);

  virtual bool	getEffectName (char* name);
  virtual bool	getVendorString (char* text);
  virtual bool	getProductString (char* text);
  virtual VstInt32 getVendorVersion ();

  virtual bool	getInputProperties (VstInt32 index, VstPinProperties* properties);
  virtual bool	getOutputProperties (VstInt32 index, VstPinProperties* properties);
};

/*--------------------------------------------------------------------------*/
class vstUIObject {
protected:
  string fLabel;
  float* fZone;
		
  float range(float min, float max, float val) 
  {	// VST parameters are normalized in the range [0;1]
    val = min + val * (max - min);
    return (val < min) ? min : (val > max) ? max : val;
  }
	 
public:			
  vstUIObject(const char* label, float* zone):fLabel(label),fZone(zone) {}
  virtual ~vstUIObject() {}

  virtual void  GetName(char *text){std::strcpy(text,fLabel.c_str());}
  virtual void  SetValue(double f) {*fZone = range(0.0f,1.0f,(float)f);}
  virtual float GetValue() {return *fZone;}
  virtual void  GetDisplay(char *text){std::sprintf(text,"%f",*fZone);}
  virtual long  GetID() 
  {	/* returns the sum of all the ASCII characters  contained in the parameter's label */
    unsigned int i;
    long acc;
    for(i=0,acc = 0;i<fLabel.length();i++) acc += (fLabel.c_str())[i];
    return acc;
  }
};

/*--------------------------------------------------------------------------*/
class vstToggleButton : public vstUIObject {
	
public:	
	
  vstToggleButton(const char* label, float* zone):vstUIObject(label,zone) {}
  virtual ~vstToggleButton() {}
  virtual float GetValue() {return *fZone;}
  virtual void SetValue(double f) {*fZone = (f>0.5f)?1.0f:0.0f;}				
  virtual void  GetDisplay(char *text){(*fZone>0.5f)? std::strcpy(text,"ON"): std::strcpy(text,"OFF");}
};

/*--------------------------------------------------------------------------*/
class vstCheckButton : public vstUIObject {
	
public:
	
  vstCheckButton(const char* label, float* zone):vstUIObject(label,zone) {}
  virtual ~vstCheckButton() {}
  virtual float GetValue() {return *fZone;}
  virtual void SetValue(double f) {*fZone = (f>0.5f)?1.0f:0.0f;}
  virtual void  GetDisplay(char *text){(*fZone>0.5f)? std::strcpy(text,"ON"): std::strcpy(text,"OFF");}		
};

/*--------------------------------------------------------------------------*/
class vstButton : public vstUIObject {
	
public:
	
  vstButton(const char* label, float* zone):vstUIObject(label,zone) {}
  virtual ~vstButton() {}		
  virtual float GetValue() {return *fZone;}
  virtual void SetValue(double f) {*fZone = (f>0.5f)?1.0f:0.0f;}		
  virtual void  GetDisplay(char *text){(*fZone>0.5f)? std::strcpy(text,"ON"): std::strcpy(text,"OFF");}
};

/*--------------------------------------------------------------------------*/
class vstSlider : public vstUIObject {

private:
	
  float fInit;
  float fMin;
  float fMax;
  float fStep;
	
public:	
	
  vstSlider(const char* label, float* zone, float init, float min, float max, float step)
    :vstUIObject(label,zone), fInit(init), fMin(min), fMax(max),fStep(step) {}
  virtual ~vstSlider() {}	

  virtual float GetValue() {return (*fZone-fMin)/(fMax-fMin);}	// normalize
  virtual void SetValue(double f) {*fZone = range(fMin,fMax,(float)f);} // expand
};

/*--------------------------------------------------------------------------*/
class vstUI : public UI
{
private:
	
  vector<vstUIObject*> fUITable;
		
public:
			
  vstUI(){}
  virtual ~vstUI() 
  {
    for (vector<vstUIObject*>::iterator iter = fUITable.begin(); iter != fUITable.end(); iter++) delete *iter;
  }
		
  void addButton(const char* label, float* zone) {fUITable.push_back(new vstButton(label, zone));}
		
  void addToggleButton(const char* label, float* zone) {fUITable.push_back(new vstToggleButton(label, zone));}
		
  void addCheckButton(const char* label, float* zone) {fUITable.push_back(new vstCheckButton(label, zone));}
		
  void addVerticalSlider(const char* label, float* zone, float init, float min, float max, float step)
  { 	
    fUITable.push_back(new vstSlider(label, zone, init, min, max, step));
  }
		
  void addHorizontalSlider(const char* label, float* zone, float init, float min, float max, float step)
  {
    fUITable.push_back(new vstSlider(label, zone, init, min, max, step));
  }
		
  void addNumEntry(const char* label, float* zone, float init, float min, float max, float step)
  { /* Number entries converted to horizontal sliders */
    fUITable.push_back(new vstSlider(label, zone, init, min, max, step));
  }
		
  void openFrameBox(const char* label) {}
  void openTabBox(const char* label) {}
  void openHorizontalBox(const char* label) {}
  void openVerticalBox(const char* label) {}
  void closeBox() {}
		
  void  SetValue(VstInt32 index, double f) {assert(index<fUITable.size()); fUITable[index]->SetValue(f);}
  float GetValue(VstInt32 index) {assert(index<fUITable.size()); return fUITable[index]->GetValue();}
  void  GetDisplay(VstInt32 index, char *text) {assert(index<fUITable.size()); fUITable[index]->GetDisplay(text);}
  void  GetName(VstInt32 index, char *text) {assert(index<fUITable.size()); fUITable[index]->GetName(text);}
  long  GetNumParams() {return fUITable.size();}

  long  makeID()
    /* Creates a (unique?)id by summing all the parameter's labels, 
     * then wrapping it in the range [0;maxNumberOfId] and adding 
     * this number to the offset made by the Four Character ID: 'FAUS'
     */
  {   
    const long maxNumberOfId = 128;
    long baseid = 'FAUS';
    long id=0;
    for(int i=0;i<fUITable.size();i++) id += fUITable[i]->GetID();
    return baseid + id % maxNumberOfId;
  }
		
  // To be implemented
  void addNumDisplay(const char* label, float* zone, int precision){}
  void addTextDisplay(const char* label, float* zone, char* names[], float min, float max){}
  void addHorizontalBargraph(const char* label, float* zone, float min, float max){}
  void addVerticalBargraph(const char* label, float* zone, float min, float max){}
};

//-----------------------------------------------------------------------------
#define NUM_PROGRAMS 0

AudioEffect* createEffectInstance (audioMasterCallback audioMaster)
{
// The dsp and its UI need to be allocated now because
// AudioEffectX wants the no. parameters available as an instance argument:
  mydsp* dspi = new mydsp();
  vstUI* dspUIi = new vstUI(); 
  dspi->buildUserInterface(dspUIi);
  return new Faust(audioMaster,dspi,dspUIi);
}

Faust::Faust(audioMasterCallback audioMaster, mydsp* dspi, vstUI* dspUIi)
  : AudioEffectX(audioMaster, NUM_PROGRAMS, dspUIi->GetNumParams())
{
  // Copy the pointers to dsp and dspUI instances and take them over 
  // (we'll also deallocate):
  dsp = dspi;
  dspUI = dspUIi;
  dsp->init(long(getSampleRate()));
  meta["name"] = "FaustFx";
  mydsp::metadata(&meta);
  setNumInputs(dsp->getNumInputs());		
  setNumOutputs(dsp->getNumOutputs());		
  setUniqueID(dspUI->makeID());					
  canProcessReplacing();

  vst_strncpy(programName, "Default", kVstMaxProgNameLen); // default program name
}

//----------------------------------------------------------------------------
Faust::~Faust()
{
  if (dsp) delete dsp;
  if (dspUI) delete dspUI;
}

//-------------------------------------------------------------------------------------------------------
void Faust::setProgramName (char* name)
{
  // this template does not use programs yet - just say "Default":
  vst_strncpy (programName, name, kVstMaxProgNameLen);
}

//-----------------------------------------------------------------------------
void Faust::getProgramName(char *name)
{
  vst_strncpy (name, programName, kVstMaxProgNameLen);
}

//-----------------------------------------------------------------------------
void Faust::setParameter(VstInt32 index, float value)
{
  if(index<numParams)
    dspUI->SetValue(index,value);
}

//-----------------------------------------------------------------------------
float Faust::getParameter(VstInt32 index)
{
  if(index<numParams)
    return dspUI->GetValue(index);
  else
    return 0.0f;
}
//-----------------------------------------------------------------------------
void Faust::getParameterName(VstInt32 index, char *label)
{
  if(index<numParams)
    dspUI->GetName(index,label); // parameter name, including units
  else
    vst_strncpy (label, "IndexOutOfRange", kVstMaxParamStrLen);
}
//-----------------------------------------------------------------------------
void Faust::getParameterDisplay(VstInt32 index, char *text)
{
  if(index<numParams)
    dspUI->GetDisplay(index,text); // displayed float value as text
  else
    vst_strncpy (text, "IndexOutOfRange", kVstMaxParamStrLen);
}
//-----------------------------------------------------------------------------
void Faust::getParameterLabel(VstInt32 index, char *label)
{
  vst_strncpy (label, "", kVstMaxParamStrLen); // parameter units in Name
}

//-----------------------------------------------------------------------------
void Faust::setSampleRate(float sampleRate)
{
  // allways call this
  AudioEffect::setSampleRate(sampleRate);
  dsp->init(long(getSampleRate()));
}

//-----------------------------------------------------------------------------------------
bool Faust::getEffectName (char* text)
{
  vst_strncpy (text, meta["name"].c_str(), kVstMaxProductStrLen);
  return true;
}

//-----------------------------------------------------------------------------------------
bool Faust::getVendorString (char* text)
{
  if (meta.count("author") > 0) {
    vst_strncpy (text, meta["author"].c_str(), kVstMaxVendorStrLen);
    return true;
  } else {
    return false;
  }
}

//-----------------------------------------------------------------------------------------
bool Faust::getProductString (char* text)
{
  vst_strncpy (text, meta["name"].c_str(), kVstMaxProductStrLen);
  return true;
}

//-----------------------------------------------------------------------------------------
VstInt32 Faust::getVendorVersion ()
{ 
	return 1000; 
}

//-----------------------------------------------------------------------------
void Faust::processReplacing(float **inputs, float **outputs, VstInt32 sampleFrames)
{
    AVOIDDENORMALS;
    dsp->compute(sampleFrames, inputs, outputs);
}

//-----------------------------------------------------------------------------------------
bool Faust::getInputProperties (VstInt32 index, VstPinProperties* properties)
{
  if(index>=0 && index<dsp->getNumInputs())
  {
    sprintf (properties->label, "Grame Faust DSP input: %d",index);
    sprintf (properties->shortLabel, "In %d",index);
    properties->flags = kVstPinIsActive;
    if (dsp->getNumInputs() == 2) {
      properties->flags |= kVstPinIsStereo;
    }
    return true;
  }
  else
    return false;
}

//-----------------------------------------------------------------------------------------
bool Faust::getOutputProperties (VstInt32 index, VstPinProperties* properties)
{
  if(index>=0 && index<dsp->getNumOutputs())
  {
    sprintf (properties->label, "Grame Faust DSP output: %d",index);
    sprintf (properties->shortLabel, "Out %d",index);
    properties->flags = kVstPinIsActive;
    if (dsp->getNumOutputs() == 2) {
      properties->flags |= kVstPinIsStereo;
    }
    return true;
  }
  else
    return false;
}

/********************END ARCHITECTURE SECTION (part 2/2)****************/


